dnl
dnl Extra macros used by GWXLIBS.
dnl

dnl
dnl First and foremost is a modified check for mmap(). The original
dnl autoconf MMAP check would fail if the system cant handle MAP_FIXED.
dnl Very few applications actually use that. So I have changed to test
dnl to set two defines, one called HAVE_MMAP and one called
dnl HAVE_MMAP_FIXED. The latter should be used to check to see if
dnl MAP_FIXED works correctly. If the application doesnt care about
dnl fixed memory mappings, it can happily use HAVE_MMAP.
AC_DEFUN([GWX_FUNC_MMAP],
[AC_CHECK_HEADERS(stdlib.h unistd.h)
AC_CHECK_FUNCS(getpagesize)
AC_MSG_CHECKING(for working mmap)
AC_CACHE_VAL(ac_cv_func_mmap_multi,
[AC_RUN_IFELSE([AC_LANG_SOURCE([AC_INCLUDES_DEFAULT]
[[/* Thanks to Mike Haertel and Jim Avera for this test.
   Here is a matrix of mmap possibilities:
	mmap private not fixed
	mmap private fixed at somewhere currently unmapped
	mmap private fixed at somewhere already mapped
	mmap shared not fixed
	mmap shared fixed at somewhere currently unmapped
	mmap shared fixed at somewhere already mapped
   For private mappings, we should verify that changes cannot be read()
   back from the file, nor mmap's back from the file at a different
   address.  (There have been systems where private was not correctly
   implemented like the infamous i386 svr4.0, and systems where the
   VM page cache was not coherent with the file system buffer cache
   like early versions of FreeBSD and possibly contemporary NetBSD.)
   For shared mappings, we should conversely verify that changes get
   propogated back to all the places they're supposed to be.

   Grep wants private fixed already mapped.
   The main things grep needs to know about mmap are:
   * does it exist and is it safe to write into the mmap'd area
   * how to use it (BSD variants)  */

#include <fcntl.h>
#include <sys/mman.h>
#include <errno.h>

#if !STDC_HEADERS && !HAVE_STDLIB_H
char *malloc ();
#endif

/* This mess was copied from the GNU getpagesize.h.  */
#if !HAVE_GETPAGESIZE
/* Assume that all systems that can run configure have sys/param.h.  */
# if !HAVE_SYS_PARAM_H
#  define HAVE_SYS_PARAM_H 1
# endif

# ifdef _SC_PAGESIZE
#  define getpagesize() sysconf(_SC_PAGESIZE)
# else /* no _SC_PAGESIZE */
#  if HAVE_SYS_PARAM_H
#   include <sys/param.h>
#   ifdef EXEC_PAGESIZE
#    define getpagesize() EXEC_PAGESIZE
#   else /* no EXEC_PAGESIZE */
#    ifdef NBPG
#     define getpagesize() NBPG * CLSIZE
#     ifndef CLSIZE
#      define CLSIZE 1
#     endif /* no CLSIZE */
#    else /* no NBPG */
#     ifdef NBPC
#      define getpagesize() NBPC
#     else /* no NBPC */
#      ifdef PAGESIZE
#       define getpagesize() PAGESIZE
#      endif /* PAGESIZE */
#     endif /* no NBPC */
#    endif /* no NBPG */
#   endif /* no EXEC_PAGESIZE */
#  else /* no HAVE_SYS_PARAM_H */
#   define getpagesize() 8192	/* punt totally */
#  endif /* no HAVE_SYS_PARAM_H */
# endif /* no _SC_PAGESIZE */

#endif /* no HAVE_GETPAGESIZE */

int
main ()
{
  char *data, *data2, *data3, *data4;
  char tout[8];
  int i, pagesize;
  int fd, ret = 0;

  pagesize = getpagesize ();

  /* First, make a file with some known garbage in it. */
  data = (char *) malloc (pagesize);
  if (!data)
    exit (1);
  for (i = 0; i < pagesize; ++i)
    *(data + i) = rand ();
  umask (0);
  fd = creat ("conftest.mmap", 0600);
  if (fd < 0)
    exit (1);
  if (write (fd, data, pagesize) != pagesize)
    exit (1);
  close (fd);

  /* Next, try to mmap the file at a fixed address which already has
     something else allocated at it.  If we can, also make sure that
     we see the same garbage.  */
  fd = open ("conftest.mmap", O_RDWR);
  if (fd < 0)
    exit (1);
  data2 = (char *) malloc (2 * pagesize);
  if (!data2)
    exit (1);
  data2 += (pagesize - ((int) data2 & (pagesize - 1))) & (pagesize - 1);
  data4 = mmap (data2, pagesize, PROT_READ | PROT_WRITE,
                     MAP_PRIVATE | MAP_FIXED, fd, 0L);
  if (errno != 0 && errno == ENOMEM) {
      errno = 0;
      data4 = mmap (data, pagesize, PROT_READ | PROT_WRITE,
	  MAP_PRIVATE, fd, 0L);
      if (errno != 0)
	  exit (1);
      ret = 2;
  } else if (data4 != data2)
    exit (1);
  for (i = 0; i < pagesize; ++i)
    if (*(data + i) != *(data4 + i))
      exit (1);

  /* Finally, make sure that changes to the mapped area do not
     percolate back to the file as seen by read().  (This is a bug on
     some variants of i386 svr4.0.)  */
  for (i = 0; i < pagesize; ++i)
    *(data4 + i) = *(data4 + i) + 1;
  data3 = (char *) malloc (pagesize);
  if (!data3)
    exit (1);
  if (read (fd, data3, pagesize) != pagesize)
    exit (1);
  for (i = 0; i < pagesize; ++i)
    if (*(data + i) != *(data3 + i))
      exit (1);
  close (fd);
  fd=creat("conftestmp", 0600);
  if (fd < 0)
      exit (1);
  tout[0] = '0' + ret;
  tout[1] = '\n';
  write (fd, tout, 2);
  close (fd);
  exit (0);
}]])],
               [ac_cv_func_mmap_multi=`cat conftestmp`],
               [ac_cv_func_mmap_multi=1],
               [ac_cv_func_mmap_multi=1])])
if test $ac_cv_func_mmap_multi = 0; then
  ac_cv_func_mmap_fixed_mapped=yes
  ac_cv_func_mmap=yes
elif test $ac_cv_func_mmap_multi = 1; then
  ac_cv_func_mmap_fixed_mapped=no
  ac_cv_func_mmap=no
else
  ac_cv_func_mmap_fixed_mapped=no
  ac_cv_func_mmap=yes
fi
if test $ac_cv_func_mmap_fixed_mapped = yes; then
  AC_GWX_DEFINE(HAVE_MMAP_FIXED, 1,
            [Define if `mmap' supports fixed, mapped files])
  AC_MSG_RESULT([yes, with MAP_FIXED])
fi
if test $ac_cv_func_mmap = yes; then
  AC_GWX_DEFINE(HAVE_MMAP, 1,
            [Define if your system supports the `mmap' system call])
  AC_MSG_RESULT([yes, without MAP_FIXED])
fi
if test $ac_cv_func_mmap_multi = 1; then
  AC_MSG_RESULT(no)
fi
rm -f conftest.mmap conftestmp
])# GWX_FUNC_MMAP

dnl
dnl Many of the packages want to know if we are on some sort of System V
dnl machine, and if so, what version. This is an attempt to get that
dnl right.
dnl
AC_DEFUN(AC_SYS_SYSTEMV,[
AC_REQUIRE([AC_CANONICAL_HOST])
AC_MSG_CHECKING([for UNIX System V])
AC_CACHE_VAL(glib_cv_sys_systemv,[
systype=none
case "$host" in
  *sco3*)     systype=sysv32 ;;
  *sysv3*)    systype=usgv32 ;;
  *sysv4*)    systype=sysv4 ;;
  *sysv5*)    systype=sysv5 ;;
  *are7*)     systype=sysv5 ;;
  *svr4*)     systype=sysv4 ;;
  *svr5*)     systype=sysv5 ;;
  *solaris2*) systype=sysv4 ;;
  *solaris7*) systype=sysv4 ;;
  *aix*)      systype=usgv32 ;;
  *isc3*)     systype=sysv32 ;;
  *)          systype=none ;;
esac
glib_cv_sys_systemv=$systype
])dnl End of cache value

sysvdefs=
case "$glib_cv_sys_systemv" in
  usgv32)  SYSVDEFS="-DUSG -DSYSV32 -DSYSV" ;;
  sysv32)  SYSVDEFS="-DSYSV32 -DSYSV" ;;
  sysv4)   SYSVDEFS="-DSVR4 -DSYSV4" ;;
  sysv5)   SYSVDEFS="-DSVR42 -DSVR4 -DSVR5 -DSYSV5 -DSYSV4" ;;
esac

if test x$glib_cv_sys_systemv = xnone; then
  sysvres="no"
else
  sysvres="yes"
fi
AC_SUBST(SYSVDEFS)
AC_MSG_RESULT([${sysvres}])
])dnl End of AC_SYS_SYSTYPE

dnl
dnl Check for sys_errlist
dnl
AC_DEFUN(AC_VAR_SYS_ERRLIST,[
AC_REQUIRE([AC_PROG_CC])
AC_MSG_CHECKING(for sys_errlist)
AC_CACHE_VAL(glib_cv_var_sys_errlist,[
AC_TRY_LINK(, [
extern char *sys_errlist[];
extern int sys_nerr;
sys_errlist[sys_nerr-1][0] = 0;
], glib_cv_var_sys_errlist=yes, glib_cv_var_sys_errlist=no)
])dnl End of cache value
AC_MSG_RESULT([${glib_cv_var_sys_errlist}])
if test $glib_cv_var_sys_errlist = no; then
  AC_GWX_DEFINE(NO_SYS_ERRLIST,1,[global 'sys_errlist' not found])
fi
])dnl End of AC_VAR_SYS_ERRLIST

dnl
dnl Check for sys_siglist
dnl
AC_DEFUN(AC_VAR_SYS_SIGLIST,[
AC_REQUIRE([AC_PROG_CC])
AC_MSG_CHECKING(for sys_siglist)
AC_CACHE_VAL(glib_cv_var_sys_siglist,[
AC_TRY_LINK(, [
extern char *sys_siglist[];
sys_siglist[0][0] = 0;
], glib_cv_var_sys_siglist=yes, glib_cv_var_sys_siglist=no)
])dnl End of cache value
AC_MSG_RESULT([${glib_cv_var_sys_siglist}])
if test $glib_cv_var_sys_siglist = no; then
  AC_GWX_DEFINE(NO_SYS_SIGLIST,1,[global 'sys_siglist' not found])
fi
])dnl End of AC_VAR_SYS_SIGLIST

dnl
dnl Check for sys_siglist decl (see Tue Jan 19 00:44:24 1999 in changelog)
dnl
AC_DEFUN(AC_VAR_SYS_SIGLIST_DECL,[
AC_REQUIRE([AC_PROG_CC])
AC_MSG_CHECKING(for sys_siglist declaration)
AC_CACHE_VAL(glib_cv_var_sys_siglist_decl,[
AC_TRY_COMPILE([#include <signal.h>], [
strlen (sys_siglist[0]);
], glib_cv_var_sys_siglist_decl=yes, glib_cv_var_sys_siglist_decl=no)
])dnl End of cache value
AC_MSG_RESULT([${glib_cv_var_sys_siglist_decl_ok}])
if test $glib_cv_var_sys_siglist_decl = no; then
  AC_GWX_DEFINE(NO_SYS_SIGLIST_DECL,1,[global 'sys_siglist' not declared])
fi
])dnl End of AC_VAR_SYS_SIGLIST_DECL

dnl
dnl Check for type unsigned char
dnl
AC_DEFUN(AC_TYPE_UNSIGNED_CHAR,[
AC_REQUIRE([AC_PROG_CC])
AC_MSG_CHECKING(for unsigned char)
AC_CACHE_VAL(glib_cv_type_unsigned_char,[
AC_TRY_COMPILE(,[
unsigned char un_char;
], glib_cv_type_unsigned_char=yes, glib_cv_type_unsigned_char=no)
])dnl End of cache value
AC_MSG_RESULT([${glib_cv_type_unsigned_char}])
if test $glib_cv_type_unsigned_char = yes; then
  AC_GWX_DEFINE(HAVE_UNSIGNED_CHAR)
fi
])dnl End of AC_TYPE_UNSIGNED_CHAR

dnl
dnl Check for type unsigned short
dnl
AC_DEFUN(AC_TYPE_UNSIGNED_SHORT,[
AC_REQUIRE([AC_PROG_CC])
AC_MSG_CHECKING(for unsigned short)
AC_CACHE_VAL(glib_cv_type_unsigned_short,[
AC_TRY_COMPILE(,[
unsigned short un_short;
], glib_cv_type_unsigned_short=yes, glib_cv_type_unsigned_short=no)
])dnl End of cache value
AC_MSG_RESULT([${glib_cv_type_unsigned_short}])
if test $glib_cv_type_unsigned_short = yes; then
  AC_GWX_DEFINE(HAVE_UNSIGNED_SHORT)
fi
])dnl End of AC_TYPE_UNSIGNED_SHORT

dnl
dnl This bit from gtk+/glib
dnl
AC_DEFUN(AC_CHECK_WCTYPE,[
AC_REQUIRE([AC_PROG_CC])
AC_MSG_CHECKING([if iswalnum() and friends are properly defined])
AC_CACHE_VAL(glib_cv_wctype_ok,[
AC_TRY_LINK([#include <stdlib.h>],[
#if (defined(HAVE_WCTYPE_H) || defined(HAVE_WCHAR_H))
#  ifdef HAVE_WCTYPE_H
#    include <wctype.h>
#  else
#    ifdef HAVE_WCHAR_H
#      include <wchar.h>
#    endif
#  endif
#else
#  define iswalnum(c) ((wchar_t)(c) <= 0xFF && isalnum(c))
#endif
iswalnum((wchar_t) 0);
], glib_cv_wctype_ok=yes, glib_cv_wctype_ok=no)
])dnl End of cache value
AC_MSG_RESULT([${glib_cv_wctype_ok}])

if test $glib_cv_wctype_ok = no; then
   AC_GWX_DEFINE(HAVE_BROKEN_WCTYPE)
fi

GDK_WLIBS=
AC_CHECK_FUNC(iswalnum,,[AC_CHECK_LIB(w,iswalnum,GDK_WLIBS=-lw)])
AC_SUBST(GDK_WLIBS)
])dnl End of AC_CHECK_WCTYPE

dnl *** check for sane realloc() ***
AC_DEFUN(AC_CHECK_REALLOC,[
AC_REQUIRE([AC_PROG_CC])
AC_MSG_CHECKING(whether realloc (NULL) will work)
AC_CACHE_VAL(glib_cv_sane_realloc,[
	AC_TRY_RUN([
	#include <stdlib.h>
	int main() {
	  return realloc (0, sizeof (int)) == 0;
	}],
	[glib_cv_sane_realloc=yes],
	[glib_cv_sane_realloc=no],
	[glib_cv_sane_realloc=yes])
])dnl End of cache value
AC_MSG_RESULT([${glib_cv_sane_realloc}])

if test $glib_cv_sane_realloc = yes; then
   AC_GWX_DEFINE(REALLOC_NULL_WORKS)
   AC_GWX_DEFINE(REALLOC_0_WORKS)
fi
])dnl End of AC_CHECK_REALLOC

dnl
dnl Check to see if the compiler supports prototypes
dnl
AC_DEFUN(GWX_C_PROTOTYPES,[
AC_REQUIRE([AC_PROG_CC])
AC_MSG_CHECKING(for function prototypes)
AC_CACHE_VAL(glib_cv_c_prototypes,[
AC_TRY_COMPILE(,[
int testfunction (int arg1, int * arg2); /* check prototypes */
struct methods_struct {		/* check method-pointer declarations */
  int (*error_exit) (char *msgtext);
  int (*trace_message) (char *msgtext);
  int (*another_method) (void);
};
int testfunction (int arg1, int * arg2) /* check definitions */
{ return arg2[arg1]; }
int test2function (void)	/* check void arg list */
{ return 0; }
], glib_cv_c_prototypes=yes, glib_cv_c_prototypes=no)
])dnl End of cache value
AC_MSG_RESULT([${glib_cv_c_prototypes}])

if test $glib_cv_c_prototypes = yes; then
   AC_GWX_DEFINE(HAVE_PROTOTYPES)
fi
])dnl End of GWX_C_PROTOYPES

dnl
dnl This is intuited from jpeg's configure (they forgot to provide their
dnl configure.in, which they really should have).
dnl
AC_DEFUN(AC_C_RIGHT_SHIFT_UNSIGNED,[
AC_REQUIRE([AC_PROG_CC])
AC_MSG_CHECKING([to see if right shift is unsigned])
AC_CACHE_VAL(glib_cv_c_right_shift_unsigned,[
AC_TRY_RUN([
#ifdef HAVE_PROTOTYPES
int is_shifting_signed (long arg)
#else
int is_shifting_signed (arg)
     long arg;
#endif
/* See whether right-shift on a long is signed or not. */
{
  long res = arg >> 4;

  if (res == -0x7F7E80CL) {	/* expected result for signed shift */
    return 1;			/* right shift is signed */
  }
  /* see if unsigned-shift hack will fix it. */
  /* we can't just test exact value since it depends on width of long... */
  res |= (~0L) << (32-4);
  if (res == -0x7F7E80CL) {	/* expected result now? */
    return 0;			/* right shift is unsigned */
  }
  printf("Right shift isn't acting as I expect it to.\n");
  printf("I fear the JPEG software will not work at all.\n\n");
  return 0;			/* try it with unsigned anyway */
}
main() {
  exit(is_shifting_signed(-0x7F7E80B1L));
}
], glib_cv_c_right_shift_unsigned=yes, glib_cv_c_right_shift_unsigned=no,
glib_cv_c_right_shift_unsigned=yes)
])dnl End of cache value
AC_MSG_RESULT([${glib_cv_c_right_shift_unsigned}])

if test $glib_cv_c_right_shift_unsigned = yes; then
   AC_GWX_DEFINE(RIGHT_SHIFT_IS_UNSIGNED)
fi
])dnl End of AC_C_RIGHT_SHIFT_SIGNED

dnl
dnl This is used when searching through the gwxcfg.h header file. We do
dnl this by running the preprocessor on the file after inserting special
dnl code, rather than doing an egrep through it (which is less reliable).
dnl
dnl The macro is defined as:
dnl AC_GWX_CHECK(VARIABLE, ACTION-IF-FOUND, [ACTION-IF-NOT-FOUND])
dnl AC_GOPT_CHECK(VARIABLE, ACTION-IF-FOUND, [ACTION-IF-NOT-FOUND)
dnl
dnl AC_GOPT_CHECK is the same as AC_GWX_CHECK except that it does
dnl not do a SUBST for the library name, and should be used to check
dnl for library options, not actual library compile enables.
dnl
AC_DEFUN(AC_GWX_CHECK,[
AC_REQUIRE_CPP()dnl
gwx_using_$1=no
AC_MSG_CHECKING(for library $1)
cat > conftest.$ac_ext <<EOF
[#]line __oline__ "configure"
#include "confdefs.h"
#include "gwxcfg.h"
#if defined(GWX_COMPILE_$1)
# if (GWX_COMPILE_$1)
yes
# endif
#endif
EOF
AC_SUBST(GWXCFG_DEP_$1)
AC_SUBST(GHAVE_$1)
AC_SUBST(GLDFLAG_$1)
AC_SUBST(GLDFLAG_$1_L)
AC_SUBST(GLDFLAG_DEP_$1)
AC_SUBST(GLDFLAG_DEP_$1_L)
AC_SUBST(GINCLUDE_$1)
if (eval "$ac_cpp conftest.$ac_ext") 2>&AS_MESSAGE_LOG_FD |
  egrep "yes" > /dev/null 2>&1; then
  gwx_using_$1=yes
  AC_GWX_DEFINE(HAVE_$1)
  AC_GWX_DEFINE(HAVE_LIB$1)
  ifelse([$2], , :, [rm -rf conftest*
  AC_MSG_RESULT(yes)
  [cat >> confdefs.h <<EOF
#define HAVE_$1 1
EOF
]dnl
  GHAVE_$1="-DHAVE_LIB$1 -DHAVE_$1"
  GWXCFG_DEP_$1=""
  $2])
ifelse([$3], ,[else
AC_MSG_RESULT(no)
] , [else
  AC_MSG_RESULT(no)
  rm -rf conftest*
  $3
])dnl
fi
rm -rf conftest*
])dnl
])dnl End of AC_GWX_CHECK

AC_DEFUN(AC_GOPT_CHECK,[
AC_REQUIRE_CPP()dnl
AC_MSG_CHECKING(for option $1)
cat > conftest.$ac_ext <<EOF
[#]line __oline__ "configure"
#include "confdefs.h"
#include "gwxcfg.h"
#if defined($1)
# if ($1 != 0)
yes
# endif
#endif
EOF
if (eval "$ac_cpp conftest.$ac_ext") 2>&AS_MESSAGE_LOG_FD |
  egrep "yes" > /dev/null 2>&1; then
  ifelse([$2], , AC_MSG_RESULT(yes), [rm -rf conftest*
  AC_MSG_RESULT(yes)
  $2])
ifelse([$3], ,[else
AC_MSG_RESULT(no)
] , [else
  AC_MSG_RESULT(no)
  rm -rf conftest*
  $3
])dnl
fi
rm -rf conftest*
])dnl
])dnl End of AC_GOPT_CHECK

dnl
dnl This is used instead of ac_define so that autoheader doesnt choke.
dnl Since we know that in GWXLIBS we will be outputing stuff to headers
dnl from other packages, we really dont need to weigh down our own
dnl acconfig.h with things defined in other packages header templates.
dnl Since autoheader scans for ac_define stuff, we need our own way of
dnl getting things into confdefs.h without getting autoheader's attention.
dnl
define(AC_GWX_DEFINE,[
m4_ifval([$3], [AH_TEMPLATE([$1], [$3])])dnl
cat >>confdefs.h <<\_ACEOF
[@%:@define] $1 m4_if($#, 2, [$2], $#, 3, [$2], 1)
_ACEOF
])dnl End of AC_GWX_DEFINE

define(AC_GWX_DEFINE_UNQUOTED,[
m4_ifval([$3], [AH_TEMPLATE([$1], [$3])])dnl
cat >>confdefs.h <<_ACEOF
[@%:@define] $1 m4_if($#, 2, [$2], $#, 3, [$2], 1)
_ACEOF
])dnl End of AC_GWX_DEFINE_UNQUOTED

dnl
dnl This is used to extract the library version numbers from gwxcfg.h
dnl and set the appropriate makefile variables in Makefile.top
dnl AC_GWX_LIBVER(LIBRARY-NAME, GWXCFG-NAME, MAKEFILE-NAME)
AC_DEFUN(AC_GWX_LIBVER,[
AC_REQUIRE_CPP()dnl
AC_MSG_CHECKING(for $1 shared library version)
cat > conftest.$ac_ext <<EOF
[#]line __oline__ "configure"
#include "confdefs.h"
#include "gwxcfg.h"
LIBVER=$2
EOF
if (eval "$ac_cpp conftest.$ac_ext" > conftest.out) 2>&AS_MESSAGE_LOG_FD; then
  tlibver=`sed -n -e '/LIBVER=/p' conftest.out | sed -e 's/LIBVER=//' | sed -e 's/" "//'`
  AC_MSG_RESULT([${tlibver}])
  $3="$tlibver"
else
  AC_MSG_RESULT(0.0.0)
  $3="0.0.0"
fi
AC_SUBST($3)
rm -rf conftest*
])dnl End of AC_GWX_LIBVER

dnl
dnl check for availability of multibyte characters and functions
dnl
AC_DEFUN(BASH_CHECK_MULTIBYTE,
[
AC_CHECK_HEADERS(wctype.h)
AC_CHECK_HEADERS(wchar.h)
AC_CHECK_HEADERS(langinfo.h)

AC_CHECK_FUNC(mbsrtowcs, AC_DEFINE(HAVE_MBSRTOWCS))
AC_CHECK_FUNC(wcwidth, AC_DEFINE(HAVE_WCWIDTH))

AC_CACHE_CHECK([for mbstate_t], bash_cv_have_mbstate_t,
[AC_TRY_RUN([
#include <wchar.h>
int
main ()
{
  mbstate_t ps;
  return 0;
}], bash_cv_have_mbstate_t=yes,  bash_cv_have_mbstate_t=no)])
if test $bash_cv_have_mbstate_t = yes; then
	AC_GWX_DEFINE(HAVE_MBSTATE_T)
fi

AC_CACHE_CHECK([for nl_langinfo and CODESET], bash_cv_langinfo_codeset,
[AC_TRY_LINK(
[#include <langinfo.h>],
[char* cs = nl_langinfo(CODESET);],
bash_cv_langinfo_codeset=yes, bash_cv_langinfo_codeset=no)])
if test $bash_cv_langinfo_codeset = yes; then
   AC_GWX_DEFINE(HAVE_CODESET,1,[Have nl_langinfo (CODESET)])
   AC_GWX_DEFINE(HAVE_LANGINFO_CODESET,1,[Have nl_langinfo (CODESET)])
fi

])

dnl Check type of signal routines (posix, 4.2bsd, 4.1bsd or v7)
AC_DEFUN(BASH_SIGNAL_CHECK,
[AC_REQUIRE([AC_TYPE_SIGNAL])
AC_MSG_CHECKING(for type of signal functions)
AC_CACHE_VAL(bash_cv_signal_vintage,
[
  AC_TRY_LINK([#include <signal.h>],[
    sigset_t ss;
    struct sigaction sa;
    sigemptyset(&ss); sigsuspend(&ss);
    sigaction(SIGINT, &sa, (struct sigaction *) 0);
    sigprocmask(SIG_BLOCK, &ss, (sigset_t *) 0);
  ], bash_cv_signal_vintage=posix,
  [
    AC_TRY_LINK([#include <signal.h>], [
	int mask = sigmask(SIGINT);
	sigsetmask(mask); sigblock(mask); sigpause(mask);
    ], bash_cv_signal_vintage=4.2bsd,
    [
      AC_TRY_LINK([
	#include <signal.h>
	RETSIGTYPE foo() { }], [
		int mask = sigmask(SIGINT);
		sigset(SIGINT, foo); sigrelse(SIGINT);
		sighold(SIGINT); sigpause(SIGINT);
        ], bash_cv_signal_vintage=svr3, bash_cv_signal_vintage=v7
    )]
  )]
)
])
AC_MSG_RESULT($bash_cv_signal_vintage)
if test "$bash_cv_signal_vintage" = posix; then
AC_GWX_DEFINE(HAVE_POSIX_SIGNALS)
elif test "$bash_cv_signal_vintage" = "4.2bsd"; then
AC_GWX_DEFINE(HAVE_BSD_SIGNALS)
elif test "$bash_cv_signal_vintage" = svr3; then
AC_GWX_DEFINE(HAVE_USG_SIGHOLD)
fi
])

AC_DEFUN(BASH_REINSTALL_SIGHANDLERS,
[AC_REQUIRE([AC_TYPE_SIGNAL])
AC_REQUIRE([BASH_SIGNAL_CHECK])
AC_MSG_CHECKING([if signal handlers must be reinstalled when invoked])
AC_CACHE_VAL(bash_cv_must_reinstall_sighandlers,
[AC_TRY_RUN([
#include <signal.h>
#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

typedef RETSIGTYPE sigfunc();

int nsigint;

#ifdef HAVE_POSIX_SIGNALS
sigfunc *
set_signal_handler(sig, handler)
     int sig;
     sigfunc *handler;
{
  struct sigaction act, oact;
  act.sa_handler = handler;
  act.sa_flags = 0;
  sigemptyset (&act.sa_mask);
  sigemptyset (&oact.sa_mask);
  sigaction (sig, &act, &oact);
  return (oact.sa_handler);
}
#else
#define set_signal_handler(s, h) signal(s, h)
#endif

RETSIGTYPE
sigint(s)
int s;
{
  nsigint++;
}

main()
{
	nsigint = 0;
	set_signal_handler(SIGINT, sigint);
	kill((int)getpid(), SIGINT);
	kill((int)getpid(), SIGINT);
	exit(nsigint != 2);
}
], bash_cv_must_reinstall_sighandlers=no, bash_cv_must_reinstall_sighandlers=yes,
   [AC_MSG_ERROR(cannot check signal handling if cross compiling -- defaulting to no)
    bash_cv_must_reinstall_sighandlers=no]
)])
AC_MSG_RESULT($bash_cv_must_reinstall_sighandlers)
if test $bash_cv_must_reinstall_sighandlers = yes; then
AC_GWX_DEFINE(MUST_REINSTALL_SIGHANDLERS)
fi
])

AC_DEFUN(BASH_FUNC_POSIX_SETJMP,
[AC_REQUIRE([BASH_SIGNAL_CHECK])
AC_MSG_CHECKING(for presence of POSIX-style sigsetjmp/siglongjmp)
AC_CACHE_VAL(bash_cv_func_sigsetjmp,
[AC_TRY_RUN([
#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif
#include <sys/types.h>
#include <signal.h>
#include <setjmp.h>

main()
{
#if !defined (_POSIX_VERSION) || !defined (HAVE_POSIX_SIGNALS)
exit (1);
#else

int code;
sigset_t set, oset;
sigjmp_buf xx;

/* get the mask */
sigemptyset(&set);
sigemptyset(&oset);
sigprocmask(SIG_BLOCK, (sigset_t *)NULL, &set);
sigprocmask(SIG_BLOCK, (sigset_t *)NULL, &oset);

/* save it */
code = sigsetjmp(xx, 1);
if (code)
  exit(0);	/* could get sigmask and compare to oset here. */

/* change it */
sigaddset(&set, SIGINT);
sigprocmask(SIG_BLOCK, &set, (sigset_t *)NULL);

/* and siglongjmp */
siglongjmp(xx, 10);
exit(1);
#endif
}], bash_cv_func_sigsetjmp=present, bash_cv_func_sigsetjmp=missing,
    [AC_MSG_ERROR(cannot check for sigsetjmp/siglongjmp if cross-compiling -- defaulting to missing)
     bash_cv_func_sigsetjmp=missing]
)])
AC_MSG_RESULT($bash_cv_func_sigsetjmp)
if test $bash_cv_func_sigsetjmp = present; then
AC_GWX_DEFINE(HAVE_POSIX_SIGSETJMP)
fi
])

AC_DEFUN(BASH_FUNC_LSTAT,
[dnl Cannot use AC_CHECK_FUNCS(lstat) because Linux defines lstat() as an
dnl inline function in <sys/stat.h>.
AC_CACHE_CHECK([for lstat], bash_cv_func_lstat,
[AC_TRY_LINK([
#include <sys/types.h>
#include <sys/stat.h>
],[ lstat(".",(struct stat *)0); ],
bash_cv_func_lstat=yes, bash_cv_func_lstat=no)])
if test $bash_cv_func_lstat = yes; then
  AC_GWX_DEFINE(HAVE_LSTAT)
fi
])

AC_DEFUN(BASH_CHECK_GETPW_FUNCS,
[AC_MSG_CHECKING(whether programs are able to redeclare getpw functions)
AC_CACHE_VAL(bash_cv_can_redecl_getpw,
[AC_TRY_COMPILE([#include <sys/types.h>
#include <pwd.h>
extern struct passwd *getpwent();
extern struct passwd *getpwuid();
extern struct passwd *getpwnam();],
[struct passwd *z; z = getpwent(); z = getpwuid(0); z = getpwnam("root");],
  bash_cv_can_redecl_getpw=yes,bash_cv_can_redecl_getpw=no)])
AC_MSG_RESULT($bash_cv_can_redecl_getpw)
if test $bash_cv_can_redecl_getpw = no; then
AC_GWX_DEFINE(HAVE_GETPW_DECLS)
fi
])

AC_DEFUN(BASH_FUNC_STRCOLL,
[
AC_MSG_CHECKING(whether or not strcoll and strcmp differ)
AC_CACHE_VAL(bash_cv_func_strcoll_broken,
[AC_TRY_RUN([
#include <stdio.h>
#if defined (HAVE_LOCALE_H)
#include <locale.h>
#endif

main(c, v)
int     c;
char    *v[];
{
        int     r1, r2;
        char    *deflocale, *defcoll;

#ifdef HAVE_SETLOCALE
        deflocale = setlocale(LC_ALL, "");
	defcoll = setlocale(LC_COLLATE, "");
#endif

#ifdef HAVE_STRCOLL
	/* These two values are taken from tests/glob-test. */
        r1 = strcoll("abd", "aXd");
#else
	r1 = 0;
#endif
        r2 = strcmp("abd", "aXd");

	/* These two should both be greater than 0.  It is permissible for
	   a system to return different values, as long as the sign is the
	   same. */

        /* Exit with 1 (failure) if these two values are both > 0, since
	   this tests whether strcoll(3) is broken with respect to strcmp(3)
	   in the default locale. */
	exit (r1 > 0 && r2 > 0);
}
], bash_cv_func_strcoll_broken=yes, bash_cv_func_strcoll_broken=no,
   [AC_MSG_ERROR(cannot check strcoll if cross compiling -- defaulting to no)
    bash_cv_func_strcoll_broken=no]
)])
AC_MSG_RESULT($bash_cv_func_strcoll_broken)
if test $bash_cv_func_strcoll_broken = yes; then
AC_GWX_DEFINE(STRCOLL_BROKEN)
fi
])

dnl
AC_DEFUN(BASH_TYPE_SIGHANDLER,
[AC_MSG_CHECKING([whether signal handlers are of type void])
AC_CACHE_VAL(bash_cv_void_sighandler,
[AC_TRY_COMPILE([#include <sys/types.h>
#include <signal.h>
#ifdef signal
#undef signal
#endif
#ifdef __cplusplus
extern "C"
#endif
void (*signal ()) ();],
[int i;], bash_cv_void_sighandler=yes, bash_cv_void_sighandler=no)])dnl
AC_MSG_RESULT($bash_cv_void_sighandler)
if test $bash_cv_void_sighandler = yes; then
AC_GWX_DEFINE(VOID_SIGHANDLER)
fi
])

AC_DEFUN(BASH_HAVE_TIOCGWINSZ,
[AC_MSG_CHECKING(for TIOCGWINSZ in sys/ioctl.h)
AC_CACHE_VAL(bash_cv_tiocgwinsz_in_ioctl,
[AC_TRY_COMPILE([#include <sys/types.h>
#include <sys/ioctl.h>], [int x = TIOCGWINSZ;],
  bash_cv_tiocgwinsz_in_ioctl=yes,bash_cv_tiocgwinsz_in_ioctl=no)])
AC_MSG_RESULT($bash_cv_tiocgwinsz_in_ioctl)
if test $bash_cv_tiocgwinsz_in_ioctl = yes; then   
AC_GWX_DEFINE(GWINSZ_IN_SYS_IOCTL)
fi
])

AC_DEFUN(BASH_HAVE_TIOCSTAT,
[AC_MSG_CHECKING(for TIOCSTAT in sys/ioctl.h)
AC_CACHE_VAL(bash_cv_tiocstat_in_ioctl,
[AC_TRY_COMPILE([#include <sys/types.h>
#include <sys/ioctl.h>], [int x = TIOCSTAT;],
  bash_cv_tiocstat_in_ioctl=yes,bash_cv_tiocstat_in_ioctl=no)])
AC_MSG_RESULT($bash_cv_tiocstat_in_ioctl)
if test $bash_cv_tiocstat_in_ioctl = yes; then   
AC_GWX_DEFINE(TIOCSTAT_IN_SYS_IOCTL)
fi
])

AC_DEFUN(BASH_HAVE_FIONREAD,
[AC_MSG_CHECKING(for FIONREAD in sys/ioctl.h)
AC_CACHE_VAL(bash_cv_fionread_in_ioctl,
[AC_TRY_COMPILE([#include <sys/types.h>
#include <sys/ioctl.h>], [int x = FIONREAD;],
  bash_cv_fionread_in_ioctl=yes,bash_cv_fionread_in_ioctl=no)])
AC_MSG_RESULT($bash_cv_fionread_in_ioctl)
if test $bash_cv_fionread_in_ioctl = yes; then   
AC_GWX_DEFINE(FIONREAD_IN_SYS_IOCTL)
fi
])

dnl
dnl See if speed_t is declared in <sys/types.h>.  Some versions of linux
dnl require a definition of speed_t each time <termcap.h> is included,
dnl but you can only get speed_t if you include <termios.h> (on some
dnl versions) or <sys/types.h> (on others).
dnl
AC_DEFUN(BASH_MISC_SPEED_T,
[AC_MSG_CHECKING(for speed_t in sys/types.h)
AC_CACHE_VAL(bash_cv_speed_t_in_sys_types,
[AC_TRY_COMPILE([#include <sys/types.h>], [speed_t x;],
  bash_cv_speed_t_in_sys_types=yes,bash_cv_speed_t_in_sys_types=no)])
AC_MSG_RESULT($bash_cv_speed_t_in_sys_types)
if test $bash_cv_speed_t_in_sys_types = yes; then   
AC_GWX_DEFINE(SPEED_T_IN_SYS_TYPES)
fi
])

AC_DEFUN(BASH_STRUCT_WINSIZE,
[AC_MSG_CHECKING(for struct winsize in sys/ioctl.h and termios.h)
AC_CACHE_VAL(bash_cv_struct_winsize_header,
[AC_TRY_COMPILE([#include <sys/types.h>
#include <sys/ioctl.h>], [struct winsize x;],
  bash_cv_struct_winsize_header=ioctl_h,
  [AC_TRY_COMPILE([#include <sys/types.h>
#include <termios.h>], [struct winsize x;],
  bash_cv_struct_winsize_header=termios_h, bash_cv_struct_winsize_header=other)
])])
if test $bash_cv_struct_winsize_header = ioctl_h; then
  AC_MSG_RESULT(sys/ioctl.h)
  AC_GWX_DEFINE(STRUCT_WINSIZE_IN_SYS_IOCTL)
  AC_GWX_DEFINE(HAVE_WINSIZE)
elif test $bash_cv_struct_winsize_header = termios_h; then
  AC_MSG_RESULT(termios.h)
  AC_GWX_DEFINE(STRUCT_WINSIZE_IN_TERMIOS)
  AC_GWX_DEFINE(HAVE_WINSIZE)
else
  AC_MSG_RESULT(not found)
fi
])

AC_DEFUN(BASH_STRUCT_DIRENT_D_INO,
[AC_REQUIRE([AC_HEADER_DIRENT])
AC_MSG_CHECKING(if struct dirent has a d_ino member)
AC_CACHE_VAL(bash_cv_dirent_has_dino,
[AC_TRY_COMPILE([
#include <stdio.h>
#include <sys/types.h>
#ifdef HAVE_UNISTD_H
# include <unistd.h>
#endif /* HAVE_UNISTD_H */
#if defined(HAVE_DIRENT_H)
# include <dirent.h>
#else
# define dirent direct
# ifdef HAVE_SYS_NDIR_H
#  include <sys/ndir.h>
# endif /* SYSNDIR */
# ifdef HAVE_SYS_DIR_H
#  include <sys/dir.h>
# endif /* SYSDIR */
# ifdef HAVE_NDIR_H
#  include <ndir.h>
# endif
#endif /* HAVE_DIRENT_H */
],[
struct dirent d; int z; z = d.d_ino;
], bash_cv_dirent_has_dino=yes, bash_cv_dirent_has_dino=no)])
AC_MSG_RESULT($bash_cv_dirent_has_dino)
if test $bash_cv_dirent_has_dino = yes; then
AC_GWX_DEFINE(STRUCT_DIRENT_HAS_D_INO)
fi
])

AC_DEFUN(BASH_STRUCT_DIRENT_D_FILENO,
[AC_REQUIRE([AC_HEADER_DIRENT])
AC_MSG_CHECKING(if struct dirent has a d_fileno member)
AC_CACHE_VAL(bash_cv_dirent_has_d_fileno,
[AC_TRY_COMPILE([
#include <stdio.h>
#include <sys/types.h>
#ifdef HAVE_UNISTD_H
# include <unistd.h>
#endif /* HAVE_UNISTD_H */
#if defined(HAVE_DIRENT_H)
# include <dirent.h>
#else
# define dirent direct
# ifdef HAVE_SYS_NDIR_H
#  include <sys/ndir.h>
# endif /* SYSNDIR */
# ifdef HAVE_SYS_DIR_H
#  include <sys/dir.h>
# endif /* SYSDIR */
# ifdef HAVE_NDIR_H
#  include <ndir.h>
# endif
#endif /* HAVE_DIRENT_H */
],[
struct dirent d; int z; z = d.d_fileno;
], bash_cv_dirent_has_d_fileno=yes, bash_cv_dirent_has_d_fileno=no)])
AC_MSG_RESULT($bash_cv_dirent_has_d_fileno)
if test $bash_cv_dirent_has_d_fileno = yes; then
AC_GWX_DEFINE(STRUCT_DIRENT_HAS_D_FILENO)
fi
])

AC_DEFUN(BASH_CHECK_LIB_TERMCAP,
[
if test "X$bash_cv_termcap_lib" = "X"; then
_bash_needmsg=yes
else
AC_MSG_CHECKING(which library has the termcap functions)
_bash_needmsg=
fi
AC_CACHE_VAL(bash_cv_termcap_lib,
[AC_CHECK_LIB(tinfo, tgetent, bash_cv_termcap_lib=libtinfo,
    [AC_CHECK_LIB(termcap, tgetent, bash_cv_termcap_lib=libtermcap,
        [AC_CHECK_LIB(curses, tgetent, bash_cv_termcap_lib=libcurses,
	    [AC_CHECK_LIB(ncurses, tgetent, bash_cv_termcap_lib=libncurses,
	        bash_cv_termcap_lib=gnutermcap)])])])])
if test "X$_bash_needmsg" = "Xyes"; then
AC_MSG_CHECKING(which library has the termcap functions)
fi
AC_MSG_RESULT(using $bash_cv_termcap_lib)
if test $bash_cv_termcap_lib = gnutermcap && test -z "$rl_prefer_curses"; then
LDFLAGS="$LDFLAGS -L./lib/termcap"
TERMCAP_LIB="./lib/termcap/libtermcap.a"
TERMCAP_DEP="./lib/termcap/libtermcap.a"
elif test $bash_cv_termcap_lib = libtermcap && test -z "$rl_prefer_curses"; then
TERMCAP_LIB=-ltermcap
TERMCAP_DEP=
elif test $bash_cv_termcap_lib = libncurses; then
TERMCAP_LIB=-lncurses
TERMCAP_DEP=
elif test $bash_cv_termcap_lib = libtinfo; then
TERMCAP_LIB=-ltinfo
TERMCAP_DEP=
else
TERMCAP_LIB=-lcurses
TERMCAP_DEP=
fi
])

dnl
dnl Check to see which version of X11 the system supports. Will set
dnl X11VERSION=R5 or R6.
dnl
AC_DEFUN(GWX_X11VERSION, [
AC_REQUIRE_CPP()dnl
AC_MSG_CHECKING(for X11 version)
AC_CACHE_VAL(glib_cv_x11_version, [
AC_EGREP_CPP(yes,
[#include <X11/IntrinsicP.h>
#if (XT_REVISION == 5)
yes
#endif
],[X11VERSION=5],[
AC_EGREP_CPP(yes,
[#include <X11/IntrinsicP.h>
#if (XT_REVISION == 6)
yes
#endif
],[X11VERSION=6],[X11VERSION=6]]))
glib_cv_x11_version=R${X11VERSION}
])dnl End of cache value
X11VERSION=$glib_cv_x11_version
AC_MSG_RESULT([${X11VERSION}])

if test $X11VERSION = R6; then
  AC_GWX_DEFINE(HAVE_X11R6)
fi
AC_SUBST(X11VERSION)
])dnl End of GWX_X11VERSION

dnl
dnl The following was written by jhawk@mit.edu
dnl
dnl AC_LIBRARY_NET: Id: net.m4,v 1.4 1997/10/25 20:49:53 jhawk Exp 
dnl
dnl This test is for network applications that need socket() and
dnl gethostbyname() -ish functions.  Under Solaris, those applications need to
dnl link with "-lsocket -lnsl".  Under IRIX, they should *not* link with
dnl "-lsocket" because libsocket.a breaks a number of things (for instance:
dnl gethostbyname() under IRIX 5.2, and snoop sockets under most versions of
dnl IRIX).
dnl 
dnl Unfortunately, many application developers are not aware of this, and
dnl mistakenly write tests that cause -lsocket to be used under IRIX.  It is
dnl also easy to write tests that cause -lnsl to be used under operating
dnl systems where neither are necessary (or useful), such as SunOS 4.1.4, which
dnl uses -lnsl for TLI.
dnl 
dnl This test exists so that every application developer does not test this in
dnl a different, and subtly broken fashion.
dnl 
dnl It has been argued that this test should be broken up into two seperate
dnl tests, one for the resolver libraries, and one for the libraries necessary
dnl for using Sockets API. Unfortunately, the two are carefully intertwined and
dnl allowing the autoconf user to use them independantly potentially results in
dnl unfortunate ordering dependancies -- as such, such component macros would
dnl have to carefully use indirection and be aware if the other components were
dnl executed. Since other autoconf macros do not go to this trouble, and almost
dnl no applications use sockets without the resolver, this complexity has not
dnl been implemented.
dnl
dnl The check for libresolv is in case you are attempting to link statically
dnl and happen to have a libresolv.a lying around (and no libnsl.a).
dnl
dnl SPECIAL NOTE: We need to trash any cached values for these functions
dnl otherwise, if you re-run configure after changing things, it will
dnl pick up the cached values from trying new libraries, and we wont
dnl correctly pick up which libraries these functions appear in.

AC_DEFUN(AC_LIBRARY_NET, [
   unset ac_cv_lib_resolv_inet_ntoa
   unset ac_cv_func_gethostbyname
   unset ac_cv_lib_nsl_gethostbyname
   unset ac_cv_lib_socket_gethostbyname
   unset ac_cv_lib_resolv_gethostbyname
   unset ac_cv_func_socket
   unset ac_cv_lib_socket_socket
   # Most operating systems have gethostbyname() in the default searched
   # libraries (i.e. libc):
   saved_net_LIBS="$LIBS"
   LIBS=
   AC_CHECK_LIB(resolv, inet_ntoa, AC_GWX_DEFINE(HAVE_LIBRESOLV))
   AC_CHECK_FUNC(gethostbyname, ,
     # Some OSes (eg. Solaris) place it in libnsl:
     AC_CHECK_LIB(nsl, gethostbyname, , 
       # Some strange OSes (SINIX) have it in libsocket:
       AC_CHECK_LIB(socket, gethostbyname, ,
          # Unfortunately libsocket sometimes depends on libnsl.
          # AC_CHECK_LIB's API is essentially broken so the following
          # ugliness is necessary:
          AC_CHECK_LIB(socket, gethostbyname,
             LIBS="-lsocket -lnsl $LIBS",
               AC_CHECK_LIB(resolv, gethostbyname),
             -lnsl)
       )
     )
   )
  AC_CHECK_FUNC(socket, , AC_CHECK_LIB(socket, socket, ,
    AC_CHECK_LIB(socket, socket, LIBS="-lsocket -lnsl $LIBS", , -lnsl)))
  SYSSOCKLIBS="$LIBS"
  AC_SUBST(SYSSOCKLIBS)
  LIBS="$saved_net_LIBS $SYSSOCKLIBS"
  ])

## FreeType specific autoconf tests

AC_DEFUN(FT_MUNMAP_DECL,
[AC_MSG_CHECKING([whether munmap must be declared])
AC_CACHE_VAL(ft_cv_munmap_decl,
[AC_TRY_COMPILE([
#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif
#include <sys/mman.h>],
[char *(*pfn) = (char *(*))munmap],
ft_cv_munmap_decl=no,
ft_cv_munmap_decl=yes)])
AC_MSG_RESULT($ft_cv_munmap_decl)
if test $ft_cv_munmap_decl = yes; then
	AC_GWX_DEFINE(NEED_MUNMAP_DECL)
fi])

AC_DEFUN(FT_MUNMAP_PARAM,
[AC_MSG_CHECKING([for munmap's first parameter type])
AC_TRY_COMPILE([
#include <unistd.h>
#include <sys/mman.h>
int munmap(void *, size_t);],,
  AC_MSG_RESULT([void *]);AC_GWX_DEFINE(MUNMAP_USES_VOIDP),
  AC_MSG_RESULT([char *]))
])

dnl GWX_IF_VAR_EQ (ENV_VAR, VALUE [, EQUALS_ACTION] [, ELSE_ACTION])
AC_DEFUN(GWX_IF_VAR_EQ,[
        case "$[$1]" in
        "[$2]"[)]
                [$3]
                ;;
        *[)]
                [$4]
                ;;
        esac
])

dnl GLIB_SYSDEFS (INCLUDES, DEFS_LIST, OFILE [, PREFIX])
AC_DEFUN(GLIB_SYSDEFS,
[glib_sysdefso="translit($3, [-_a-zA-Z0-9 *], [-_a-zA-Z0-9])"
glib_sysdef_msg=`echo $2 | sed 's/:[[^ 	]]*//g'`
if test "x`(echo '\n') 2>/dev/null`" != 'x\n'; then
  glib_nl='\\n'
else
  glib_nl='\n'
fi
AC_MSG_CHECKING(system definitions for $glib_sysdef_msg)
cat >confrun.c <<_______EOF
#include <stdio.h>
$1
int main (int c, char **v) {
  FILE *f = fopen ("$glib_sysdefso", "a");
  if (!f) return 1;
_______EOF
for glib_sysdef_input in $2 ; do
	glib_sysdef=`echo $glib_sysdef_input | sed 's/^\([[^:]]*\):.*$/\1/'`
	glib_default=`echo $glib_sysdef_input | sed 's/^[[^:]]*:\(.*\)$/\1/'`
	echo "#ifdef $glib_sysdef" >>confrun.c
	echo "  fprintf (f, \"#define GLIB_SYSDEF_%s %s%d${glib_nl}\", \"$glib_sysdef\", \"$4\", $glib_sysdef);" >>confrun.c
	echo "#else" >>confrun.c
	if test $glib_sysdef != $glib_default; then
		echo "  fprintf (f, \"#define GLIB_SYSDEF_%s %s%d${glib_nl}\", \"$glib_sysdef\", \"$4\", $glib_default);" >>confrun.c
	else
		echo "  fprintf (f, \"#define GLIB_SYSDEF_%s${glib_nl}\", \"$glib_sysdef\");" >>confrun.c
	fi
	echo "#endif" >>confrun.c
done
echo "return 0; }" >>confrun.c
AC_TRY_RUN(`cat confrun.c`, AC_MSG_RESULT(done),
[	for glib_sysdef_input in $2 ; do
		glib_sysdef=`echo $glib_sysdef_input | sed 's/^\([[^:]]*\):.*$/\1/'`
		glib_default=`echo $glib_sysdef_input | sed 's/^[[^:]]*:\(.*\)$/\1/'`
		if test $glib_sysdef != $glib_default; then
			glib_default=" $4$glib_default"
		else
			glib_default=
		fi
		echo "#define GLIB_SYSDEF_$glib_sysdef$glib_default" >>$glib_sysdefso
	done
	AC_MSG_RESULT(failed)])
rm -f confrun.c
])
dnl Like AC_TRY_EVAL but also errors out if the compiler generates
dnl _any_ output. Some compilers might issue warnings which we want
dnl to catch.
AC_DEFUN(AC_TRY_EVAL2,
[{ (eval echo configure:__oline__: \"[$]$1\") 1>&AC_FD_CC; dnl
(eval [$]$1) 2>&AC_FD_CC; _out=`eval [$]$1 2>&1` && test "x$_out" = x; }])

dnl Like AC_TRY_COMPILE but calls AC_TRY_EVAL2 instead of AC_TRY_EVAL
AC_DEFUN(AC_TRY_COMPILE2,
[cat > conftest.$ac_ext <<EOF
[#]line __oline__ "configure"
#include "confdefs.h"
[$1]
int main() {
[$2]
; return 0; }
EOF
if AC_TRY_EVAL2(ac_compile); then
  ifelse([$3], , :, [rm -rf conftest*
  $3])
else
  echo "configure: failed program was:" >&AC_FD_CC
  cat conftest.$ac_ext >&AC_FD_CC
ifelse([$4], , , [  rm -rf conftest*
  $4
])dnl
fi
rm -f conftest*])

dnl
dnl Figure out mutexes for this compiler/architecture.
dnl from Berkeley-DB 3.3.4 dist/aclocal/mutex.m4, hacked by jkj.
dnl

AC_DEFUN(AC_GWX_MUTEXES, [
AC_CACHE_CHECK([for mutexes], db_cv_mutex, [
db_cv_mutex=no

orig_libs=$LIBS

# User-specified POSIX mutexes.
#
# Assume that -lpthread exists when the user specifies POSIX mutexes.  (I
# only expect this option to be used on Solaris, which has -lpthread.)
if test "$db_cv_posixmutexes" = yes; then
	db_cv_mutex="posix_only"
fi

# User-specified UI mutexes.
#
# Assume that -lthread exists when the user specifies UI mutexes.  (I only
# expect this option to be used on Solaris, which has -lthread.)
if test "$db_cv_uimutexes" = yes; then
	db_cv_mutex="ui_only"
fi

# LWP threads: _lwp_XXX
#
# Test for LWP threads before testing for UI/POSIX threads, we prefer them
# on Solaris.  There are two reasons: the Solaris C library has UI/POSIX
# interface stubs, but they're broken, configuring them for inter-process
# mutexes doesn't return an error, but it doesn't work either.  Second,
# there's a bug in SunOS 5.7 where applications get pwrite, not pwrite64,
# if they load the C library before the appropriate threads library, e.g.,
# tclsh using dlopen to load the DB library.  Anyway, by using LWP threads
# we avoid answering lots of user questions, not to mention the bugs.
if test "$db_cv_mutex" = no; then
AC_TRY_RUN([
#include <synch.h>
main(){
	static lwp_mutex_t mi = SHAREDMUTEX;
	static lwp_cond_t ci = SHAREDCV;
	lwp_mutex_t mutex = mi;
	lwp_cond_t cond = ci;
	exit (
	_lwp_mutex_lock(&mutex) ||
	_lwp_mutex_unlock(&mutex));
}], [db_cv_mutex="Solaris/lwp"])
fi

# UI threads: thr_XXX
#
# Try with and without the -lthread library.
if test "$db_cv_mutex" = no -o "$db_cv_mutex" = "ui_only"; then
LIBS="-lthread $LIBS"
AC_TRY_RUN([
#include <thread.h>
#include <synch.h>
main(){
	mutex_t mutex;
	cond_t cond;
	int type = USYNC_PROCESS;
	exit (
	mutex_init(&mutex, type, NULL) ||
	cond_init(&cond, type, NULL) ||
	mutex_lock(&mutex) ||
	mutex_unlock(&mutex));
}], [db_cv_mutex="UI/threads/library"])
LIBS="$orig_libs"
fi
if test "$db_cv_mutex" = no -o "$db_cv_mutex" = "ui_only"; then
AC_TRY_RUN([
#include <thread.h>
#include <synch.h>
main(){
	mutex_t mutex;
	cond_t cond;
	int type = USYNC_PROCESS;
	exit (
	mutex_init(&mutex, type, NULL) ||
	cond_init(&cond, type, NULL) ||
	mutex_lock(&mutex) ||
	mutex_unlock(&mutex));
}], [db_cv_mutex="UI/threads"])
fi
if test "$db_cv_mutex" = "ui_only"; then
	AC_MSG_ERROR([unable to find UI mutex interfaces])
fi


# POSIX.1 pthreads: pthread_XXX
#
# Try with and without the -lpthread library.
if test "$db_cv_mutex" = no -o "$db_cv_mutex" = "posix_only"; then
AC_TRY_RUN([
#include <pthread.h>
main(){
	pthread_cond_t cond;
	pthread_mutex_t mutex;
	pthread_condattr_t condattr;
	pthread_mutexattr_t mutexattr;
	exit (
	pthread_condattr_init(&condattr) ||
	pthread_condattr_setpshared(&condattr, PTHREAD_PROCESS_SHARED) ||
	pthread_mutexattr_init(&mutexattr) ||
	pthread_mutexattr_setpshared(&mutexattr, PTHREAD_PROCESS_SHARED) ||
	pthread_cond_init(&cond, &condattr) ||
	pthread_mutex_init(&mutex, &mutexattr) ||
	pthread_mutex_lock(&mutex) ||
	pthread_mutex_unlock(&mutex) ||
	pthread_mutex_destroy(&mutex) ||
	pthread_cond_destroy(&cond) ||
	pthread_condattr_destroy(&condattr) ||
	pthread_mutexattr_destroy(&mutexattr));
}], [db_cv_mutex="POSIX/pthreads"])
fi
if test "$db_cv_mutex" = no -o "$db_cv_mutex" = "posix_only"; then
LIBS="-lpthread $LIBS"
AC_TRY_RUN([
#include <pthread.h>
main(){
	pthread_cond_t cond;
	pthread_mutex_t mutex;
	pthread_condattr_t condattr;
	pthread_mutexattr_t mutexattr;
	exit (
	pthread_condattr_init(&condattr) ||
	pthread_condattr_setpshared(&condattr, PTHREAD_PROCESS_SHARED) ||
	pthread_mutexattr_init(&mutexattr) ||
	pthread_mutexattr_setpshared(&mutexattr, PTHREAD_PROCESS_SHARED) ||
	pthread_cond_init(&cond, &condattr) ||
	pthread_mutex_init(&mutex, &mutexattr) ||
	pthread_mutex_lock(&mutex) ||
	pthread_mutex_unlock(&mutex) ||
	pthread_mutex_destroy(&mutex) ||
	pthread_cond_destroy(&cond) ||
	pthread_condattr_destroy(&condattr) ||
	pthread_mutexattr_destroy(&mutexattr));
}], [db_cv_mutex="POSIX/pthreads/library"])
LIBS="$orig_libs"
fi
if test "$db_cv_mutex" = "posix_only"; then
	AC_MSG_ERROR([unable to find POSIX mutex interfaces])
fi

# msemaphore: HPPA only
# Try HPPA before general msem test, it needs special alignment.
if test "$db_cv_mutex" = no; then
AC_TRY_RUN([
#include <sys/mman.h>
main(){
#if defined(__hppa)
	typedef msemaphore tsl_t;
	msemaphore x;
	msem_init(&x, 0);
	msem_lock(&x, 0);
	msem_unlock(&x, 0);
	exit(0);
#else
	exit(1);
#endif
}], [db_cv_mutex="HP/msem_init"])
fi

# msemaphore: AIX, OSF/1
if test "$db_cv_mutex" = no; then
AC_TRY_RUN([
#include <sys/types.h>
#include <sys/mman.h>;
main(){
	typedef msemaphore tsl_t;
	msemaphore x;
	msem_init(&x, 0);
	msem_lock(&x, 0);
	msem_unlock(&x, 0);
	exit(0);
}], [db_cv_mutex="UNIX/msem_init"])
fi

# ReliantUNIX
if test "$db_cv_mutex" = no; then
LIBS="$LIBS -lmproc"
AC_TRY_LINK([#include <ulocks.h>],
[typedef spinlock_t tsl_t;
spinlock_t x; initspin(&x, 1); cspinlock(&x); spinunlock(&x);],
[db_cv_mutex="ReliantUNIX/initspin"])
LIBS="$orig_libs"
fi

# SCO: UnixWare has threads in libthread, but OpenServer doesn't.
if test "$db_cv_mutex" = no; then
AC_TRY_RUN([
main(){
#if defined(__USLC__)
	exit(0);
#endif
	exit(1);
}], [db_cv_mutex="OpenUNIX/x86/cc-assembly"])
fi

# abilock_t: SGI
if test "$db_cv_mutex" = no; then
AC_TRY_LINK([#include <abi_mutex.h>],
[typedef abilock_t tsl_t;
abilock_t x; init_lock(&x); acquire_lock(&x); release_lock(&x);],
[db_cv_mutex="SGI/init_lock"])
fi

# sema_t: Solaris
# The sema_XXX calls do not work on Solaris 5.5.  I see no reason to ever
# turn this test on, unless we find some other platform that uses the old
# POSIX.1 interfaces.  (I plan to move directly to pthreads on Solaris.)
if test "$db_cv_mutex" = DOESNT_WORK; then
AC_TRY_LINK([#include <synch.h>],
[typedef sema_t tsl_t;
 sema_t x;
 sema_init(&x, 1, USYNC_PROCESS, NULL); sema_wait(&x); sema_post(&x);],
[db_cv_mutex="UNIX/sema_init"])
fi

# _lock_try/_lock_clear: Solaris
# On Solaris systems without Pthread or UI mutex interfaces, DB uses the
# undocumented _lock_try _lock_clear function calls instead of either the
# sema_trywait(3T) or sema_wait(3T) function calls.  This is because of
# problems in those interfaces in some releases of the Solaris C library.
if test "$db_cv_mutex" = no; then
AC_TRY_LINK([#include <sys/machlock.h>],
[typedef lock_t tsl_t;
 lock_t x;
 _lock_try(&x); _lock_clear(&x);],
[db_cv_mutex="Solaris/_lock_try"])
fi

# _check_lock/_clear_lock: AIX
if test "$db_cv_mutex" = no; then
AC_TRY_LINK([#include <sys/atomic_op.h>],
[int x; _check_lock(&x,0,1); _clear_lock(&x,0);],
[db_cv_mutex="AIX/_check_lock"])
fi

# Alpha/gcc: OSF/1
if test "$db_cv_mutex" = no; then
AC_TRY_RUN([main(){
#if defined(__alpha)
#if defined(__GNUC__)
exit(0);
#endif
#endif
exit(1);}],
[db_cv_mutex="ALPHA/gcc-assembly"])
fi

# PaRisc/gcc: HP/UX
if test "$db_cv_mutex" = no; then
AC_TRY_RUN([main(){
#if defined(__hppa)
#if defined(__GNUC__)
exit(0);
#endif
#endif
exit(1);}],
[db_cv_mutex="HPPA/gcc-assembly"])
fi

# PPC/gcc:
if test "$db_cv_mutex" = no; then
AC_TRY_RUN([main(){
#if defined(__powerpc__) || defined(__ppc__)
#if defined(__GNUC__)
exit(0);
#endif
#endif
exit(1);}],
[db_cv_mutex="PPC/gcc-assembly"])
fi

# Sparc/gcc: SunOS, Solaris
if test "$db_cv_mutex" = no; then
AC_TRY_RUN([main(){
#if defined(__sparc__)
#if defined(__GNUC__)
	exit(0);
#endif
#endif
	exit(1);
}], [db_cv_mutex="Sparc/gcc-assembly"])
fi

# 68K/gcc: SunOS
if test "$db_cv_mutex" = no; then
AC_TRY_RUN([main(){
#if (defined(mc68020) || defined(sun3))
#if defined(__GNUC__)
	exit(0);
#endif
#endif
	exit(1);
}], [db_cv_mutex="68K/gcc-assembly"])
fi

# x86/gcc: FreeBSD, NetBSD, BSD/OS, Linux
if test "$db_cv_mutex" = no; then
AC_TRY_RUN([main(){
#if defined(i386) || defined(__i386__)
#if defined(__GNUC__)
	exit(0);
#endif
#endif
	exit(1);
}], [db_cv_mutex="x86/gcc-assembly"])
fi

# ia86/gcc: Linux
if test "$db_cv_mutex" = no; then
AC_TRY_RUN([main(){
#if defined(__ia64)
#if defined(__GNUC__)
	exit(0);
#endif
#endif
	exit(1);
}], [db_cv_mutex="ia64/gcc-assembly"])
fi

# uts/cc: UTS
if test "$db_cv_mutex" = no; then
AC_TRY_RUN([main(){
#if defined(_UTS)
	exit(0);
#endif
	exit(1);
}], [db_cv_mutex="UTS/cc-assembly"])
fi
])

if test "$db_cv_mutex" = no; then
	AC_MSG_WARN(
	    [THREAD MUTEXES NOT AVAILABLE FOR THIS COMPILER/ARCHITECTURE.])
	DBXTRASRC="mut_fcntl.c $DBXTRASRC"
else
	AC_GWX_DEFINE(HAVE_MUTEX_THREADS)
fi

case "$db_cv_mutex" in
68K/gcc-assembly)	DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_68K_GCC_ASSEMBLY);;
AIX/_check_lock)	DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_AIX_CHECK_LOCK);;
ALPHA/gcc-assembly)	DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_ALPHA_GCC_ASSEMBLY);;
HP/msem_init)		DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_HPPA_MSEM_INIT);;
HPPA/gcc-assembly)	DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_HPPA_GCC_ASSEMBLY);;
ia64/gcc-assembly)	DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_IA64_GCC_ASSEMBLY);;
POSIX/pthreads)		DBXTRASRC="mut_pthread.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_PTHREADS);;
POSIX/pthreads/library)	LIBS="-lpthread $LIBS"
			DBXTRASRC="mut_pthread.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_PTHREADS);;
PPC/gcc-assembly)	DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_PPC_GCC_ASSEMBLY);;
ReliantUNIX/initspin)	LIBS="$LIBS -lmproc"
			DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_RELIANTUNIX_INITSPIN);;
OpenUNIX/x86/cc-assembly)	DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_SCO_X86_CC_ASSEMBLY);;
SGI/init_lock)		DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_SGI_INIT_LOCK);;
Solaris/_lock_try)	DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_SOLARIS_LOCK_TRY);;
Solaris/lwp)		DBXTRASRC="mut_pthread.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_SOLARIS_LWP);;
Sparc/gcc-assembly)	DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_SPARC_GCC_ASSEMBLY);;
UI/threads)		DBXTRASRC="mut_pthread.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_UI_THREADS);;
UI/threads/library)	LIBS="-lthread $LIBS"
			DBXTRASRC="mut_pthread.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_UI_THREADS);;
UNIX/msem_init)		DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_MSEM_INIT);;
UNIX/sema_init)		DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_SEMA_INIT);;
UTS/cc-assembly)	DBXTRASRC="$DBXTRASRC uts4.cc.s"
			AC_GWX_DEFINE(HAVE_MUTEX_UTS_CC_ASSEMBLY);;
x86/gcc-assembly)	DBXTRASRC="mut_tas.c $DBXTRASRC"
			AC_GWX_DEFINE(HAVE_MUTEX_X86_GCC_ASSEMBLY);;
esac])

# $Id: types.ac,v 11.6 2001/05/22 01:00:31 bostic Exp $

# Check for the standard system types.
AC_DEFUN(AM_TYPES, [

AC_TYPE_MODE_T
AC_TYPE_OFF_T
AC_TYPE_PID_T
AC_TYPE_SIZE_T

AC_SUBST(u_char_decl)
AC_CACHE_CHECK([for u_char], db_cv_uchar, [
AC_TRY_COMPILE([#include <sys/types.h>], u_char foo;,
	[db_cv_uchar=yes], [db_cv_uchar=no])])
if test "$db_cv_uchar" = no; then
	u_char_decl="typedef unsigned char u_char;"
fi

AC_SUBST(u_short_decl)
AC_CACHE_CHECK([for u_short], db_cv_ushort, [
AC_TRY_COMPILE([#include <sys/types.h>], u_short foo;,
	[db_cv_ushort=yes], [db_cv_ushort=no])])
if test "$db_cv_ushort" = no; then
	u_short_decl="typedef unsigned short u_short;"
fi

AC_SUBST(u_int_decl)
AC_CACHE_CHECK([for u_int], db_cv_uint, [
AC_TRY_COMPILE([#include <sys/types.h>], u_int foo;,
	[db_cv_uint=yes], [db_cv_uint=no])])
if test "$db_cv_uint" = no; then
	u_int_decl="typedef unsigned int u_int;"
fi

AC_SUBST(u_long_decl)
AC_CACHE_CHECK([for u_long], db_cv_ulong, [
AC_TRY_COMPILE([#include <sys/types.h>], u_long foo;,
	[db_cv_ulong=yes], [db_cv_ulong=no])])
if test "$db_cv_ulong" = no; then
	u_long_decl="typedef unsigned long u_long;"
fi

# DB/Vi use specific integer sizes.
AC_SUBST(int8_decl)
AC_CACHE_CHECK([for int8_t], db_cv_int8, [
AC_TRY_COMPILE([#include <sys/types.h>], int8_t foo;,
	[db_cv_int8=yes],
AC_TRY_RUN([main(){exit(sizeof(char) != 1);}],
	[db_cv_int8="char"], [db_cv_int8=no]))])
if test "$db_cv_int8" = no; then
	AC_MSG_ERROR(No signed 8-bit integral type.)
fi
if test "$db_cv_int8" != yes; then
	int8_decl="typedef $db_cv_int8 int8_t;"
fi

AC_SUBST(u_int8_decl)
AC_CACHE_CHECK([for u_int8_t], db_cv_uint8, [
AC_TRY_COMPILE([#include <sys/types.h>], u_int8_t foo;,
	[db_cv_uint8=yes],
AC_TRY_RUN([main(){exit(sizeof(unsigned char) != 1);}],
	[db_cv_uint8="unsigned char"], [db_cv_uint8=no]))])
if test "$db_cv_uint8" = no; then
	AC_MSG_ERROR(No unsigned 8-bit integral type.)
fi
if test "$db_cv_uint8" != yes; then
	u_int8_decl="typedef $db_cv_uint8 u_int8_t;"
fi

AC_SUBST(u_int16_decl)
AC_CACHE_CHECK([for u_int16_t], db_cv_uint16, [
AC_TRY_COMPILE([#include <sys/types.h>], u_int16_t foo;,
	[db_cv_uint16=yes],
AC_TRY_RUN([main(){exit(sizeof(unsigned short) != 2);}],
	[db_cv_uint16="unsigned short"],
AC_TRY_RUN([main(){exit(sizeof(unsigned int) != 2);}],
	[db_cv_uint16="unsigned int"], [db_cv_uint16=no])))])
if test "$db_cv_uint16" = no; then
	AC_MSG_ERROR([No unsigned 16-bit integral type.])
fi
if test "$db_cv_uint16" != yes; then
	u_int16_decl="typedef $db_cv_uint16 u_int16_t;"
fi

AC_SUBST(int16_decl)
AC_CACHE_CHECK([for int16_t], db_cv_int16, [
AC_TRY_COMPILE([#include <sys/types.h>], int16_t foo;,
	[db_cv_int16=yes],
AC_TRY_RUN([main(){exit(sizeof(short) != 2);}],
	[db_cv_int16="short"],
AC_TRY_RUN([main(){exit(sizeof(int) != 2);}],
	[db_cv_int16="int"], [db_cv_int16=no])))])
if test "$db_cv_int16" = no; then
	AC_MSG_ERROR([No signed 16-bit integral type.])
fi
if test "$db_cv_int16" != yes; then
	int16_decl="typedef $db_cv_int16 int16_t;"
fi

AC_SUBST(u_int32_decl)
AC_CACHE_CHECK([for u_int32_t], db_cv_uint32, [
AC_TRY_COMPILE([#include <sys/types.h>], u_int32_t foo;,
	[db_cv_uint32=yes],
AC_TRY_RUN([main(){exit(sizeof(unsigned int) != 4);}],
	[db_cv_uint32="unsigned int"],
AC_TRY_RUN([main(){exit(sizeof(unsigned long) != 4);}],
	[db_cv_uint32="unsigned long"], [db_cv_uint32=no])))])
if test "$db_cv_uint32" = no; then
	AC_MSG_ERROR([No unsigned 32-bit integral type.])
fi
if test "$db_cv_uint32" != yes; then
	u_int32_decl="typedef $db_cv_uint32 u_int32_t;"
fi

AC_SUBST(int32_decl)
AC_CACHE_CHECK([for int32_t], db_cv_int32, [
AC_TRY_COMPILE([#include <sys/types.h>], int32_t foo;,
	[db_cv_int32=yes],
AC_TRY_RUN([main(){exit(sizeof(int) != 4);}],
	[db_cv_int32="int"],
AC_TRY_RUN([main(){exit(sizeof(long) != 4);}],
	[db_cv_int32="long"], [db_cv_int32=no])))])
if test "$db_cv_int32" = no; then
	AC_MSG_ERROR([No signed 32-bit integral type.])
fi
if test "$db_cv_int32" != yes; then
	int32_decl="typedef $db_cv_int32 int32_t;"
fi

# Check for ssize_t -- if none exists, find a signed integral type that's
# the same size as a size_t.  Prefer int over long, because it read/write
# and others historically returned an int.
AC_SUBST(ssize_t_decl)
AC_CACHE_CHECK([for ssize_t], db_cv_ssize_t, [
AC_TRY_COMPILE([#include <sys/types.h>], ssize_t foo;,
	[db_cv_ssize_t=yes],
AC_TRY_RUN([
	#include <sys/types.h>
	main(){exit(sizeof(size_t) != sizeof(int));}],
	[db_cv_ssize_t="int"],
AC_TRY_RUN([
	#include <sys/types.h>
	main(){exit(sizeof(size_t) != sizeof(long long));}],
	[db_cv_ssize_t="long long"],
AC_TRY_RUN([
	#include <sys/types.h>
	main(){exit(sizeof(size_t) != sizeof(long));}],
	[db_cv_ssize_t="long"], [db_cv_ssize_t="int"]))))])
if test "$db_cv_ssize_t" != yes; then
	ssize_t_decl="typedef $db_cv_ssize_t ssize_t;"
fi

# Find the largest integral type.
AC_SUBST(db_align_t_decl)
AC_CACHE_CHECK([for largest integral type], db_cv_align_t, [
AC_TRY_COMPILE([#include <sys/types.h>], long long foo;,
	[db_cv_align_t="unsigned long long"], [db_cv_align_t="unsigned long"])])
db_align_t_decl="typedef $db_cv_align_t db_align_t;"

# Find the integral type which is the same size as a pointer.
AC_SUBST(db_alignp_t_decl)
AC_CACHE_CHECK([for integral type equal to pointer size], db_cv_alignp_t, [
db_cv_alignp_t=$db_cv_align_t
AC_TRY_RUN([main(){exit(sizeof(unsigned int) != sizeof(char *));}],
	[db_cv_alignp_t="unsigned int"])
AC_TRY_RUN([main(){exit(sizeof(unsigned long) != sizeof(char *));}],
	[db_cv_alignp_t="unsigned long"])
AC_TRY_RUN([main(){exit(sizeof(unsigned long long) != sizeof(char *));}],
	[db_cv_alignp_t="unsigned long long"])])
db_alignp_t_decl="typedef $db_cv_alignp_t db_alignp_t;"

])

# C++ checks to determine what style of headers to use and
# whether to use "using" clauses.

AC_DEFUN(AC_CXX_HAVE_STDHEADERS, [
AC_SUBST(cxx_have_stdheaders)
AC_CACHE_CHECK([whether C++ supports the ISO C++ standard includes],
db_cv_cxx_have_stdheaders,
[AC_LANG_SAVE
 AC_LANG_CPLUSPLUS
 AC_TRY_COMPILE([#include <iostream>
],[return 0;],
 db_cv_cxx_have_stdheaders=yes, db_cv_cxx_have_stdheaders=no)
 AC_LANG_RESTORE
])
if test "$db_cv_cxx_have_stdheaders" = yes; then
	cxx_have_stdheaders="#define	HAVE_CXX_STDHEADERS 1"
fi])

dnl ====================================================================
dnl check if hard links are supported.
dnl
AC_DEFUN([AC_PROG_LN_H], [# test for ln hardlink support
AC_MSG_CHECKING(whether ln works)
AC_CACHE_VAL(ac_cv_prog_LN_H,
[rm -f conftest.src conftest.dst
echo "conftest" > conftest.src
if ln conftest.src conftest.dst 2>/dev/null
then
  ac_cv_prog_LN_H="ln"
else
  ac_cv_prog_LN_H="cp"
fi
rm -f conftest.src conftest.dst
])dnl
LN_H="$ac_cv_prog_LN_H"
if test "$ac_cv_prog_LN_H" = "ln"; then
	AC_MSG_RESULT(yes)
else
	AC_MSG_RESULT(no)
fi
AC_SUBST(LN_H)dnl
])dnl

## Portability defines that help interoperate with classic and modern autoconfs
ifdef([AC_TR_SH],[
define([GLIB_TR_SH],[AC_TR_SH([$1])])
define([GLIB_TR_CPP],[AC_TR_CPP([$1])])
], [
define([GLIB_TR_SH],
       [patsubst(translit([[$1]], [*+], [pp]), [[^a-zA-Z0-9_]], [_])])
define([GLIB_TR_CPP],
       [patsubst(translit([[$1]],
  	                  [*abcdefghijklmnopqrstuvwxyz],
 			  [PABCDEFGHIJKLMNOPQRSTUVWXYZ]),
		 [[^A-Z0-9_]], [_])])
])

# GLIB_CHECK_COMPILE_WARNINGS(PROGRAM, [ACTION-IF-FOUND], [ACTION-IF-NOT-FOUND])
# ---------------------------------------------------------------------
# Try to compile PROGRAM, check for warnings
m4_define([GLIB_CHECK_COMPILE_WARNINGS],
[m4_ifvaln([$1], [AC_LANG_CONFTEST([$1])])dnl
rm -f conftest.$ac_objext
glib_ac_compile_save="$ac_compile"
ac_compile='$CC -c $CFLAGS $CPPFLAGS conftest.$ac_ext'
AS_IF([_AC_EVAL_STDERR($ac_compile) &&
         AC_TRY_COMMAND([(if test -s conftest.err; then false ; else true; fi)])],
      [$2],
      [echo "$as_me: failed program was:" >&AS_MESSAGE_LOG_FD
cat conftest.$ac_ext >&AS_MESSAGE_LOG_FD
m4_ifvaln([$3],[$3])dnl])dnl
ac_compile="$glib_ac_compile_save"
rm -f conftest.$ac_objext conftest.err m4_ifval([$1], [conftest.$ac_ext])[]dnl
])# GLIB_CHECK_COMPILE_WARNINGS

dnl GWX_SIZEOF (INCLUDES, TYPE, ALIAS [, CROSS-SIZE])
AC_DEFUN(GWX_SIZEOF,
[pushdef([glib_Sizeof], GLIB_TR_SH([glib_cv_sizeof_$3]))dnl
AC_CACHE_CHECK([size of $2], glib_Sizeof,
[AC_TRY_RUN([#include <stdio.h>
#if STDC_HEADERS
#include <stdlib.h>
#include <stddef.h>
#endif
$1
main()
{
  FILE *f=fopen("conftestval", "w");
  if (!f) exit(1);
  fprintf(f, "%d\n", sizeof($2));
  exit(0);
}], 
  [glib_Sizeof=`cat conftestval`  dnl''
],
  [glib_Sizeof=0],
  ifelse([$4], [], [], [glib_Sizeof=$4]))])
AC_GWX_DEFINE_UNQUOTED(GLIB_TR_CPP(glib_sizeof_$3), [$[]glib_Sizeof], [Size of $3])
popdef([glib_Sizeof])dnl
])

dnl @synopsis AC_FUNC_VSNPRINTF_UNIX95
dnl
dnl Check whether there is a vsnprintf() function with UNIX95 semantics.
dnl
AC_DEFUN([AC_FUNC_VSNPRINTF_UNIX95],
[AC_CACHE_CHECK(for UNIX95 vsnprintf,
  ac_cv_func_vsnprintf_unix95,
[AC_TRY_RUN(
[#include <stdio.h>
#include <stdarg.h>

int
doit(char * s, ...)
{
  char buffer[32];
  va_list args;
  int r;

  va_start(args, s);
  r = vsnprintf(buffer, 5, s, args);
  va_end(args);

  if (r == -1)
    exit(0);

  exit(1);
}

int
main(void)
{
  doit("1234567");
  exit(1);
}], ac_cv_func_vsnprintf_unix95=yes, ac_cv_func_vsnprintf_unix95=no, ac_cv_func_vsnprintf_unix95=yes)])
if test $ac_cv_func_vsnprintf_unix95 = yes; then
  AC_GWX_DEFINE(HAVE_UNIX95_VSNPRINTF, 1,
            [Define if you have a version of the vsnprintf function
             with semantics as specified by the UNIX95 standard.])
fi
])dnl End AC_FUNC_VSNPRINTF_UNIX95

dnl GWX_BYTE_CONTENTS (INCLUDES, TYPE, ALIAS, N_BYTES, INITIALIZER)
AC_DEFUN(GWX_BYTE_CONTENTS,
[pushdef([glib_ByteContents], GLIB_TR_SH([glib_cv_byte_contents_$3]))dnl
AC_CACHE_CHECK([byte contents of $5], glib_ByteContents,
[AC_TRY_RUN([#include <stdio.h>
$1
main()
{
  static $2 tv = $5;
  char *p = (char*) &tv;
  int i;
  FILE *f=fopen("conftestval", "w");
  if (!f) exit(1);
  for (i = 0; i < $4; i++)
    fprintf(f, "%s%d", i?",":"", *(p++));
  fprintf(f, "\n");
  exit(0);
}], 
   [glib_ByteContents=`cat conftestval`  dnl''
], 
   [glib_ByteContents=no],
   [glib_ByteContents=no])])
AC_DEFINE_UNQUOTED(GLIB_TR_CPP(glib_byte_contents_$3), [$[]glib_ByteContents],
	[Byte contents of $3])
popdef([glib_ByteContents])dnl
])

AC_DEFUN(AC_CPP_ACCEPT_IDL,
	[AC_CACHE_CHECK([if C preprocessor likes IDL],
		ac_cv_cpp_accept_idl,
		[AC_TRY_CPP([
			#pragma prefix "foo.org"
			module FOO {
				typedef unsigned long long big;
				interface BAR {
					readonly attribute big number;
				};
			};
		],
		ac_cv_cpp_accept_idl=yes,
		ac_cv_cpp_accept_idl=no)])])

AC_DEFUN(AC_CPP_PIPE_STDIN,
	[AC_CACHE_CHECK([if C preprocessor can read from stdin],
		ac_cv_cpp_pipe_stdin,
		[AC_REQUIRE_CPP
		if echo | $CPP - 2>/dev/null 1>&2 ; then
			ac_cv_cpp_pipe_stdin=yes
		else
			ac_cv_cpp_pipe_stdin=no
		fi])])

AC_DEFUN(AC_CPP_NOSTDINC,
       [AC_CACHE_CHECK([how to ignore standard include path],
               ac_cv_cpp_nostdinc,
               [case "$CC" in
	       	*gcc*) ac_cv_cpp_nostdinc="-nostdinc" ;;
       		  *)   saved_CPPFLAGS="$CPPFLAGS"
	               CPPFLAGS="$CPPFLAGS -I-"
        	       AC_TRY_CPP(,ac_cv_cpp_nostdinc=-I-,
                	       [CPPFLAGS="$saved_CPPFLAGS -I"
                       	AC_TRY_CPP(,ac_cv_cpp_nostdinc=-I,)])
               		CPPFLAGS="$saved_CPPFLAGS" ;;
		esac
	       ])
	])

dnl AM_GLIB_PATH_PROG_WITH_TEST(VARIABLE, PROG-TO-CHECK-FOR,
dnl   TEST-PERFORMED-ON-FOUND_PROGRAM [, VALUE-IF-NOT-FOUND [, PATH]])
AC_DEFUN([AM_GLIB_PATH_PROG_WITH_TEST],
[# Extract the first word of "$2", so it can be a program name with args.
set dummy $2; ac_word=[$]2
AC_MSG_CHECKING([for $ac_word])
AC_CACHE_VAL(ac_cv_path_$1,
[case "[$]$1" in
  /*)
  ac_cv_path_$1="[$]$1" # Let the user override the test with a path.
  ;;
  *)
  IFS="${IFS= 	}"; ac_save_ifs="$IFS"; IFS="${IFS}:"
  for ac_dir in ifelse([$5], , $PATH, [$5]); do
    test -z "$ac_dir" && ac_dir=.
    if test -f $ac_dir/$ac_word; then
      if [$3]; then
	ac_cv_path_$1="$ac_dir/$ac_word"
	break
      fi
    fi
  done
  IFS="$ac_save_ifs"
dnl If no 4th arg is given, leave the cache variable unset,
dnl so AC_PATH_PROGS will keep looking.
ifelse([$4], , , [  test -z "[$]ac_cv_path_$1" && ac_cv_path_$1="$4"
])dnl
  ;;
esac])dnl
$1="$ac_cv_path_$1"
if test ifelse([$4], , [-n "[$]$1"], ["[$]$1" != "$4"]); then
  AC_MSG_RESULT([$]$1)
else
  AC_MSG_RESULT(no)
fi
AC_SUBST($1)dnl
])

dnl
dnl Handle all I18N stuff. This is majorly hacked from the gettext
dnl code, from Ulrich Drepper <drepper@cygnus.com>, 1995, 1996
dnl
dnl The most significant change is we check for -lgnuintl first,
dnl before -lintl. It is extremely unfortunate thats what the gettext
dnl folks decided to call it, as SCO and other systems have a system
dnl -lintl, and this clashes. So at least on SCO, I make sure its called
dnl -lgnuintl. This may be a slefish check right now but hopefully I
dnl can persuade the Linux folks to call it something else. It can be
dnl done without breaking backwards compatibility.
dnl
dnl We also dont set LIBS directly. For the purposes of GWXLIBS, not
dnl everything needs it. So we set a variable called I18NLIBS, and the
dnl makefiles that need it can add it.
dnl
AC_DEFUN(GWX_I18N,[
  GWXI18N=no
  AC_REQUIRE([AC_PROG_MAKE_SET])dnl
  AC_REQUIRE([AC_PROG_CC])dnl
  AC_REQUIRE([AC_CANONICAL_HOST])dnl
  AC_REQUIRE([AC_PROG_RANLIB])dnl
  AC_REQUIRE([AC_ISC_POSIX])dnl
  AC_REQUIRE([AC_HEADER_STDC])dnl
  AC_REQUIRE([AC_C_CONST])dnl
  AC_REQUIRE([AC_C_INLINE])dnl
  AC_REQUIRE([AC_TYPE_OFF_T])dnl
  AC_REQUIRE([AC_TYPE_SIZE_T])dnl
  AC_REQUIRE([AC_FUNC_ALLOCA])dnl
  AC_REQUIRE([GWX_FUNC_MMAP])dnl
  AC_REQUIRE([GWX_INTDIV0])dnl
  AC_REQUIRE([GWX_TYPE_UINTMAX_T])dnl
  AC_REQUIRE([GWX_HEADER_INTTYPES_H])dnl
  AC_REQUIRE([GWX_INTTYPES_PRI])dnl

  i18nsave_LIBS="$LIBS"

   AC_CHECK_HEADERS(\
argz.h \
limits.h \
locale.h \
nl_types.h \
malloc.h \
stddef.h \
stdlib.h \
string.h \
unistd.h \
sys/param.h)

   AC_CHECK_FUNCS(\
feof_unlocked \
fgets_unlocked \
getc_unlocked \
getcwd \
getegid \
geteuid \
getgid \
getuid \
mempcpy \
munmap \
putenv \
setenv \
setlocale \
stpcpy \
strchr \
strcasecmp \
strdup \
strtoul \
tsearch \
__argz_count \
__argz_stringify \
__argz_next \
__fsetlocking)

  dnl Figure out what method
  nls_cv_force_use_gnu_gettext="no"

  nls_cv_use_gnu_gettext="$nls_cv_force_use_gnu_gettext"
  if test "$nls_cv_force_use_gnu_gettext" != "yes"; then
    dnl User does not insist on using GNU NLS library.  Figure out what
    dnl to use.  If gettext or catgets are available (in this order) we
    dnl use this.  Else we have to fall back to GNU NLS library.
    dnl catgets is only used if permitted by option --with-catgets.
    nls_cv_header_intl=
    nls_cv_header_libgt=
    CATOBJEXT=NONE
    XGETTEXT=:

    AC_CHECK_HEADER(libintl.h,[
      AC_CACHE_CHECK([for dgettext in libc], gt_cv_func_dgettext_libc,[
        AC_TRY_LINK([#include <libintl.h>], [return (int) dgettext ("","")],
          gt_cv_func_dgettext_libc=yes, gt_cv_func_dgettext_libc=no)])

      gt_cv_func_dgettext_libgnuintl="no"
      libintl_extra_libs=""

      if test "$gt_cv_func_dgettext_libc" != "yes" ; then
        AC_CHECK_LIB(gnuintl, bindtextdomain,[
          AC_CHECK_LIB(gnuintl, dgettext, gt_cv_func_dgettext_libgnuintl=yes)])

        if test "$gt_cv_func_dgettext_libc" != "yes" ; then
          AC_MSG_CHECKING([if -liconv is needed to use gettext])
          AC_MSG_RESULT([])
          AC_CHECK_LIB(gnuintl, dcgettext,[
	    gt_cv_func_dgettext_libgnuintl=yes
            libintl_extra_libs=-liconv],:,-liconv)
        fi
      fi

      dnl Do it all again, checking for -lintl now.
      if test "$gt_cv_func_dgettext_libgnuintl" = "no"; then
        gt_cv_func_dgettext_libintl="no"
        libintl_extra_libs=""

        if test "$gt_cv_func_dgettext_libc" != "yes" ; then
          AC_CHECK_LIB(intl, bindtextdomain,[
            AC_CHECK_LIB(intl, dgettext, gt_cv_func_dgettext_libintl=yes)])

          if test "$gt_cv_func_dgettext_libc" != "yes" ; then
            AC_MSG_CHECKING([if -liconv is needed to use gettext])
            AC_MSG_RESULT([])
            AC_CHECK_LIB(intl, dcgettext,[
	      gt_cv_func_dgettext_libintl=yes
              libintl_extra_libs=-liconv],:,-liconv)
          fi
        fi
      fi

      if test "$gt_cv_func_dgettext_libgnuintl" = "yes"; then
        I18NLIBS="-lgnuintl $libintl_extra_libs";
      elif test "$gt_cv_func_dgettext_libintl" = "yes"; then
        I18NLIBS="-lintl $libintl_extra_libs";
      fi

      LIBS="$LIBS $I18NLIBS"

      if test "$gt_cv_func_dgettext_libc" = "yes" \
        || test "$gt_cv_func_dgettext_libgnuintl" = "yes" \
        || test "$gt_cv_func_dgettext_libintl" = "yes"; then
        GWXI18N=yes
        AC_GWX_DEFINE(HAVE_GETTEXT,1,[Define if the GNU gettext() function is already present or preinstalled.])
        AM_GLIB_PATH_PROG_WITH_TEST(MSGFMT, msgfmt,[
          test -z "`$ac_dir/$ac_word -h 2>&1 | grep 'dv '`"], no)dnl
        if test "$MSGFMT" != "no"; then
          AC_CHECK_FUNCS(dcgettext)
          AC_PATH_PROG(GMSGFMT, gmsgfmt, $MSGFMT)
          AC_PATH_PROG(MSGMERGE, msgmerge, :)
          AM_GLIB_PATH_PROG_WITH_TEST(XGETTEXT, xgettext,[
            test -z "`$ac_dir/$ac_word -h 2>&1 | grep '(HELP)'`"], :)
          AC_TRY_LINK(, [extern int _nl_msg_cat_cntr;
            return _nl_msg_cat_cntr],[
            CATOBJEXT=.gmo
            DATADIRNAME=share],[
            CATOBJEXT=.mo
            DATADIRNAME=lib])
          INSTOBJEXT=.mo
        fi
      fi
    ])

    if test "$CATOBJEXT" = "NONE"; then
      dnl Neither gettext nor catgets in included in the C library.
      dnl Fall back on GNU gettext library.
      nls_cv_use_gnu_gettext=yes
    fi
  fi

  if test "$nls_cv_use_gnu_gettext" != "yes"; then
    AC_GWX_DEFINE(ENABLE_NLS, 1, [defined to indicate that i18n is enabled])
  else
    dnl Unset this variable since we use the non-zero value as a flag.
    CATOBJEXT=
  fi

  dnl Test whether we really found GNU xgettext.
  if test "$XGETTEXT" != ":"; then
    dnl If it is not GNU xgettext we define it as : so that the
    dnl Makefiles still can work.
    if $XGETTEXT --omit-header /dev/null 2> /dev/null; then
      : ;
    else
      AC_MSG_RESULT([found xgettext program is not GNU xgettext; ignore it])
      XGETTEXT=":"
    fi
  fi

  dnl A big change from the original code. We dont process Makefike.ins
  dnl and we dont mess with LINGUAS. It is up to each package that
  dnl uses I18N to do this correctly.

  dnl Make all variables we use known to autoconf.
  AC_SUBST(CATOBJEXT)
  AC_SUBST(DATADIRNAME)
  AC_SUBST(INSTOBJEXT)
  AC_SUBST(I18NLIBS)
  if test "x$with_localedir" = "x"; then
    localedir="${prefix}/$DATADIRNAME/locale"
  fi
  LIBS="$i18nsave_LIBS"
]) dnl End of GWX_I18N

AC_DEFUN(GWX_GTK1_GLIBCONFIG,[
  AC_CONFIG_COMMANDS(gtk+/glib/glibconfig.h,[
	echo "$as_me: creating gtk+/glib/glibconfig.h"
	outfile=glibconfig.h-tmp
	cat > $outfile <<\_______EOF
/* glibconfig.h
 *
 * This is a generated file.  Please modify `configure.in'
 */

#ifndef GLIBCONFIG_H
#define GLIBCONFIG_H

_______EOF

	if test x$glib_limits_h = xyes; then
	  echo '#include <limits.h>' >> $outfile
	fi
	if test x$glib_float_h = xyes; then
	  echo '#include <float.h>' >> $outfile
	fi
	if test x$glib_values_h = xyes; then
	  echo '#include <values.h>' >> $outfile
	fi
	if test x$g_mutex_header_file != x; then
	  echo '#include <'"$g_mutex_header_file"'>' >> $outfile
	fi
	if test x$glib_sys_poll_h = xyes; then
	  echo '#define GLIB_HAVE_SYS_POLL_H' >> $outfile
	fi

	cat >> $outfile <<_______EOF

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define G_MINFLOAT	$glib_mf
#define G_MAXFLOAT	$glib_Mf
#define G_MINDOUBLE	$glib_md
#define G_MAXDOUBLE	$glib_Md
#define G_MINSHORT	$glib_ms
#define G_MAXSHORT	$glib_Ms
#define G_MININT	$glib_mi
#define G_MAXINT	$glib_Mi
#define G_MINLONG	$glib_ml
#define G_MAXLONG	$glib_Ml

_______EOF


	### this should always be true in a modern C/C++ compiler
	cat >>$outfile <<_______EOF
typedef signed char gint8;
typedef unsigned char guint8;
_______EOF


	if test -n "$gint16"; then
	  cat >>$outfile <<_______EOF
typedef signed $gint16 gint16;
typedef unsigned $gint16 guint16;
_______EOF
	fi


	if test -n "$gint32"; then
	  cat >>$outfile <<_______EOF
typedef signed $gint32 gint32;
typedef unsigned $gint32 guint32;
_______EOF
	fi


	if test -n "$gint64"; then
	  cat >>$outfile <<_______EOF
${glib_warning_guard}#define G_HAVE_GINT64 1

${glib_extension}typedef signed $gint64 gint64;
${glib_extension}typedef unsigned $gint64 guint64;

#define G_GINT64_CONSTANT(val)	$gint64_constant
_______EOF
	fi


	if test -z "$glib_unknown_void_p"; then
	  cat >>$outfile <<_______EOF

#define GPOINTER_TO_INT(p)	((gint)  ${glib_gpi_cast} (p))
#define GPOINTER_TO_UINT(p)	((guint) ${glib_gpui_cast} (p))

#define GINT_TO_POINTER(i)	((gpointer) ${glib_gpi_cast} (i))
#define GUINT_TO_POINTER(u)	((gpointer) ${glib_gpui_cast} (u))
_______EOF
	else
	  echo '#error SIZEOF_VOID_P unknown - This should never happen' >>$outfile
	fi



	cat >>$outfile <<_______EOF
$glib_atexit
$glib_memmove
$glib_defines

$glib_vacopy

#ifdef	__cplusplus
#define	G_HAVE_INLINE	1
#else	/* !__cplusplus */
$glib_inline
#endif	/* !__cplusplus */
_______EOF

	echo >>$outfile
	if test x$g_mutex_has_default = xyes; then
		cat >>$outfile <<_______EOF
$g_enable_threads_def G_THREADS_ENABLED
#define G_THREADS_IMPL_$g_threads_impl_def
typedef struct _GStaticMutex GStaticMutex;
struct _GStaticMutex
{
  struct _GMutex *runtime_mutex;
  union {
    char   pad[$g_mutex_sizeof];
    double dummy_double;
    void  *dummy_pointer;
    long   dummy_long;
  } aligned_pad_u;
};
#define	G_STATIC_MUTEX_INIT	{ NULL, { { $g_mutex_contents} } }
#define	g_static_mutex_get_mutex(mutex) \
  (g_thread_use_default_impl ? ((GMutex*) &((mutex)->aligned_pad_u)) : \
   g_static_mutex_get_mutex_impl (&((mutex)->runtime_mutex)))
_______EOF
	else
		cat >>$outfile <<_______EOF
$g_enable_threads_def G_THREADS_ENABLED
#define G_THREADS_IMPL_$g_threads_impl_def
typedef struct _GMutex* GStaticMutex;
#define G_STATIC_MUTEX_INIT NULL
#define g_static_mutex_get_mutex(mutex) (g_static_mutex_get_mutex_impl (mutex))
_______EOF
	fi

	echo >>$outfile
	g_bit_sizes="16 32"
	if test -n "$gint64"; then
	  g_bit_sizes="$g_bit_sizes 64"
	fi
	for bits in $g_bit_sizes; do
	  cat >>$outfile <<_______EOF
#define GINT${bits}_TO_${g_bs_native}(val)	((gint${bits}) (val))
#define GUINT${bits}_TO_${g_bs_native}(val)	((guint${bits}) (val))
#define GINT${bits}_TO_${g_bs_alien}(val)	((gint${bits}) GUINT${bits}_SWAP_LE_BE (val))
#define GUINT${bits}_TO_${g_bs_alien}(val)	(GUINT${bits}_SWAP_LE_BE (val))
_______EOF
	done

	cat >>$outfile <<_______EOF
#define GLONG_TO_LE(val)	((glong) GINT${glongbits}_TO_LE (val))
#define GULONG_TO_LE(val)	((gulong) GUINT${glongbits}_TO_LE (val))
#define GLONG_TO_BE(val)	((glong) GINT${glongbits}_TO_BE (val))
#define GULONG_TO_BE(val)	((gulong) GUINT${glongbits}_TO_BE (val))
#define GINT_TO_LE(val)		((gint) GINT${gintbits}_TO_LE (val))
#define GUINT_TO_LE(val)	((guint) GUINT${gintbits}_TO_LE (val))
#define GINT_TO_BE(val)		((gint) GINT${gintbits}_TO_BE (val))
#define GUINT_TO_BE(val)	((guint) GUINT${gintbits}_TO_BE (val))
#define G_BYTE_ORDER $g_byte_order

_______EOF

	if test -r glibconfig-sysdefs.h; then
	  cat glibconfig-sysdefs.h >>$outfile
	fi


	cat >>$outfile <<_______EOF

$glib_wc


#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* GLIBCONFIG_H */
_______EOF


	if cmp -s $outfile gtk+/glib/glibconfig.h; then
	  echo "$as_me: gtk+/glib/glibconfig.h is unchanged"
	  rm -f $outfile
	else
	  mv $outfile gtk+/glib/glibconfig.h
	fi
    ],[
case xyes in
x$ac_cv_header_float_h)
  glib_float_h=yes
  glib_mf=FLT_MIN glib_Mf=FLT_MAX
  glib_md=DBL_MIN glib_Md=DBL_MAX
  ;;
x$ac_cv_header_values_h)
  glib_values_h=yes
  glib_mf=MINFLOAT  glib_Mf=MAXFLOAT
  glib_md=MINDOUBLE glib_Md=MAXDOUBLE
  ;;
esac

case xyes in
x$ac_cv_header_limits_h)
  glib_limits_h=yes
  glib_ms=SHRT_MIN glib_Ms=SHRT_MAX
  glib_mi=INT_MIN  glib_Mi=INT_MAX
  glib_ml=LONG_MIN glib_Ml=LONG_MAX
  ;;
x$ac_cv_header_values_h)
  glib_values_h=yes
  glib_ms=MINSHORT glib_Ms=MAXSHORT
  glib_mi=MININT   glib_Mi=MAXINT
  glib_ml=MINLONG  glib_Ml=MAXLONG
  ;;
esac

if test x$ac_cv_header_sys_poll_h = xyes ; then
  glib_sys_poll_h=yes
fi

case 2 in
$ac_cv_sizeof_short)		gint16=short;;
$ac_cv_sizeof_int)		gint16=int;;
esac
case 4 in
$ac_cv_sizeof_short)		gint32=short;;
$ac_cv_sizeof_int)		gint32=int;;
$ac_cv_sizeof_long)		gint32=long;;
esac
case 8 in
$ac_cv_sizeof_int)
  gint64=int
  glib_extension=
  glib_warning_guard=
  gint64_constant='(val)'
  ;;
$ac_cv_sizeof_long)
  gint64=long
  glib_extension=
  glib_warning_guard=
  gint64_constant='(val##L)'
  ;;
$ac_cv_sizeof_long_long)
  gint64='long long'
  glib_extension='G_GNUC_EXTENSION '
  glib_warning_guard="
#if defined (__GNUC__) && (__GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 8))
#  define G_GNUC_EXTENSION __extension__
#else
#  define G_GNUC_EXTENSION
#endif

"
  gint64_constant='(G_GNUC_EXTENSION (val##LL))'
  ;;
esac

gintbits=`expr $ac_cv_sizeof_int \* 8`
glongbits=`expr $ac_cv_sizeof_long \* 8`


case $ac_cv_sizeof_void_p in
$ac_cv_sizeof_int)  	glib_gpi_cast=''        glib_gpui_cast=''         ;;
$ac_cv_sizeof_long) 	glib_gpi_cast='(glong)' glib_gpui_cast='(gulong)' ;;
*) 			glib_unknown_void_p=yes ;;
esac


case xyes in
x$ac_cv_func_atexit)
  glib_atexit="
#ifdef NeXT /* @#%@! NeXTStep */
# define g_ATEXIT(proc)	(!atexit (proc))
#else
# define g_ATEXIT(proc)	(atexit (proc))
#endif"
  ;;
x$ac_cv_func_on_exit)
  glib_atexit="
#define g_ATEXIT(proc)	(on_exit ((void (*)(int, void*))(proc), NULL))"
  ;;
esac

case xyes in
x$ac_cv_func_memmove)
  glib_memmove='
#define g_memmove(d,s,n) G_STMT_START { memmove ((d), (s), (n)); } G_STMT_END'
  ;;
*)
  glib_memmove="
/* We make the assumption that if memmove isn't available, then
 * bcopy will do the job. This isn't safe everywhere. (bcopy can't
 * necessarily handle overlapping copies) */
#define g_memmove(d,s,n) G_STMT_START { bcopy ((s), (d), (n)); } G_STMT_END"
  ;;
esac

glib_defines="
#define GLIB_MAJOR_VERSION $GLIB1_MAJOR_VERSION
#define GLIB_MINOR_VERSION $GLIB1_MINOR_VERSION
#define GLIB_MICRO_VERSION $GLIB1_MICRO_VERSION
"

case xyes in
x$glib_cv_va_copy)	glib_vacopy='#define G_VA_COPY	va_copy' ;;
x$glib_cv___va_copy)	glib_vacopy='#define G_VA_COPY	__va_copy' ;;
*)			glib_vacopy=''
esac

if test x$glib_cv_va_val_copy = xno; then
  glib_vacopy="\$glib_vacopy
#define G_VA_COPY_AS_ARRAY 1"
fi

if test x$glib_cv_hasinline = xyes; then
    glib_inline='#define G_HAVE_INLINE 1'
fi
if test x$glib_cv_has__inline = xyes; then
    glib_inline="\$glib_inline
#define G_HAVE___INLINE 1"
fi
if test x$glib_cv_has__inline__ = xyes; then
    glib_inline="\$glib_inline
#define G_HAVE___INLINE__ 1"
fi

case xyes in
x$ac_cv_c_bigendian)
  g_byte_order=G_BIG_ENDIAN
  g_bs_native=BE
  g_bs_alien=LE
  ;;
*)
  g_byte_order=G_LITTLE_ENDIAN
  g_bs_native=LE
  g_bs_alien=BE
  ;;
esac

if test x$glib_wchar_h = xyes; then
  glib_wc='
#define G_HAVE_WCHAR_H 1'
fi
if test x$glib_wctype_h = xyes; then
  glib_wc="\$glib_wc
#define G_HAVE_WCTYPE_H 1"
fi
if test x$glib_working_wctype = xno; then
  glib_wc="\$glib_wc
#define G_HAVE_BROKEN_WCTYPE 1"
fi

case x$have_threads in
xnone)	g_enable_threads_def="#undef";;
*)	g_enable_threads_def="#define";;
esac

g_threads_impl_def=$g_threads_impl

g_mutex_has_default="$mutex_has_default"
g_mutex_sizeof="$glib_cv_sizeof_gmutex"
g_mutex_contents="$glib_cv_byte_contents_gmutex"
    ])
]) dnl End of GWX_GTK1_GLIBCONFIG

AC_DEFUN(GWX_GTK2_GLIBCONFIG,[
  AC_CONFIG_COMMANDS(gtk2+/glib/glibconfig.h,[
	echo "$as_me: creating gtk2+/glib/glibconfig.h"
	outfile=glibconfig.h-tmp
	cat > $outfile <<\_______EOF
/* glibconfig.h
 *
 * This is a generated file.  Please modify 'configure.in'
 */

#ifndef __G_LIBCONFIG_H__
#define __G_LIBCONFIG_H__

#include <glib/gmacros.h>

_______EOF

	if test x$glib2_limits_h = xyes; then
	  echo '#include <limits.h>' >> $outfile
	fi
	if test x$glib2_float_h = xyes; then
	  echo '#include <float.h>' >> $outfile
	fi
	if test x$glib2_values_h = xyes; then
	  echo '#include <values.h>' >> $outfile
	fi
	if test "$glib2_header_alloca_h" = "yes"; then
	  echo '#define GLIB_HAVE_ALLOCA_H' >> $outfile
	fi
	if test x$glib_sys_poll_h = xyes; then
	  echo '#define GLIB_HAVE_SYS_POLL_H' >> $outfile
	fi

	cat >> $outfile <<_______EOF

G_BEGIN_DECLS

#define G_MINFLOAT	$glib2_mf
#define G_MAXFLOAT	$glib2_Mf
#define G_MINDOUBLE	$glib2_md
#define G_MAXDOUBLE	$glib2_Md
#define G_MINSHORT	$glib2_ms
#define G_MAXSHORT	$glib2_Ms
#define G_MAXUSHORT	$glib2_Mus
#define G_MININT	$glib2_mi
#define G_MAXINT	$glib2_Mi
#define G_MAXUINT	$glib2_Mui
#define G_MINLONG	$glib2_ml
#define G_MAXLONG	$glib2_Ml
#define G_MAXULONG	$glib2_Mul

#define G_MININT64	G_GINT64_CONSTANT(0x8000000000000000)
#define G_MAXINT64	G_GINT64_CONSTANT(0x7fffffffffffffff)
#define G_MAXUINT64	G_GINT64_CONSTANT(0xffffffffffffffffU)

_______EOF


	### this should always be true in a modern C/C++ compiler
	cat >>$outfile <<_______EOF
typedef signed char gint8;
typedef unsigned char guint8;
_______EOF


	if test -n "$g2int16"; then
	  cat >>$outfile <<_______EOF
typedef signed $g2int16 gint16;
typedef unsigned $g2int16 guint16;
#define G_GINT16_FORMAT $g2int16_format
#define G_GUINT16_FORMAT $g2uint16_format
_______EOF
	fi


	if test -n "$g2int32"; then
	  cat >>$outfile <<_______EOF
typedef signed $g2int32 gint32;
typedef unsigned $g2int32 guint32;
#define G_GINT32_FORMAT $g2int32_format
#define G_GUINT32_FORMAT $g2uint32_format
_______EOF
	fi

	cat >>$outfile <<_______EOF
#define G_HAVE_GINT64 1          /* deprecated, always true */

${glib2_extension}typedef signed $g2int64 gint64;
${glib2_extension}typedef unsigned $g2int64 guint64;

#define G_GINT64_CONSTANT(val)	$g2int64_constant
_______EOF

	if test x$g2int64_format != x ; then
	  cat >>$outfile <<_______EOF
#define G_GINT64_FORMAT $g2int64_format
#define G_GUINT64_FORMAT $g2uint64_format
_______EOF
        else
	  cat >>$outfile <<_______EOF
#undef G_GINT64_FORMAT
#undef G_GUINT64_FORMAT
_______EOF
        fi           

        cat >>$outfile <<_______EOF

#define GLIB_SIZEOF_VOID_P $glib2_void_p
#define GLIB_SIZEOF_LONG   $glib2_long
#define GLIB_SIZEOF_SIZE_T $glib2_size_t

_______EOF

echo "typedef signed $glib2_size_type_define gssize;" >> $outfile
echo "typedef unsigned $glib2_size_type_define gsize;" >> $outfile

	if test -z "$glib2_unknown_void_p"; then
	  cat >>$outfile <<_______EOF

#define GPOINTER_TO_INT(p)	((gint)  ${glib2_gpi_cast} (p))
#define GPOINTER_TO_UINT(p)	((guint) ${glib2_gpui_cast} (p))

#define GINT_TO_POINTER(i)	((gpointer) ${glib2_gpi_cast} (i))
#define GUINT_TO_POINTER(u)	((gpointer) ${glib2_gpui_cast} (u))
_______EOF
	else
	  echo '#error SIZEOF_VOID_P unknown - This should never happen' >>$outfile
	fi



	cat >>$outfile <<_______EOF
$glib2_atexit
$glib2_memmove
$glib2_defines
$glib2_os

$glib2_vacopy

#ifdef	__cplusplus
#define	G_HAVE_INLINE	1
#else	/* !__cplusplus */
$glib2_inline
#endif	/* !__cplusplus */

_______EOF

	if test x$g2_have_iso_c_varargs = xyes ; then
		cat >>$outfile <<_______EOF
#ifndef __cplusplus
# define G_HAVE_ISO_VARARGS 1
#endif
_______EOF
	fi
	if test x$g2_have_iso_cxx_varargs = xyes ; then
		cat >>$outfile <<_______EOF
#ifdef __cplusplus
# define G_HAVE_ISO_VARARGS 1
#endif
_______EOF
	fi
	if test x$g2_have_gnuc_varargs = xyes ; then
		cat >>$outfile <<_______EOF

/* gcc-2.95.x supports both gnu style and ISO varargs, but if -ansi
 * is passed ISO vararg support is turned off, and there is no work
 * around to turn it on, so we unconditionally turn it off.
 */
#if __GNUC__ == 2 && __GNUC_MINOR__ == 95
#  undef G_HAVE_ISO_VARARGS
#endif

#define G_HAVE_GNUC_VARARGS 1
_______EOF
	fi

	case x$g2_stack_grows in
	xyes) echo "#define G_HAVE_GROWING_STACK 1" >>$outfile ;;
	*)    echo "#define G_HAVE_GROWING_STACK 0" >>$outfile ;;
	esac


	echo >>$outfile
	if test x$g2_have_eilseq = xno; then
		cat >>$outfile <<_______EOF
#ifndef EILSEQ
/* On some systems, like SunOS and NetBSD, EILSEQ is not defined.
 * The correspondence between this and the corresponding definition
 * in libiconv is essential.
 */
#  define EILSEQ ENOENT
#endif
_______EOF

	fi

	echo >>$outfile
	if test x$g2_mutex_has_default = xyes; then
		cat >>$outfile <<_______EOF
$g2_enable_threads_def G_THREADS_ENABLED
#define G_THREADS_IMPL_$g2_threads_impl_def
typedef struct _GStaticMutex GStaticMutex;
struct _GStaticMutex
{
  struct _GMutex *runtime_mutex;
  union {
    char   pad[$g2_mutex_sizeof];
    double dummy_double;
    void  *dummy_pointer;
    long   dummy_long;
  } static_mutex;
};
#define	G_STATIC_MUTEX_INIT	{ NULL, { { $g2_mutex_contents} } }
#define	g_static_mutex_get_mutex(mutex) \
  (g_thread_use_default_impl ? ((GMutex*) &((mutex)->static_mutex)) : \
   g_static_mutex_get_mutex_impl (&((mutex)->runtime_mutex)))
_______EOF
	else
		cat >>$outfile <<_______EOF
$g2_enable_threads_def G_THREADS_ENABLED
#define G_THREADS_IMPL_$g2_threads_impl_def
typedef struct _GMutex* GStaticMutex;
#define G_STATIC_MUTEX_INIT NULL
#define g_static_mutex_get_mutex(mutex) (g_static_mutex_get_mutex_impl (mutex))
_______EOF
	fi

	cat >>$outfile <<_______EOF
/* This represents a system thread as used by the implementation. An
 * alien implementaion, as loaded by g_thread_init can only count on
 * "sizeof (gpointer)" bytes to store their info. We however need more
 * for some of our native implementations. */
typedef union _GSystemThread GSystemThread;
union _GSystemThread
{
  char   data[$g2_system_thread_sizeof];
  double dummy_double;
  void  *dummy_pointer;
  long   dummy_long;
};
_______EOF

	echo >>$outfile
	g_bit_sizes="16 32 64"
	for bits in $g_bit_sizes; do
	  cat >>$outfile <<_______EOF
#define GINT${bits}_TO_${g2_bs_native}(val)	((gint${bits}) (val))
#define GUINT${bits}_TO_${g2_bs_native}(val)	((guint${bits}) (val))
#define GINT${bits}_TO_${g2_bs_alien}(val)	((gint${bits}) GUINT${bits}_SWAP_LE_BE (val))
#define GUINT${bits}_TO_${g2_bs_alien}(val)	(GUINT${bits}_SWAP_LE_BE (val))
_______EOF
	done

	cat >>$outfile <<_______EOF
#define GLONG_TO_LE(val)	((glong) GINT${g2longbits}_TO_LE (val))
#define GULONG_TO_LE(val)	((gulong) GUINT${g2longbits}_TO_LE (val))
#define GLONG_TO_BE(val)	((glong) GINT${g2longbits}_TO_BE (val))
#define GULONG_TO_BE(val)	((gulong) GUINT${g2longbits}_TO_BE (val))
#define GINT_TO_LE(val)		((gint) GINT${g2intbits}_TO_LE (val))
#define GUINT_TO_LE(val)	((guint) GUINT${g2intbits}_TO_LE (val))
#define GINT_TO_BE(val)		((gint) GINT${g2intbits}_TO_BE (val))
#define GUINT_TO_BE(val)	((guint) GUINT${g2intbits}_TO_BE (val))
#define G_BYTE_ORDER $g2_byte_order

_______EOF

	if test -r glibconfig-sysdefs.h; then
	  cat glibconfig-sysdefs.h >>$outfile
	fi

	cat >>$outfile <<_______EOF

#define G_MODULE_SUFFIX "$g2_module_suffix"

G_END_DECLS

#endif /* GLIBCONFIG_H */
_______EOF


	if cmp -s $outfile gtk2+/glib/glibconfig.h; then
	  echo "$as_me: gtk2+/glib/glibconfig.h is unchanged"
	  rm -f $outfile
	else
	  mv $outfile gtk2+/glib/glibconfig.h
	fi
    ],[

if test "x${ac_cv_working_alloca_h+set}" = xset ; then
  glib2_header_alloca_h="$ac_cv_working_alloca_h"
else
  glib2_header_alloca_h="$ac_cv_header_alloca_h"
fi

case xyes in
x$ac_cv_header_float_h)
  glib2_float_h=yes
  glib2_mf=FLT_MIN glib2_Mf=FLT_MAX
  glib2_md=DBL_MIN glib2_Md=DBL_MAX
  ;;
x$ac_cv_header_values_h)
  glib2_values_h=yes
  glib2_mf=MINFLOAT  glib2_Mf=MAXFLOAT
  glib2_md=MINDOUBLE glib2_Md=MAXDOUBLE
  ;;
esac

case xyes in
x$ac_cv_header_limits_h)
  glib2_limits_h=yes
  glib2_ms=SHRT_MIN glib2_Ms=SHRT_MAX glib2_Mus=USHRT_MAX
  glib2_mi=INT_MIN  glib2_Mi=INT_MAX  glib2_Mui=UINT_MAX
  glib2_ml=LONG_MIN glib2_Ml=LONG_MAX glib2_Mul=ULONG_MAX
  ;;
x$ac_cv_header_values_h)
  glib2_values_h=yes
  glib2_ms=MINSHORT glib2_Ms=MAXSHORT glib2_Mus="(((gushort)G_MAXSHORT)*2+1)"
  glib2_mi=MININT   glib2_Mi=MAXINT   glib2_Mui="(((guint)G_MAXINT)*2+1)"
  glib2_ml=MINLONG  glib2_Ml=MAXLONG  glib2_Mul="(((gulong)G_MAXLONG)*2+1)"
  ;;
esac

if test x$ac_cv_header_sys_poll_h = xyes ; then
  glib2_sys_poll_h=yes
fi

case 2 in
$ac_cv_sizeof_short)		
  g2int16=short
  g2int16_format='"hi"'
  g2uint16_format='"hu"'
  ;;
$ac_cv_sizeof_int)		
  g2int16=int
  g2int16_format='"i"'
  g2uint16_format='"u"'
  ;;
esac
case 4 in
$ac_cv_sizeof_short)		
  g2int32=short
  g2int32_format='"hi"'
  g2uint32_format='"hu"'
  ;;
$ac_cv_sizeof_int)		
  g2int32=int
  g2int32_format='"i"'
  g2uint32_format='"u"'
  ;;
$ac_cv_sizeof_long)		
  g2int32=long
  g2int32_format='"li"'
  g2uint32_format='"lu"'
  ;;
esac
case 8 in
$ac_cv_sizeof_int)
  g2int64=int
  g2int64_format='"i"'
  g2uint64_format='"u"'
  glib2_extension=
  g2int64_constant='(val)'
  ;;
$ac_cv_sizeof_long)
  g2int64=long
  g2int64_format='"li"'
  g2uint64_format='"lu"'
  glib2_extension=
  g2int64_constant='(val##L)'
  ;;
$ac_cv_sizeof_long_long)
  g2int64='long long'
  if test -n "$glib_cv_long_long_format"; then
    g2int64_format='"'$glib_cv_long_long_format'i"'
    g2uint64_format='"'$glib_cv_long_long_format'u"'
  fi
  glib2_extension='G_GNUC_EXTENSION '
  g2int64_constant='(G_GNUC_EXTENSION (val##LL))'
  ;;
esac
glib2_size_t=$glib_cv_sizeof_size_t
glib2_size_type_define=$glib_size_type
glib2_void_p=$ac_cv_sizeof_long
glib2_long=$ac_cv_sizeof_void_p

g2intbits=`expr $ac_cv_sizeof_int \* 8`
g2longbits=`expr $ac_cv_sizeof_long \* 8`


case $ac_cv_sizeof_void_p in
$ac_cv_sizeof_int)  	glib2_gpi_cast=''        glib2_gpui_cast=''         ;;
$ac_cv_sizeof_long) 	glib2_gpi_cast='(glong)' glib2_gpui_cast='(gulong)' ;;
*) 			glib2_unknown_void_p=yes ;;
esac


case xyes in
x$ac_cv_func_atexit)
  glib2_atexit="
#ifdef NeXT /* @#%@! NeXTStep */
# define g_ATEXIT(proc)	(!atexit (proc))
#else
# define g_ATEXIT(proc)	(atexit (proc))
#endif"
  ;;
x$ac_cv_func_on_exit)
  glib2_atexit="
#define g_ATEXIT(proc)	(on_exit ((void (*)(int, void*))(proc), NULL))"
  ;;
esac

case xyes in
x$ac_cv_func_memmove)
  glib2_memmove='
#define g_memmove(d,s,n) G_STMT_START { memmove ((d), (s), (n)); } G_STMT_END'
  ;;
x$glib_cv_working_bcopy)
  glib2_memmove="
/* memmove isn't available, but bcopy can copy overlapping memory regions */
#define g_memmove(d,s,n) G_STMT_START { bcopy ((s), (d), (n)); } G_STMT_END"
  ;;
*)  
  glib2_memmove="
/* memmove isn't found and bcopy can't copy overlapping memory regions, 
 * so we have to roll our own copy routine. */
void g_memmove (void* dest, const void * src, unsigned long len);"
  ;;
esac

glib2_defines="
#define GLIB_MAJOR_VERSION $GLIB2_MAJOR_VERSION
#define GLIB_MINOR_VERSION $GLIB2_MINOR_VERSION
#define GLIB_MICRO_VERSION $GLIB2_MICRO_VERSION
"

case xyes in
x$glib_cv_va_copy)	glib2_vacopy='#define G_VA_COPY	va_copy' ;;
x$glib_cv___va_copy)	glib2_vacopy='#define G_VA_COPY	__va_copy' ;;
*)			glib2_vacopy=''
esac

if test x$glib_cv_va_val_copy = xno; then
  glib2_vacopy="\$glib_vacopy
#define G_VA_COPY_AS_ARRAY 1"
fi

if test x$glib_cv_hasinline = xyes; then
    glib2_inline='#define G_HAVE_INLINE 1'
fi
if test x$glib_cv_has__inline = xyes; then
    glib2_inline="\$glib2_inline
#define G_HAVE___INLINE 1"
fi
if test x$glib_cv_has__inline__ = xyes; then
    glib2_inline="\$glib2_inline
#define G_HAVE___INLINE__ 1"
fi

g2_have_gnuc_varargs=$g_have_gnuc_varargs
g2_have_iso_c_varargs=$g_have_iso_c_varargs
g2_have_iso_cxx_varargs=$g_have_iso_cxx_varargs

case xyes in
x$ac_cv_c_bigendian)
  g2_byte_order=G_BIG_ENDIAN
  g2_bs_native=BE
  g2_bs_alien=LE
  ;;
*)
  g2_byte_order=G_LITTLE_ENDIAN
  g2_bs_native=LE
  g2_bs_alien=BE
  ;;
esac

g2_stack_grows=$glib_cv_stack_grows

g2_have_eilseq=$have_eilseq

case x$have_threads in
xnone)	g2_enable_threads_def="#undef";;
*)	g2_enable_threads_def="#define";;
esac

g2_threads_impl_def=$g_threads_impl

g2_mutex_has_default="$mutex_has_default"
g2_mutex_sizeof="$glib_cv_sizeof_gmutex"
g2_system_thread_sizeof="$glib_cv_sizeof_system_thread"
g2_mutex_contents="$glib_cv_byte_contents_gmutex"

g2_module_suffix="$glib_gmodule_suffix"

case $host in
  *-*-beos*)
    glib2_os="#define G_OS_BEOS"
    ;;
  *-*-cygwin*)
    glib2_os="#define G_OS_UNIX
#define G_PLATFORM_WIN32
#define G_WITH_CYGWIN"
    ;;
  *-*-mingw*)
    glib2_os="#define G_OS_WIN32
#define G_PLATFORM_WIN32"
    ;;
  *)
    glib2_os="#define G_OS_UNIX"
    ;;
esac
    ])
]) dnl End of GWX_GTK2_GLIBCONFIG

AC_DEFUN(GWX_GTK2_GDKCONFIG,[
  AC_CONFIG_COMMANDS(gtk2+/gdk/gdkconfig.h,[
	echo "$as_me: creating gtk2+/gdk/gdkconfig.h"
	outfile=gdkconfig.h-tmp
	cat > $outfile <<\_______EOF
/* gdkconfig.h
 *
 * This is a generated file.  Please modify `configure.in'
 */

#ifndef GDKCONFIG_H
#define GDKCONFIG_H

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

_______EOF

	cat >>$outfile <<_______EOF
$gdk_windowing
$gdk_wc
_______EOF

	cat >>$outfile <<_______EOF

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* GDKCONFIG_H */
_______EOF


	if cmp -s $outfile gtk2+/gdk/gdkconfig.h; then
	  echo "$as_me: gtk2+/gdk/gdkconfig.h is unchanged"
	  rm -f $outfile
	else
	  mv $outfile gtk2+/gdk/gdkconfig.h
	fi
],[
if test "x$gdktarget" = "xx11" ; then
  gdk_windowing='
#define GDK_WINDOWING_X11'
elif test "x$gdktarget" = "xwin32" ; then
  gdk_windowing='
#define GDK_WINDOWING_WIN32'
elif test "x$gdktarget" = "xlinux-fb" ; then
  gdk_windowing='
#define GDK_WINDOWING_FB
#define GDK_NATIVE_WINDOW_POINTER'
fi

if test x$gdk_wchar_h = xyes; then
  gdk_wc='
#define GDK_HAVE_WCHAR_H 1'
fi
if test x$ac_cv_header_wctype_h = xyes; then
  gdk_wc="\$gdk_wc
#define GDK_HAVE_WCTYPE_H 1"
fi
if test x$glib_cv_wctype_ok = xno; then
  gdk_wc="\$gdk_wc
#define GDK_HAVE_BROKEN_WCTYPE 1"
fi
])
]) dnl End of GWX_GTK2_GDKCONFIG

AC_DEFUN(AC_CHECK_DEFINE,[
  AC_CACHE_CHECK(for $1 in $2, ac_cv_define_$1,
    AC_EGREP_CPP([YES_IS_DEFINED], [
#include <$2>
#ifdef $1
YES_IS_DEFINED
#endif
    ], ac_cv_define_$1=yes, ac_cv_define_$1=no)
  )
  if test "$ac_cv_define_$1" = "yes" ; then
    AC_DEFINE(HAVE_$1, 1, [define to 1 if you have the $1 define])
  fi
])

AC_DEFUN(AC_IFALLYES,[
ac_rc=yes
for ac_spec in $1; do
    ac_type=`echo "$ac_spec" | sed -e 's/:.*$//'`
    ac_item=`echo "$ac_spec" | sed -e 's/^.*://'`
    case $ac_type in
        header )
            ac_item=`echo "$ac_item" | sed 'y%./+-%__p_%'`
            ac_var="ac_cv_header_$ac_item"
            ;;
        file )
            ac_item=`echo "$ac_item" | sed 'y%./+-%__p_%'`
            ac_var="ac_cv_file_$ac_item"
            ;;
        func )   ac_var="ac_cv_func_$ac_item"   ;;
        define ) ac_var="ac_cv_define_$ac_item" ;;
        custom ) ac_var="$ac_item" ;;
    esac
    eval "ac_val=\$$ac_var"
    if test ".$ac_val" != .yes; then
        ac_rc=no
        break
    fi
done
if test ".$ac_rc" = .yes; then
    :
    $2
else
    :
    $3
fi
])

AC_DEFUN(AC_TEST_FILE,
[AC_REQUIRE([AC_PROG_CC])
ac_safe=`echo "$1" | sed 'y%./+-%__p_%'`
AC_MSG_CHECKING([for $1])
AC_CACHE_VAL(ac_cv_file_$ac_safe, [
  if test -r $1; then
    eval "ac_cv_file_$ac_safe=yes"
  else
    eval "ac_cv_file_$ac_safe=no"
  fi
])dnl
if eval "test \"`echo '$ac_cv_file_'$ac_safe`\" = yes"; then
  AC_MSG_RESULT(yes)
  ifelse([$2], , :, [$2])
else
  AC_MSG_RESULT(no)
ifelse([$3], , , [$3])
fi
])

AC_DEFUN(AC_CHECK_MAXSEGSIZE,[
AC_MSG_CHECKING(for shared memory maximum segment size)
AC_CACHE_VAL(ac_cv_maxsegsize,[
OCFLAGS="$CFLAGS"
case "$1" in
    MM_SHMT_MM*    ) CFLAGS="-DTEST_MMAP   $CFLAGS" ;;
    MM_SHMT_IPCSHM ) CFLAGS="-DTEST_SHMGET $CFLAGS" ;;
esac
cross_compile=no
AC_TRY_RUN(
changequote(<<, >>)dnl
<<
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <sys/file.h>
#include <sys/types.h>
#include <sys/stat.h>
#ifdef TEST_MMAP
#include <sys/mman.h>
#endif
#ifdef TEST_SHMGET
#ifdef MM_OS_SUNOS
#define KERNEL 1
#endif
#ifdef MM_OS_BS2000
#define _KMEMUSER 
#endif
#include <sys/ipc.h>
#include <sys/shm.h>
#ifdef MM_OS_SUNOS
#undef KERNEL
#endif
#ifdef MM_OS_BS2000
#undef _KMEMUSER
#endif
#if !defined(SHM_R)
#define SHM_R 0400
#endif
#if !defined(SHM_W)
#define SHM_W 0200
#endif
#endif
#if !defined(MAP_FAILED)
#define MAP_FAILED ((void *)(-1))
#endif
#ifdef MM_OS_BEOS
#include <kernel/OS.h>
#endif

int testit(int size)
{
    int fd;
    void *segment;
#ifdef TEST_MMAP
    char file[] = "./ac_test.tmp";
    unlink(file);
    if ((fd = open(file, O_RDWR|O_CREAT, S_IRUSR|S_IWUSR)) == -1)
        return 0;
    if (ftruncate(fd, size) == -1)
        return 0;
    if ((segment = (void *)mmap(NULL, size, PROT_READ|PROT_WRITE, 
                                MAP_SHARED, fd, 0)) == (void *)MAP_FAILED) {
        close(fd);
        return 0;
    }
    munmap((caddr_t)segment, size);
    close(fd);
    unlink(file);
#endif
#ifdef TEST_SHMGET
    if ((fd = shmget(IPC_PRIVATE, size, SHM_R|SHM_W|IPC_CREAT)) == -1)
        return 0;
    if ((segment = (void *)shmat(fd, NULL, 0)) == ((void *)-1)) {
        shmctl(fd, IPC_RMID, NULL);
        return 0;
    }
    shmdt(segment);
    shmctl(fd, IPC_RMID, NULL);
#endif
#ifdef TEST_BEOS
    area_id id;
    id = create_area("mm_test", (void*)&segment, B_ANY_ADDRESS, size, 
                     B_LAZY_LOCK, B_READ_AREA|B_WRITE_AREA);
    if (id < 0)
        return 0;
    delete_area(id);
#endif
    return 1;
}

#define ABS(n) ((n) >= 0 ? (n) : (-(n)))

int main(int argc, char *argv[]) 
{
    int t, m, b;
    int d;
    int rc;
    FILE *f;

    /*
     * Find maximum possible allocation size by performing a
     * binary search starting with a search space between 0 and
     * 64MB of memory.
     */
    t = 1024*1024*64 /* = 67108864 */;
    if (testit(t))
        m = t;
    else {
        m = 1024*1024*32;
        b = 0;
        for (;;) {
            /* fprintf(stderr, "t=%d, m=%d, b=%d\n", t, m, b); */
            rc = testit(m);
            if (rc) {
                d = ((t-m)/2);
                b = m;
            }
            else {
                d = -((m-b)/2);
                t = m;
            }
            if (ABS(d) < 1024*1) {
                if (!rc)
                    m = b;
                break;
            }
            if (m < 1024*8)
                break;
            m += d;
        }
        if (m < 1024*8)
            m = 0;
    }
    if ((f = fopen("conftestval", "w")) == NULL)
        exit(1);
    fprintf(f, "%d\n", m);
    fclose(f);
    exit(0);
}
>>
changequote([, ])dnl
,[ac_cv_maxsegsize="`cat conftestval`"
case $host in
 *sco3.2v5*) ac_cv_maxsegsize=524288
esac
],
ac_cv_maxsegsize=0
,
ac_cv_maxsegsize=0
)
CFLAGS="$OCFLAGS"
])
msg="$ac_cv_maxsegsize"
if test $msg -eq 67108864; then
    msg="64MB (soft limit)"
elif test $msg -gt 1048576; then
    msg="`expr $msg / 1024`"
    msg="`expr $msg / 1024`"
    msg="${msg}MB"
elif test $msg -gt 1024; then
    msg="`expr $msg / 1024`"
    msg="${msg}KB"
else
    ac_cv_maxsegsize=0
    msg=unknown
fi
MM_SHM_MAXSEGSIZE=$ac_cv_maxsegsize
test ".$msg" = .unknown && AC_MSG_ERROR([Unable to determine maximum shared memory segment size])
AC_MSG_RESULT([$msg])
AC_DEFINE_UNQUOTED(MM_SHM_MAXSEGSIZE, $MM_SHM_MAXSEGSIZE, [maximum segment size])
])

AC_DEFUN([GWX_ADD_PC],
[AC_CONFIG_FILES(pc/$1,[
  gwxcfg=`cat $ac_file | sed -n -e '/^GWXCFG=/p'` 2>/dev/null
  if test -n "$gwxcfg"; then
    cfgfile=`echo "$gwxcfg" | sed -e 's/^GWXCFG=//'` 2>/dev/null
    thispc=`basename $ac_file .pc`
    cat pc/TEMPLATE | sed -e "s/@THISCFG@/$cfgfile/g" -e "s/@THISPC@/$thispc/g" > pc/${cfgfile}-config && chmod +x pc/${cfgfile}-config
    GWXCFGFILES="$GWXCFGFILES ${cfgfile}-config"
  fi
  ])
 PCFILES="$PCFILES $1"
])

dnl
dnl Check whether there is a snprintf() function with C99 semantics installed.
dnl
AC_DEFUN([AC_FUNC_SNPRINTF_C99],
[AC_CACHE_CHECK(for C99 snprintf,
  ac_cv_func_snprintf_c99,
[AC_TRY_RUN(
[#include <stdio.h>
#include <stdarg.h>

int
doit()
{
  char buffer[32];
  va_list args;
  int r;

  r = snprintf(buffer, 5, "1234567");

  if (r != 7)
    exit(1);

  r = snprintf(buffer, 0, "1234567");

  if (r != 7)
    exit(1);

  r = snprintf(NULL, 0, "1234567");

  if (r != 7)
    exit(1);

  exit(0);
}

int
main(void)
{
  doit();
  exit(1);
}], ac_cv_func_snprintf_c99=yes, ac_cv_func_snprintf_c99=no, ac_cv_func_snprintf_c99=no)])
dnl Note that the default is to be pessimistic in the case of cross compilation.
dnl If you know that the target has a C99 snprintf(), you can get around this
dnl by setting ac_func_snprintf_c99 to yes, as described in the Autoconf manual.
if test $ac_cv_func_snprintf_c99 = yes; then
  AC_DEFINE(HAVE_C99_SNPRINTF, 1,
            [Define if you have a version of the snprintf function
             with semantics as specified by the ISO C99 standard.])
fi
])# AC_FUNC_SNPRINTF_C99

dnl
dnl Check whether there is a vsnprintf() function with C99 semantics installed.
dnl
AC_DEFUN([AC_FUNC_VSNPRINTF_C99],
[AC_CACHE_CHECK(for C99 vsnprintf,
  ac_cv_func_vsnprintf_c99,
[AC_TRY_RUN(
[#include <stdio.h>
#include <stdarg.h>

int
doit(char * s, ...)
{
  char buffer[32];
  va_list args;
  int r;

  va_start(args, s);
  r = vsnprintf(buffer, 5, s, args);
  va_end(args);

  if (r != 7)
    exit(1);

  exit(0);
}

int
main(void)
{
  doit("1234567");
  exit(1);
}], ac_cv_func_vsnprintf_c99=yes, ac_cv_func_vsnprintf_c99=no, ac_cv_func_vsnprintf_c99=no)])
dnl Note that the default is to be pessimistic in the case of cross compilation.
dnl If you know that the target has a C99 vsnprintf(), you can get around this
dnl by setting ac_func_vsnprintf_c99 to yes, as described in the Autoconf manual.
if test $ac_cv_func_vsnprintf_c99 = yes; then
  AC_DEFINE(HAVE_C99_VSNPRINTF, 1,
            [Define if you have a version of the vsnprintf function
             with semantics as specified by the ISO C99 standard.])
fi
])# AC_FUNC_VSNPRINTF_C99

dnl
dnl Check whether the printf() family supports Unix98 %n$ positional parameters 
dnl
AC_DEFUN([AC_FUNC_PRINTF_UNIX98],
[AC_CACHE_CHECK(whether printf supports positional parameters,
  ac_cv_func_printf_unix98,
[AC_TRY_RUN(
[#include <stdio.h>
LINK
int
main (void)
{
  char buffer[128];

  sprintf (buffer, "%2\$d %3\$d %1\$d", 1, 2, 3);
  if (strcmp ("2 3 1", buffer) == 0)
    exit (0);
  exit (1);
}], ac_cv_func_printf_unix98=yes, ac_cv_func_printf_unix98=no, ac_cv_func_printf_unix98=no)])
dnl Note that the default is to be pessimistic in the case of cross compilation.
dnl If you know that the target printf() supports positional parameters, you can get around 
dnl this by setting ac_func_printf_unix98 to yes, as described in the Autoconf manual.
if test $ac_cv_func_printf_unix98 = yes; then
  AC_DEFINE(HAVE_UNIX98_PRINTF, 1,
            [Define if your printf function family supports positional parameters
             as specified by Unix98.])
fi
])# AC_FUNC_PRINTF_UNIX98

dnl Check for the presence of SA_RESTORER field in struct sigaction.
dnl
dnl OPENSLP_STRUCT_SA_RESTORER
AC_DEFUN([GWX_STRUCT_SA_RESTORER],
[AC_CACHE_CHECK([for sa_restorer in struct sigaction], 
ac_cv_struct_sa_restorer,
[AC_TRY_COMPILE([#include <sys/types.h>
#include <sys/signal.h>], [struct sigaction s; s.sa_restorer;],
ac_cv_struct_sa_restorer=yes, ac_cv_struct_sa_restorer=no)])
if test $ac_cv_struct_sa_restorer = yes; then
  AC_DEFINE(HAVE_SA_RESTORER)
fi
])

# GLIB_ASSERT_SET(VARIABLE)
# -------------------------
AC_DEFUN([GLIB_ASSERT_SET],
[if test "x${$1+set}" != "xset" ; then
  AC_MSG_ERROR($1 [must be set in cache file when cross-compiling.])
fi
])dnl

dnl Check for re-entrancy stuff. Assumed CFLAGS has -D_REENTRANT.
AC_DEFUN([GWX_REENTRANCY],[
  have_missing_r_funcs=
  AC_MSG_CHECKING(for asctime_r)
  AC_CACHE_VAL(ac_cv_asctime_args,[
    AC_TRY_LINK([#include <time.h>],[
      struct tm tmb;
      char buf[128];
      asctime_r(&tmb, buf);], ac_cv_asctime_args=2)
    if test -z "$ac_cv_asctime_args" ; then
      AC_TRY_LINK([#include <time.h>],[
        struct tm tmb;
        char buf[128];
        asctime_r(&tmb, buf, 128);], ac_cv_asctime_args=3)
    fi
    if test -z "$ac_cv_asctime_args"; then
      ac_cv_asctime_args=0
    fi
  ])dnl End of cache: ac_cv_asctime_args
  if test "x$ac_cv_asctime_args" = "x0"; then
    AC_MSG_RESULT([no])
    have_missing_r_funcs="$have_missing_r_funcs asctime_r"
  else
    AC_DEFINE(HAVE_ASCTIME_R, 1, [define if you have the asctime_r function])
    AC_MSG_RESULT([yes, and it takes $ac_cv_asctime_args arguments])
    if test "$ac_cv_asctime_args" = 2; then
      AC_DEFINE(HAVE_ASCTIME_R_2)
    elif test "$ac_cv_asctime_args" = 3; then
      AC_DEFINE(HAVE_ASCTIME_R_3)
    fi
  fi

  AC_MSG_CHECKING(for ctime_r)
  AC_CACHE_VAL(ac_cv_ctime_args,[
    AC_TRY_LINK([#include <time.h>],[
      time_t clock;
      char buf[26];
      ctime_r(&clock, buf);], ac_cv_ctime_args=2)
    if test -z "$ac_cv_ctime_args" ; then
      AC_TRY_LINK([#include <time.h>],[
        time_t clock;
        char buf[26];
        ctime_r(&clock, buf, 26);], ac_cv_ctime_args=3)
    fi
    if test -z "$ac_cv_ctime_args"; then
      ac_cv_ctime_args=0
    fi
  ])dnl End of cache: ac_cv_ctime_args
  if test "x$ac_cv_ctime_args" = "x0"; then
    AC_MSG_RESULT([no])
    have_missing_r_funcs="$have_missing_r_funcs ctime_r"
  else
    AC_DEFINE(HAVE_CTIME_R, 1, [define if you have the ctime_r function])
    AC_MSG_RESULT([yes, and it takes $ac_cv_ctime_args arguments])
    if test "$ac_cv_ctime_args" = 2; then
      AC_DEFINE(HAVE_CTIME_R_2)
    elif test "$ac_cv_ctime_args" = 3; then
      AC_DEFINE(HAVE_CTIME_R_3)
    fi
  fi

  AC_MSG_CHECKING(for localtime_r)
  AC_CACHE_VAL(ac_cv_localtime_args,[
    AC_TRY_LINK([#include <time.h>],[
      time_t clock;
      struct tm buf;
      localtime_r(&clock, &buf);], ac_cv_localtime_args=2)
    if test -z "$ac_cv_localtime_args" ; then
      AC_TRY_LINK([#include <time.h>],[
        time_t clock;
        struct tm buf;
        localtime_r(&clock, &buf, sizeof(buf));], ac_cv_localtime_args=3)
    fi
    if test -z "$ac_cv_localtime_args"; then
      ac_cv_localtime_args=0
    fi
  ])dnl End of cache: ac_cv_localtime_args
  if test "x$ac_cv_localtime_args" = "x0"; then
    AC_MSG_RESULT([no])
    have_missing_r_funcs="$have_missing_r_funcs localtime_r"
  else
    AC_DEFINE(HAVE_LOCALTIME_R,1,[define if you have the localtime_r function])
    AC_MSG_RESULT([yes, and it takes $ac_cv_localtime_args arguments])
    if test "$ac_cv_localtime_args" = 2; then
      AC_DEFINE(HAVE_LOCALTIME_R_2)
    elif test "$ac_cv_localtime_args" = 3; then
      AC_DEFINE(HAVE_LOCALTIME_R_3)
    fi
  fi

  AC_MSG_CHECKING(for gmtime_r)
  AC_CACHE_VAL(ac_cv_gmtime_args,[
    AC_TRY_LINK([#include <time.h>],[
      time_t clock;
      struct tm buf;
      gmtime_r(&clock, &buf);], ac_cv_gmtime_args=2)
    if test -z "$ac_cv_gmtime_args" ; then
      AC_TRY_LINK([#include <time.h>],[
        time_t clock;
        struct tm buf;
        gmtime_r(&clock, &buf, sizeof(buf));], ac_cv_gmtime_args=3)
    fi
    if test -z "$ac_cv_gmtime_args"; then
      ac_cv_gmtime_args=0
    fi
  ])dnl End of cache: ac_cv_gmtime_args
  if test "x$ac_cv_gmtime_args" = "x0"; then
    AC_MSG_RESULT([no])
    have_missing_r_funcs="$have_missing_r_funcs gmtime_r"
  else
    AC_DEFINE(HAVE_GMTIME_R, 1, [define if you have the gmtime_r function])
    AC_MSG_RESULT([yes, and it takes $ac_cv_gmtime_args arguments])
    if test "$ac_cv_gmtime_args" = 2; then
      AC_DEFINE(HAVE_GMTIME_R_2)
    elif test "$ac_cv_gmtime_args" = 3; then
      AC_DEFINE(HAVE_GMTIME_R_3)
    fi
  fi

  AC_MSG_CHECKING(for readdir_r)
  AC_CACHE_VAL(ac_cv_readdir_args,[
    AC_TRY_LINK([
#include <sys/types.h>

#if defined(HAVE_DIRENT_H)
#   include <dirent.h>
#   define NAMLEN(dirent) strlen((dirent)->d_name)
#else
#   define dirent direct
#   define NAMLEN(dirent) (dirent)->d_namlen
#   if defined(HAVE_SYS_NDIR_H)
#       include <sys/ndir.h>
#   endif
#   if defined(HAVE_SYS_DIR_H)
#       include <sys/dir.h>
#   endif
#   if defined(HAVE_NDIR_H)
#       include <ndir.h>
#   endif
#endif  ],[
      struct dirent dir, *dirp;
      DIR *mydir;
      dirp = readdir_r(mydir, &dir);], ac_cv_readdir_args=2)
    if test -z "$ac_cv_readdir_args"; then
      AC_TRY_LINK([
#include <sys/types.h>
#if defined(HAVE_DIRENT_H)
#   include <dirent.h>
#   define NAMLEN(dirent) strlen((dirent)->d_name)
#else
#   define dirent direct
#   define NAMLEN(dirent) (dirent)->d_namlen
#   if defined(HAVE_SYS_NDIR_H)
#       include <sys/ndir.h>
#   endif
#   if defined(HAVE_SYS_DIR_H)
#       include <sys/dir.h>
#   endif
#   if defined(HAVE_NDIR_H)
#       include <ndir.h>
#   endif
#endif],[
      struct dirent dir, *dirp;
      DIR *mydir;
      int rc;
      rc = readdir_r(mydir, &dir, &dirp);], ac_cv_readdir_args=3)
    fi

    if test -z "$ac_cv_readdir_args"; then
      ac_cv_readdir_args=0
    fi
  ])dnl End of cache: ac_cv_readdir_args
  if test "x$ac_cv_readdir_args" = "x0"; then
    AC_MSG_RESULT([no])
    have_missing_r_funcs="$have_missing_r_funcs readdir_r"
  else
    AC_DEFINE(HAVE_READDIR_R, 1, [define if you have the readdir_r function])
    AC_MSG_RESULT([yes, and it takes $ac_cv_readdir_args arguments])
    if test "$ac_cv_readdir_args" = 2; then
      AC_DEFINE(HAVE_READDIR_R_2)
    elif test "$ac_cv_readdir_args" = 3; then
      AC_DEFINE(HAVE_READDIR_R_3)
    fi
  fi

  AC_MSG_CHECKING(for gethostbyname_r)
  AC_CACHE_VAL(ac_cv_gethostbyname_args,[
    AC_TRY_LINK([
#include <sys/types.h>
#include <netdb.h>],[
struct hostent *hp;
struct hostent h;
char *name;
char buffer[10];
int  h_errno;
hp = gethostbyname_r(name, &h, buffer, 10, &h_errno);],
            ac_cv_gethostbyname_args=5)
    if test -z "$ac_cv_gethostbyname_args"; then
      AC_TRY_LINK([
#include <sys/types.h>
#include <netdb.h>],[
struct hostent h;
struct hostent_data hdata;
char *name;
int  rc;
rc = gethostbyname_r(name, &h, &hdata);],ac_cv_gethostbyname_args=3)
    fi
    if test -z "$ac_cv_gethostbyname_args"; then
      AC_TRY_LINK([
#include <sys/types.h>
#include <netdb.h>],[
struct hostent h;
struct hostent *hp;
char *name;
char buf[10];
int rc;
int h_errno;

rc = gethostbyname_r(name, &h, buf, 10, &hp, &h_errno);],
      ac_cv_gethostbyname_args=6)
    fi
    if test -z "$ac_cv_gethostbyname_args"; then
      ac_cv_gethostbyname_args=0
    fi
  ])dnl End of cache: ac_cv_gethostbyname_args
  if test "x$ac_cv_gethostbyname_args" = "x0"; then
    AC_MSG_RESULT([no])
    have_missing_r_funcs="$have_missing_r_funcs gethostbyname_r"
  else
    AC_DEFINE(HAVE_GETHOSTBYNAME_R, 1, [define if you have the gethostbyname_r function])
    AC_MSG_RESULT([yes, and it takes $ac_cv_gethostbyname_args arguments])
    if test "$ac_cv_gethostbyname_args" = 3; then
      AC_DEFINE(HAVE_GETHOSTBYNAME_R_3)
    elif test "$ac_cv_gethostbyname_args" = 5; then
      AC_DEFINE(HAVE_GETHOSTBYNAME_R_5)
    elif test "$ac_cv_gethostbyname_args" = 6; then
      AC_DEFINE(HAVE_GETHOSTBYNAME_R_6)
    fi
  fi

  AC_MSG_CHECKING(for gethostbyaddr_r)
  AC_CACHE_VAL(ac_cv_gethostbyaddr_args,[
    AC_TRY_LINK([
#include <sys/types.h>
#include <netdb.h>],[
char * address;
int length;
int type;
struct hostent h;
struct hostent_data hdata;
int rc;
rc = gethostbyaddr_r(address, length, type, &h, &hdata);],
      ac_cv_gethostbyaddr_args=5)

    if test -z "$ac_cv_gethostbyaddr_args"; then
      AC_TRY_LINK([
#include <sys/types.h>
#include <netdb.h>],[
char * address;
int length;
int type;
struct hostent h;
char buffer[10];
int buflen;
int h_errnop;
struct hostent * hp;

hp = gethostbyaddr_r(address, length, type, &h, buffer, buflen, &h_errnop);],
      ac_cv_gethostbyaddr_args=7)
    fi

    if test -z "$ac_cv_gethostbyaddr_args"; then
      AC_TRY_LINK([
#include <sys/types.h>
#include <netdb.h>],[
char * address;
int length;
int type;
struct hostent h;
char buffer[10];
int buflen;
int h_errnop;
struct hostent * hp;
int rc;

rc=gethostbyaddr_r(address,length,type,&h,buffer,buflen,&hp,&h_errnop);],
      ac_cv_gethostbyaddr_args=8)
    fi

    if test -z "$ac_cv_gethostbyaddr_args"; then
      ac_cv_gethostbyaddr_args=0
    fi
  ])dnl End of cache: ac_cv_gethostbyaddr_args
  if test "x$ac_cv_gethostbyaddr_args" = "x0"; then
    AC_MSG_RESULT([no])
    have_missing_r_funcs="$have_missing_r_funcs gethostbyaddr_r"
  else
    AC_DEFINE(HAVE_GETHOSTBYADDR_R, 1, [define if you have the gethostbyaddr_r function])
    AC_MSG_RESULT([yes, and it takes $ac_cv_gethostbyaddr_args arguments])
    if test "$ac_cv_gethostbyaddr_args" = 5; then
      AC_DEFINE(HAVE_GETHOSTBYADDR_R_5)
    elif test "$ac_cv_gethostbyaddr_args" = 7; then
      AC_DEFINE(HAVE_GETHOSTBYADDR_R_7)
    elif test "$ac_cv_gethostbyaddr_args" = 8; then
      AC_DEFINE(HAVE_GETHOSTBYADDR_R_8)
    fi
  fi

  AC_MSG_CHECKING(for getlogin_r)
  AC_CACHE_VAL(ac_cv_getlogin_r_style,[
    AC_TRY_RUN([
#include <unistd.h>

int main()
{
    char name[1024];
    int len=1024;
    int rc;
    char *login;

    name[0]='\0';

    rc = getlogin_r(name, len);
    if(rc == 0 && name[0] != '\0') {
	return 0; /* returns zero on success */
    } else if(rc != 0 && name[0] == '\0') {
	return 0; /* returns errno on failure */
    } else if(rc == 0 && name[0] == '\0') {
	return 0; /* can't tell */
    } else if(rc != 0 && name[0] != '\0') {
	return 1; /* returns pointer on success */
    }
}],[ac_cv_getlogin_r_style=1],[ac_cv_getlogin_r_style=2],
      [ac_cv_getlogin_r_style=])
    if test -z "$ac_cv_getlogin_r_style"; then
      ac_cv_getlogin_r_style=0
    fi
  ])dnl End of cache: ac_cv_gethostbyaddr_args
  if test "x$ac_cv_getlogin_r_style" = "x0"; then
    AC_MSG_RESULT([no])
    have_missing_r_funcs="$have_missing_r_funcs getlogin_r"
  else
    AC_DEFINE(HAVE_GETLOGIN_R, 1, [define if you have the getlogin_r function])
    if test "$ac_cv_getlogin_r_style" = 1; then
      AC_DEFINE(GETLOGIN_R_RETURNS_INT)
      AC_MSG_RESULT([yes, returning an int])
    elif test "$ac_cv_getlogin_r_style" = 2; then
      AC_DEFINE(GETLOGIN_R_RETURNS_POINTER)
      AC_MSG_RESULT([yes, returning a pointer])
    fi
  fi

  AC_MSG_CHECKING(for inet_ntoa_r)
  AC_CACHE_VAL(ac_cv_inet_ntoa_args,[
    AC_TRY_LINK([
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h],[
struct in_addr in;
char *rv;
rv = inet_ntoa_r(in, buf);],
      ac_cv_inet_ntoa_args=2)

    if test -z "$ac_cv_inet_ntoa_args"; then
      AC_TRY_LINK([
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h],[
struct in_addr in;
char buf[128], *rv;
rv = inet_ntoa_r(in, buf, 128);],
      ac_cv_inet_ntoa_args=3)
    fi

    if test -z "$ac_cv_inet_ntoa_args"; then
      ac_cv_inet_ntoa_args=0
    fi
  ])dnl End of cache: ac_cv_inet_ntoa_args
  if test "x$ac_cv_inet_ntoa_args" = "x0"; then
    AC_MSG_RESULT([no])
    have_missing_r_funcs="$have_missing_r_funcs inet_ntoa_r"
  else
    AC_DEFINE(HAVE_INET_NTOA_R,1,[define if you have the inet_ntoa_r function])
    AC_MSG_RESULT([yes, and it takes $ac_cv_inet_ntoa_args arguments])
    if test "$ac_cv_inet_ntoa_args" = 2; then
      AC_DEFINE(HAVE_INET_NTOA_R_5)
    elif test "$ac_cv_inet_ntoa_args" = 3; then
      AC_DEFINE(HAVE_INET_NTOA_R_7)
    fi
  fi

  if test -n "$have_missing_r_funcs"; then
    AC_MSG_WARN([missing reentrant functions: $have_missing_r_funcs])
  fi
])dnl

dnl AC_CHECK_SIZEOF_TYPE_T
AC_DEFUN(AC_CHECK_SIZEOF_TIME_T,
[AC_CACHE_CHECK(for whether time_t is long, ac_cv_c_long_time_t,
[AC_TRY_RUN([
#include <time.h>
int main() { exit(sizeof(time_t) == sizeof(long)); }],
ac_cv_c_long_time_t=no, ac_cv_c_long_time_t=yes)
])
if test $ac_cv_c_long_time_t = yes; then
  AC_DEFINE(HAVE_LONG_TIME_T)
fi
])

dnl AC_CHECK_SIZEOF_SIZE_T
AC_DEFUN(AC_CHECK_SIZEOF_SIZE_T,
[AC_CACHE_CHECK(for whether size_t is long, ac_cv_c_long_size_t,
[AC_TRY_RUN([
#include <stddef.h>
int main() { exit(sizeof(size_t) == sizeof(int)); }],
ac_cv_c_long_size_t=no, ac_cv_c_long_size_t=yes)
])
if test $ac_cv_c_long_size_t = yes; then
  AC_DEFINE(HAVE_LONG_SIZE_T)
fi
])

dnl AC_STRUCT_GMTOFF
dnl If struct tm contains tm_gmtoff, define HAVE_TM_GMTOFF. Otherwise,
dnl  if timezone and/or altzone exist, define HAVE_TIMEZONE and/or
dnl  HAVE_ALTZONE respectively.  Finally, if the timezone value is
dnl  backwards, define NEGATIVE_TIMEZONE.
AC_DEFUN(AC_STRUCT_GMTOFF,
[ AC_REQUIRE([AC_STRUCT_TM])dnl
  AC_MSG_CHECKING([for tm_gmtoff in struct tm])
  AC_CACHE_VAL(ac_cv_struct_gmtoff,
  [ AC_TRY_COMPILE([#include <sys/types.h>
#include <$ac_cv_struct_tm>], [struct tm tm; tm.tm_gmtoff;],
  ac_cv_struct_gmtoff=yes, ac_cv_struct_gmtoff=no)])
  AC_MSG_RESULT($ac_cv_struct_gmtoff)
if test $ac_cv_struct_gmtoff = yes; then
  AC_DEFINE(HAVE_TM_GMTOFF)
fi

AC_MSG_CHECKING(for time.h that defines timezone)
AC_CACHE_VAL(ac_cv_extern_timezone,
[AC_TRY_COMPILE([#include <time.h>], [return timezone;],
  ac_cv_extern_timezone=yes,
  ac_cv_extern_timezone=no)])
AC_MSG_RESULT($ac_cv_extern_timezone)
if test $ac_cv_extern_timezone = yes; then
  AC_DEFINE(HAVE_TIMEZONE)
fi

dnl Borrowed from the Python distribution...
AC_MSG_CHECKING(for time.h that defines altzone)
AC_CACHE_VAL(ac_cv_extern_altzone,
[AC_TRY_COMPILE([#include <time.h>], [return altzone;],
  ac_cv_extern_altzone=yes,
  ac_cv_extern_altzone=no)])
AC_MSG_RESULT($ac_cv_extern_altzone)
if test $ac_cv_extern_altzone = yes; then
  AC_DEFINE(HAVE_ALTZONE)
fi

AC_MSG_CHECKING(for time.h that defines daylight)
AC_CACHE_VAL(ac_cv_extern_daylight,
[AC_TRY_COMPILE([#include <time.h>], [return daylight;],
  ac_cv_extern_daylight=yes,
  ac_cv_extern_daylight=no)])
AC_MSG_RESULT($ac_cv_extern_daylight)
if test $ac_cv_extern_daylight = yes; then
  AC_DEFINE(HAVE_DAYLIGHT)
fi

if test $ac_cv_extern_timezone = yes; then
  AC_REQUIRE([AC_ISC_POSIX])dnl
  AC_MSG_CHECKING(if timezone is backwards)
  AC_CACHE_VAL(ac_cv_backwards_timezone,
  dnl Bletcherosity alert!  This will work for the USA and Europe, and 
  dnl countries sharing their timezones.  It will be exactly wrong for
  dnl the Atlantic ocean, bits of Russia, and minor third-world
  dnl countries.  The far East will default to "no," regardless of
  dnl platform.  If you can come up with something better, great --
  dnl Please let me know!
  [ AC_TRY_RUN([main(){
extern long timezone;
switch( timezone/3600 )
{
    /* OK: */
    case 5: case 6: case 7: case 8:	/* USA */
    case 0: case -1: case -2:		/* Europe */
        exit(0);
    /* Backwards: */
    case -5: case -6: case -7: case -8:	/* USA */
    case 1: case 2:			/* Europe */
        exit(1);
    /* Other country -- default to ok: */
    default:
        exit(0);
} return 0;}], ac_cv_backwards_timezone=no, ac_cv_backwards_timezone=yes,
  ac_cv_backwards_timezone=cross-compiling)])
  AC_MSG_RESULT($ac_cv_backwards_timezone)
if test $ac_cv_backwards_timezone = yes; then
  AC_DEFINE(NEGATIVE_TIMEZONE)
fi
fi
])dnl

# GWX_C_LONG_DOUBLE
# ----------------
AC_DEFUN([GWX_C_LONG_DOUBLE],
[AC_CACHE_CHECK(
   [for working long double with more range or precision than double],
   [ac_cv_c_long_double],
   [AC_COMPILE_IFELSE(
      [AC_LANG_BOOL_COMPILE_TRY(
	 [#include <float.h>
#ifdef _SCO_DS
#undef LDBL_MAX
#define LDBL_MAX 1.189731495357231748575e+4932
#endif
	  long double foo = 0.0;],
	 [/* Using '|' rather than '||' catches a GCC 2.95.2 x86 bug.  */
          (DBL_MAX < LDBL_MAX) | (LDBL_EPSILON < DBL_EPSILON)
	  | (DBL_MAX_EXP < LDBL_MAX_EXP) | (DBL_MANT_DIG < LDBL_MANT_DIG)])],
      ac_cv_c_long_double=yes,
      ac_cv_c_long_double=no)])
if test $ac_cv_c_long_double = yes; then
  AC_DEFINE(HAVE_LONG_DOUBLE, 1,
            [Define to 1 if long double works and has more range or precision than double.])
fi
])# GWX_C_LONG_DOUBLE

dnl AC_HEADER_INCLUDE(VARIABLE, INCLUDES)
AC_DEFUN(AC_HEADER_INCLUDE,
[ $1=""
  for ac_hdr in $2; do
    AC_TRY_CPP([#include <$ac_hdr>], [ $1="[#]include <$ac_hdr>"
break])
  done
])

dnl AC_DECL_NEED_SYS_ERR (Let me know if you have a better name.)
dnl Some systems don't have strerror; *do* have sys_errlist and sys_nerr,
dnl but don't declare them.  SunOS, for instance.
dnl This isn't a perfect test, but we can combine it with HAVE_STRERROR,
dnl HAVE_SYS_ERRLIST and HAVE_SYS_NERR.
AC_DEFUN(AC_DECL_NEED_SYS_ERR,
[ AC_MSG_CHECKING(if sys_errlist must be declared)
  AC_CACHE_VAL(ac_cv_decl_need_sys_errlist, 
  [ AC_HEADER_INCLUDE(tmp_inc_errno, errno.h sys/errno.h)
    AC_TRY_COMPILE([$tmp_inc_errno], [*sys_errlist;], 
      ac_cv_decl_need_sys_errlist=no, ac_cv_decl_need_sys_errlist=yes)])
  AC_MSG_RESULT($ac_cv_decl_need_sys_errlist)
  if test $ac_cv_decl_need_sys_errlist = yes ; then
    AC_DEFINE(NEED_SYS_ERRLIST_DECLARED)
  fi
  AC_MSG_CHECKING(if sys_nerr must be declared)
  AC_CACHE_VAL(ac_cv_decl_need_sys_nerr,
  [ AC_HEADER_INCLUDE(tmp_inc_errno, errno.h sys/errno.h)
    AC_TRY_COMPILE([$tmp_inc_errno], [sys_nerr;],
      ac_cv_decl_need_sys_nerr=no, ac_cv_decl_need_sys_nerr=yes)])
  AC_MSG_RESULT($ac_cv_decl_need_sys_nerr)
  if test $ac_cv_decl_need_sys_nerr = yes ; then
    AC_DEFINE(NEED_SYS_NERR_DECLARED)
  fi
])dnl

dnl
dnl The following stuff from GNU gettext.
dnl

AC_DEFUN([GWX_STDBOOL_H],
[dnl gcc 2.95.2 has an <stdbool.h> for which both 'true' and 'false' evaluate
dnl to 0 in preprocessor expressions.
AC_MSG_CHECKING([for stdbool.h])
AC_CACHE_VAL(gwx_cv_header_stdbool_h, [
  AC_TRY_COMPILE([#include <stdbool.h>
#if false
int A[-1];
#endif
#define b -1
#if true
#undef b
#define b 1
#endif
int B[b];
], [], gwx_cv_header_stdbool_h=yes, gwx_cv_header_stdbool_h=no)])
AC_MSG_RESULT([$gwx_cv_header_stdbool_h])
if test $gwx_cv_header_stdbool_h = yes; then
  AC_DEFINE(HAVE_STDBOOL_H, 1,
            [Define if you have a working <stdbool.h> header file.])
  STDBOOL_H=''
else
  STDBOOL_H='stdbool.h'
  AC_MSG_CHECKING([for _Bool type])
  AC_CACHE_VAL(gwx_cv_type_Bool, [
    AC_TRY_COMPILE([_Bool x = sizeof (_Bool);], [],
      gwx_cv_type_Bool=yes, gwx_cv_type_Bool=no)])
  AC_MSG_RESULT([$gt_cv_type_Bool])
  if test $gwx_cv_type_Bool = yes; then
    HAVE__BOOL=1
  else
    HAVE__BOOL=0
  fi
  AC_SUBST(HAVE__BOOL)
fi
AC_SUBST(STDBOOL_H)
])

AC_DEFUN([GWX_C_SIGNED],
[
  AC_CACHE_CHECK([for signed], gwx_cv_c_signed,
   [AC_TRY_COMPILE(, [signed char x;],gwx_cv_c_signed=yes,gwx_cv_c_signed=no)])
  if test $gwx_cv_c_signed = no; then
    AC_DEFINE(signed, ,
              [Define to empty if the C compiler doesn't support this keyword.])
  fi
])

AC_DEFUN([GWX_C_BACKSLASH_A],
[
  AC_CACHE_CHECK([whether backslash-a works in strings], gwx_cv_c_backslash_a,
   [AC_TRY_COMPILE([],
     [
#if '\a' == 'a'
      syntax error;
#endif
      char buf['\a' == 'a' ? -1 : 1];
      buf[0] = '\a';
      return buf[0] != "\a"[0];
     ],
     gwx_cv_c_backslash_a=yes,
     gwx_cv_c_backslash_a=no)])
  if test $gwx_cv_c_backslash_a = yes; then
    AC_DEFINE(HAVE_C_BACKSLASH_A, 1,
      [Define if backslash-a works in C strings.])
  fi
])

AC_DEFUN([GWX_TYPE_UNSIGNED_LONG_LONG],
[
  AC_CACHE_CHECK([for unsigned long long], gwx_type_unsigned_long_long,
  [AC_TRY_LINK([unsigned long long ull = 1; int i = 63;],
    [unsigned long long ullmax = (unsigned long long) -1;
     return ull << i | ull >> i | ullmax / ull | ullmax % ull;],
    gwx_type_unsigned_long_long=yes,
    gwx_type_unsigned_long_long=no)])
  if test $gwx_type_unsigned_long_long = yes; then
    AC_DEFINE(HAVE_UNSIGNED_LONG_LONG, 1,
      [Define if you have the unsigned long long type.])
  fi
])

AC_DEFUN([GWX_HEADER_INTTYPES_H],[
  AC_CACHE_CHECK([for inttypes.h], gwx_cv_header_inttypes_h,[
    AC_TRY_COMPILE([
#include <sys/types.h>
#include <inttypes.h>],
      [], gwx_cv_header_inttypes_h=yes, gwx_cv_header_inttypes_h=no)])
  if test $gwx_cv_header_inttypes_h = yes; then
    AC_DEFINE_UNQUOTED(HAVE_INTTYPES_H, 1,
      [Define if <inttypes.h> exists and doesn't clash with <sys/types.h>.])
  fi
])

AC_DEFUN([GWX_HEADER_INTTYPES_UINTMAX_H],[
  AC_CACHE_CHECK([for inttypes.h that declares uintmax_t],
    gwx_cv_header_inttypes_uintmax_h,[
    AC_TRY_COMPILE([
#include <sys/types.h>
#include <inttypes.h>],
      [uintmax_t i = (uintmax_t)-1;],
      gwx_cv_header_inttypes_uintmax_h=yes,
      gwx_cv_header_inttypes_uintmax_h=no)])
  if test $gwx_cv_header_inttypes_uintmax_h = yes; then
    AC_DEFINE_UNQUOTED(HAVE_INTTYPES_H_WITH_UINTMAX, 1,
      [Define if <inttypes.h> exists, doesn't clash with <sys/types.h>,
       and declares uintmax_t.])
  fi
])

AC_DEFUN([GWX_HEADER_STDINT_H],
[
  AC_CACHE_CHECK([for stdint.h], gwx_cv_header_stdint_h,[
   AC_TRY_COMPILE([
#include <sys/types.h>
#include <stdint.h>], [uintmax_t i = (uintmax_t) -1;],
    gwx_cv_header_stdint_h=yes, gwx_cv_header_stdint_h=no)])
  if test $gwx_cv_header_stdint_h = yes; then
    AC_DEFINE_UNQUOTED(HAVE_STDINT_H_WITH_UINTMAX, 1,
[Define if <stdint.h> exists, doesn't clash with <sys/types.h>,
   and declares uintmax_t. ])
  fi
])

AC_DEFUN([GWX_TYPE_UINTMAX_T],
[
  AC_REQUIRE([GWX_HEADER_INTTYPES_UINTMAX_H])
  AC_REQUIRE([GWX_HEADER_STDINT_H])
  if test $gwx_cv_header_inttypes_uintmax_h = no && test $gwx_cv_header_stdint_h = no; then
    AC_REQUIRE([GWX_TYPE_UNSIGNED_LONG_LONG])
    test $gwx_type_unsigned_long_long = yes \
      && ac_type='unsigned long long' \
      || ac_type='unsigned long'
    AC_DEFINE_UNQUOTED(uintmax_t, $ac_type,
  [Define to unsigned long or unsigned long long
   if <inttypes.h> and <stdint.h> don't define.])
  else
    AC_DEFINE(HAVE_UINTMAX_T, 1,
      [Define if you have the 'uintmax_t' type in <stdint.h> or <inttypes.h>.])
  fi
])

AC_DEFUN([GWX_INTTYPES_PRI],
[
  AC_REQUIRE([GWX_HEADER_INTTYPES_H])
  if test $gwx_cv_header_inttypes_h = yes; then
    AC_CACHE_CHECK([whether the inttypes.h PRIxNN macros are broken],
      gwx_cv_inttypes_pri_broken,
      [
        AC_TRY_COMPILE([#include <inttypes.h>
#ifdef PRId32
char *p = PRId32;
#endif
], [], gwx_cv_inttypes_pri_broken=no, gwx_cv_inttypes_pri_broken=yes)
      ])
  fi
  if test "$gwx_cv_inttypes_pri_broken" = yes; then
    AC_DEFINE_UNQUOTED(PRI_MACROS_BROKEN, 1,
      [Define if <inttypes.h> exists and defines unusable PRI* macros.])
  fi
])

# intdiv0.m4 serial 1 (gettext-0.11.3)
dnl Copyright (C) 2002 Free Software Foundation, Inc.
dnl This file is free software, distributed under the terms of the GNU
dnl General Public License.  As a special exception to the GNU General
dnl Public License, this file may be distributed as part of a program
dnl that contains a configuration script generated by Autoconf, under
dnl the same distribution terms as the rest of that program.

dnl From Bruno Haible.

AC_DEFUN([GWX_INTDIV0],
[
  AC_REQUIRE([AC_PROG_CC])dnl
  AC_REQUIRE([AC_CANONICAL_HOST])dnl

  AC_CACHE_CHECK([whether integer division by zero raises SIGFPE],
    gwx_cv_int_divbyzero_sigfpe,
    [
      AC_TRY_RUN([
#include <stdlib.h>
#include <signal.h>

static void
#ifdef __cplusplus
sigfpe_handler (int sig)
#else
sigfpe_handler (sig) int sig;
#endif
{
  /* Exit with code 0 if SIGFPE, with code 1 if any other signal.  */
  exit (sig != SIGFPE);
}

int x = 1;
int y = 0;
int z;
int nan;

int main ()
{
  signal (SIGFPE, sigfpe_handler);
/* IRIX and AIX (when "xlc -qcheck" is used) yield signal SIGTRAP.  */
#if (defined (__sgi) || defined (_AIX)) && defined (SIGTRAP)
  signal (SIGTRAP, sigfpe_handler);
#endif
/* Linux/SPARC yields signal SIGILL.  */
#if defined (__sparc__) && defined (__linux__)
  signal (SIGILL, sigfpe_handler);
#endif

  z = x / y;
  nan = y / y;
  exit (1);
}
], gwx_cv_int_divbyzero_sigfpe=yes, gwx_cv_int_divbyzero_sigfpe=no,
        [
          # Guess based on the CPU.
          case "$host_cpu" in
            alpha* | i[34567]86 | m68k | s390*)
              gwx_cv_int_divbyzero_sigfpe="guessing yes";;
            *)
              gwx_cv_int_divbyzero_sigfpe="guessing no";;
          esac
        ])
    ])
  case "$gwx_cv_int_divbyzero_sigfpe" in
    *yes) value=1;;
    *) value=0;;
  esac
  AC_DEFINE_UNQUOTED(INTDIV0_RAISES_SIGFPE, $value,
    [Define if integer division by zero raises signal SIGFPE.])
])

AC_DEFUN([GWX_FUNC_FNMATCH],[
  dnl Don't use AC_FUNC_FNMATCH. In autoconf-2.52 the test is buggy and
  dnl excludes all non-GNU implementations.
  dnl Some versions of Solaris or SCO have a broken fnmatch function.
  dnl So we run a test program.  If we are cross-compiling, take no chance.
  dnl Thanks to John Oleynick and Franc,ois Pinard for this test.
  AC_CACHE_CHECK([for working fnmatch function], gwx_cv_func_fnmatch_works, [
    AC_TRY_RUN([
#     include <stdlib.h>
#     include <fnmatch.h>
      int main ()
      {
        exit (fnmatch ("a*", "abc", 0) != 0
              || fnmatch ("d*/*1", "d/s/1", FNM_PATHNAME) != FNM_NOMATCH);
      }
      ],
      gwx_cv_func_fnmatch_works=yes, gwx_cv_func_fnmatch_works=no,
      gwx_cv_func_fnmatch_works=no  dnl cross-compiling
    )
  ])
  if test $gwx_cv_func_fnmatch_works = yes; then
    AC_DEFINE([HAVE_FNMATCH], 1,
      [Define if you have <fnmatch.h> and a working fnmatch() function.])
  fi
])

dnl See if there's a working, system-supplied version of the getline function.
dnl We can't just do AC_REPLACE_FUNCS(getline) because some systems
dnl have a function by that name in -linet that doesn't have anything
dnl to do with the function we need.
AC_DEFUN([GWX_FUNC_GETLINE],
[dnl
  gwx_getline_needs_run_time_check=no
  AC_CHECK_FUNC(getline,
		dnl Found it in some library.  Verify that it works.
		am_getline_needs_run_time_check=yes,
		gwx_cv_func_working_getline=no)
  if test $gwx_getline_needs_run_time_check = yes; then
    AC_CACHE_CHECK([for working getline function], gwx_cv_func_working_getline,
    [echo fooN |tr -d '\012'|tr N '\012' > conftest.data
    AC_TRY_RUN([
#    include <stdio.h>
#    include <stdlib.h>
#    include <string.h>
    int main ()
    { /* Based on a test program from Karl Heuer.  */
      char *line = NULL;
      size_t siz = 0;
      int len;
      FILE *in = fopen ("./conftest.data", "r");
      if (!in)
	return 1;
      len = getline (&line, &siz, in);
      exit ((len == 4 && line && strcmp (line, "foo\n") == 0) ? 0 : 1);
    }
    ], gwx_cv_func_working_getline=yes dnl The library version works.
    , gwx_cv_func_working_getline=no dnl The library version does NOT work.
    , gwx_cv_func_working_getline=no dnl We're cross compiling.
    )])
  fi
])

AC_DEFUN([GWX_FUNC_MBRTOWC],[
  AC_CACHE_CHECK([whether mbrtowc and mbstate_t are properly declared],
    gwx_cv_func_mbrtowc, [AC_TRY_LINK([#include <wchar.h>],
      [mbstate_t state; return ! (sizeof state && mbrtowc);],
      gwx_cv_func_mbrtowc=yes, gwx_cv_func_mbrtowc=no)])
  if test $gwx_cv_func_mbrtowc = yes; then
    AC_DEFINE(HAVE_MBRTOWC, 1,
      [Define to 1 if mbrtowc and mbstate_t are properly declared.])
  fi
])

AC_DEFUN([GWX_MBSTATE_T],[
   AC_CHECK_HEADERS(stdlib.h)
   AC_CACHE_CHECK([for mbstate_t], gwx_cv_type_mbstate_t,[
     AC_TRY_COMPILE([
#if HAVE_STDLIB_H
# include <stdlib.h>
#endif
#include <wchar.h>],
      [mbstate_t x; return sizeof x;],
      gwx_cv_type_mbstate_t=yes,
      gwx_cv_type_mbstate_t=no)])
   if test $gwx_cv_type_mbstate_t = no; then
     AC_DEFINE(mbstate_t, int,
	       [Define to a type if <wchar.h> does not define.])
   fi
])

AC_DEFUN([GWX_FUNC_MBSWIDTH],[
  AC_REQUIRE([AC_HEADER_STDC])
  GWX_FUNC_MBRTOWC

  AC_CACHE_CHECK([whether wcwidth is declared], gwx_cv_have_decl_wcwidth,
    [AC_TRY_COMPILE([
/* AIX 3.2.5 declares wcwidth in <string.h>. */
#if HAVE_STRING_H
# include <string.h>
#endif
#if HAVE_WCHAR_H
# include <wchar.h>
#endif
], [
#ifndef wcwidth
  char *p = (char *) wcwidth;
#endif
], gwx_cv_have_decl_wcwidth=yes, gwx_cv_have_decl_wcwidth=no)])
  if test $gwx_cv_have_decl_wcwidth = yes; then
    ac_val=1
  else
    ac_val=0
  fi
  AC_DEFINE_UNQUOTED(HAVE_DECL_WCWIDTH, $ac_val,
    [Define to 1 if you have the declaration of wcwidth(), and to 0 otherwise.])

  GWX_MBSTATE_T
])

AC_DEFUN([GWX_UNION_WAIT],[
  AC_MSG_CHECKING(for union wait)
  AC_CACHE_VAL(gwx_cv_union_wait, [dnl
    AC_TRY_LINK([
#include <sys/types.h>
#include <sys/wait.h>],
	    [union wait status; int pid; pid = wait (&status);
#ifdef WEXITSTATUS
/* Some POSIXoid systems have both the new-style macros and the old
   union wait type, and they do not work together.  If union wait
   conflicts with WEXITSTATUS et al, we don't want to use it at all.  */
if (WEXITSTATUS (status) != 0) pid = -1;
#ifdef WTERMSIG
/* If we have WEXITSTATUS and WTERMSIG, just use them on ints.  */
-- blow chunks here --
#endif
#endif
#ifdef HAVE_WAITPID
/* Make sure union wait works with waitpid.  */
pid = waitpid (-1, &status, 0);
#endif
],
	    [gwx_cv_union_wait=yes], [gwx_cv_union_wait=no])])
  if test "$gwx_cv_union_wait" = yes; then
    AC_DEFINE(HAVE_UNION_WAIT, 1,
            [Define if <sys/wait.h> defines the 'union wait' type.])
  fi
  AC_MSG_RESULT($gt_cv_union_wait)
])

AC_DEFUN([GWX_SIGNALBLOCKING],[
  signals_not_posix=
  AC_EGREP_HEADER(sigset_t, signal.h, , signals_not_posix=1)
  if test -z "$signals_not_posix"; then
    AC_CHECK_FUNC(sigprocmask, AC_DEFINE(HAVE_POSIX_SIGNALBLOCKING, 1,
     [Define to 1 if you have the sigset_t type and the sigprocmask function.]))
  fi
])

AC_DEFUN([GWX_SIGINFO],[
  AC_CACHE_CHECK([for signal handlers with siginfo_t], gwx_cv_siginfo_t,[
    AC_TRY_COMPILE([
#include <signal.h>], [
struct sigaction action;
siginfo_t info;
action.sa_flags = SA_SIGINFO;
action.sa_sigaction = (void *) 0;
], gwx_cv_siginfo_t=yes, gwx_cv_siginfo_t=no)])
  if test $gwx_cv_siginfo_t = yes; then
    AC_DEFINE(HAVE_SIGINFO, 1,
      [Define to 1 if <signal.h> defines the siginfo_t type,
   and struct sigaction has the sa_sigaction member and the SA_SIGINFO flag.])
  fi
])

# GWX_CHECK_VAR_DECL(includes,variable)
AC_DEFUN([GWX_CHECK_VAR_DECL],[
  define(gwx_cv_var, [gwx_cv_var_]$2[_declaration])
  AC_MSG_CHECKING([if $2 is properly declared])
  AC_CACHE_VAL(gwx_cv_var, [
    AC_TRY_COMPILE([$1
      extern struct { int foo; } $2;], [$2.foo = 1;],
      gwx_cv_var=no,
      gwx_cv_var=yes)])
  AC_MSG_RESULT($gwx_cv_var)
  if test $gwx_cv_var = yes; then
    AC_DEFINE([HAVE_]translit($2, [a-z], [A-Z])[_DECL], 1,
              [Define if you have the declaration of $2.])
  fi
])

AC_DEFUN([GWX_FUNC_ERROR_AT_LINE],[
  AC_CACHE_CHECK([for error_at_line], am_cv_lib_error_at_line,
   [AC_TRY_LINK([],[error_at_line(0, 0, "", 0, "");],
                am_cv_lib_error_at_line=yes,
	        am_cv_lib_error_at_line=no)])
  if test $am_cv_lib_error_at_line = yes; then
    AC_DEFINE(HAVE_ERROR_AT_LINE, 1,
      [Define to 1 if you have the functions error() and error_at_line().])
  fi
])

AC_DEFUN([GWX_FUNC_SETLOCALE],[
  AC_MSG_CHECKING([for setlocale declaration])
  AC_CACHE_VAL(gwx_cv_proto_setlocale, [
    AC_TRY_COMPILE([
#include <stdlib.h>
#include <locale.h>
extern
#ifdef __cplusplus
"C"
#endif
#if defined(__STDC__) || defined(__cplusplus)
char *setlocale (int category, char *locale);
#else
char *setlocale();
#endif
], [], gwx_cv_proto_setlocale_arg1="", gwx_cv_proto_setlocale_arg1="const")
gwx_cv_proto_setlocale="extern char *setlocale (int category, $gwx_cv_proto_setlocale_arg1 char *locale);"])
  gwx_cv_proto_setlocale=`echo "[$]gt_cv_proto_setlocale" | tr -s ' ' | sed -e 's/( /(/'`
  AC_MSG_RESULT([$]{ac_t:-
         }[$]gwx_cv_proto_setlocale)
  AC_DEFINE_UNQUOTED(SETLOCALE_CONST,$gwx_cv_proto_setlocale_arg1,
    [Define as const if the declaration of setlocale() needs const.])
])

dnl This is from cURL

dnl Check for how to set a socket to non-blocking state. There seems to exist
dnl four known different ways, with the one used almost everywhere being POSIX
dnl and XPG3, while the other different ways for different systems (old BSD,
dnl Windows and Amiga).
dnl
dnl There are two known platforms (AIX 3.x and SunOS 4.1.x) where the
dnl O_NONBLOCK define is found but does not work. This condition is attempted
dnl to get caught in this script by using an excessive number of #ifdefs...
dnl
AC_DEFUN(CURL_CHECK_NONBLOCKING_SOCKET,
[
  AC_MSG_CHECKING([non-blocking sockets style])

  AC_TRY_COMPILE([
/* headers for O_NONBLOCK test */
#include <sys/types.h>
#include <unistd.h>
#include <fcntl.h>
],[
/* try to compile O_NONBLOCK */

#if defined(sun) || defined(__sun__) || defined(__SUNPRO_C) || defined(__SUNPRO_CC)
# if defined(__SVR4) || defined(__srv4__)
#  define PLATFORM_SOLARIS
# else
#  define PLATFORM_SUNOS4
# endif
#endif
#if (defined(_AIX) || defined(__xlC__)) && !defined(_AIX4)
# define PLATFORM_AIX_V3
#endif

#if defined(PLATFORM_SUNOS4) || defined(PLATFORM_AIX_V3)
#error "O_NONBLOCK does not work on this platform"
#endif
  int socket;
  int flags = fcntl(socket, F_SETFL, flags | O_NONBLOCK);
],[
dnl the O_NONBLOCK test was fine
nonblock="O_NONBLOCK"
AC_DEFINE(HAVE_O_NONBLOCK, 1, [use O_NONBLOCK for non-blocking sockets])
],[
dnl the code was bad, try a different program now, test 2

  AC_TRY_COMPILE([
/* headers for FIONBIO test */
#include <unistd.h>
#include <stropts.h>
],[
/* FIONBIO source test */
 int flags = ioctl(socket, FIONBIO, &flags);
],[
dnl FIONBIO test was good
nonblock="FIONBIO"
AC_DEFINE(HAVE_FIONBIO, 1, [use FIONBIO for non-blocking sockets])
],[
dnl FIONBIO test was also bad
dnl the code was bad, try a different program now, test 3

  AC_TRY_COMPILE([
/* headers for ioctlsocket test (cygwin?) */
#include <windows.h>
],[
/* ioctlsocket source code */
 int flags = ioctlsocket(socket, FIONBIO, &flags);
],[
dnl ioctlsocket test was good
nonblock="ioctlsocket"
AC_DEFINE(HAVE_IOCTLSOCKET, 1, [use ioctlsocket() for non-blocking sockets])
],[
dnl ioctlsocket didnt compile!

  AC_TRY_COMPILE([
/* headers for IoctlSocket test (Amiga?) */
#include <sys/ioctl.h>
],[
/* IoctlSocket source code */
 int flags = IoctlSocket(socket, FIONBIO, (long)1);
],[
dnl ioctlsocket test was good
nonblock="IoctlSocket"
AC_DEFINE(HAVE_IOCTLSOCKET_CASE, 1, [use Ioctlsocket() for non-blocking sockets])
],[
dnl ioctlsocket didnt compile!
nonblock="nada"
AC_DEFINE(HAVE_DISABLED_NONBLOCKING, 1, [disabled non-blocking sockets])
])
dnl end of forth test

])
dnl end of third test

])
dnl end of second test

])
dnl end of non-blocking try-compile test
  AC_MSG_RESULT($nonblock)

  if test "$nonblock" = "nada"; then
    AC_MSG_WARN([non-block sockets disabled])
  fi
])

dnl Check for socklen_t: historically on BSD it is an int, and in
dnl POSIX 1g it is a type of its own, but some platforms use different
dnl types for the argument to getsockopt, getpeername, etc.  So we
dnl have to test to find something that will work.
AC_DEFUN([TYPE_SOCKLEN_T],
[
   AC_CHECK_TYPE([socklen_t], [
      SOCKLEN_T=socklen_t
      AC_DEFINE_UNQUOTED(SOCKLEN_T, $SOCKLEN_T,
			[generic type to use in place of socklen_t])],[
      AC_MSG_CHECKING([for socklen_t equivalent])
      AC_CACHE_VAL([curl_cv_socklen_t_equiv],
      [
         # Systems have either "struct sockaddr *" or
         # "void *" as the second argument to getpeername
         curl_cv_socklen_t_equiv=
         for arg2 in "struct sockaddr" void; do
            for t in size_t int unsigned long "unsigned long"; do
               AC_TRY_COMPILE([
                  #include <sys/types.h>
                  #include <sys/socket.h>

                  int getpeername (int, $arg2 *, $t *);
               ],[
                  $t len;
                  getpeername(0,0,&len);
               ],[
                  curl_cv_socklen_t_equiv="$t"
                  break
               ])
            done
         done

         if test "x$curl_cv_socklen_t_equiv" = x; then
            AC_MSG_ERROR([Cannot find a type to use in place of socklen_t])
         fi
      ])
      AC_MSG_RESULT($curl_cv_socklen_t_equiv)
      SOCKLEN_T=$curl_cv_socklen_t_equiv
      AC_DEFINE_UNQUOTED(socklen_t, $curl_cv_socklen_t_equiv,
			[type to use in place of socklen_t if not defined])
      AC_DEFINE_UNQUOTED(SOCKLEN_T, $curl_cv_socklen_t_equiv,
			[generic type to use in place of socklen_t])],
      [#include <sys/types.h>
#include <sys/socket.h>])
])

dnl Check for in_addr_t: it is used to receive the return code of inet_addr()
dnl and a few other things. If not found, we set it to unsigned int, as even
dnl 64-bit implementations use to set it to a 32-bit type.
AC_DEFUN([TYPE_IN_ADDR_T],
[
   AC_CHECK_TYPE([in_addr_t], ,[
      AC_MSG_CHECKING([for in_addr_t equivalent])
      AC_CACHE_VAL([curl_cv_in_addr_t_equiv],
      [
         # Systems have either "struct sockaddr *" or
         # "void *" as the second argument to getpeername
         curl_cv_in_addr_t_equiv=
         for t in int size_t unsigned long "unsigned long"; do
            AC_TRY_COMPILE([
               #include <sys/types.h>
               #include <sys/socket.h>
               #include <arpa/inet.h>
            ],[
               $t data = inet_addr ("1.2.3.4");
            ],[
               curl_cv_in_addr_t_equiv="$t"
               break
            ])
         done

         if test "x$curl_cv_in_addr_t_equiv" = x; then
            AC_MSG_ERROR([Cannot find a type to use in place of in_addr_t])
         fi
      ])
      AC_MSG_RESULT($curl_cv_in_addr_t_equiv)
      AC_DEFINE_UNQUOTED(in_addr_t, $curl_cv_in_addr_t_equiv,
			[type to use in place of in_addr_t if not defined])],
      [#include <sys/types.h>
#include <sys/socket.h>
#include <arpa/inet.h>])
])

