/* gwxcfg.h - Control GWXlibs configuration options
Copyright (C) 1998,2001,2002 J. Kean Johnston. All rights reserved.
$Id$

GWXLIBS is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GWXLIBS is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
License for more details.

You should have received a copy of the GNU General Public License
along with GWXLIBS; see the file COPYING.  If not, write to the Free
Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */

#if !defined(GWXCFG_HDR)
#define GWXCFG_HDR

#include "gwxoscfg.h"

/*
This section controls which of the various libraries are to be built.
Some libraries depend on others, so you should be careful when disabling
libraries, as this may well result in other libraries not being built,
or being built differently than you would expect. There really is little
reason why you wouldn't want to compile all of these libraries. They operate
well together.

To prevent a specific library from being compiled, set the appropriate
macro value to 0.
*/

/*
 * Debugging support
 *
 * If you enable this option, then you enable debugging support for ALL
 * libraries that have special debuging features. If you leave this option
 * off (the default), then all programs are compiled with -DNDEBUG, which
 * will turn any assertions in the code off. If you want to disable
 * debugging but leave assertions alone, set the assertion option to 1.
 */
#define GWX_GLOBAL_DEBUGGING	0	/* No debugging thanks */
#define GWX_GLOBAL_ASSERTIONS	1	/* But leave assertions on */
#define GWX_GLOBAL_THREADS	1	/* Use threads wherever appropriate */

/*
 * PKGCONFIG support.
 *
 * Many packages provice pkgconfig script files. These can be used by
 * applications to determine the correct compiler and linker flags to
 * use a given library. It is suggested that you enable this. But only
 * do so if you do not already have pkgconfig installed. If you do,
 * then you will need to manually copy the .pc files to wherever your
 * pkgconfig data files need to go.
 */
#define GWX_USE_PKGCONFIG	1	/* Yes, compile and use it please */

#define GWX_COMPILE_GETTEXT	1
#define GWX_COMPILE_ZLIB	1
#define GWX_COMPILE_BZIP2	1
#define GWX_COMPILE_JPEG	1
#define GWX_COMPILE_JASPER	1
#define GWX_COMPILE_JBIG	1
#define GWX_COMPILE_TIFF	1
#define GWX_COMPILE_PNG		1
#define GWX_COMPILE_LCMS	1
#define GWX_COMPILE_MNG		1
#define GWX_COMPILE_XPM		1
#define GWX_COMPILE_FREETYPE1	1
#define GWX_COMPILE_FREETYPE2	1
#define GWX_COMPILE_FONTCONFIG	1
#define GWX_COMPILE_GD1		1
#define GWX_COMPILE_GD2		1
#define GWX_COMPILE_GIFLIB	1
#define GWX_COMPILE_COMPFACE	1
#define GWX_COMPILE_MPEGLIB	1
#define GWX_COMPILE_NETPBM	1
#define GWX_COMPILE_GTKPLUS1	1
#define GWX_COMPILE_GTKPLUS2	1
#define GWX_COMPILE_IMLIB	1
#define GWX_COMPILE_READLINE	1
#define GWX_COMPILE_XAW3D	1
#define GWX_COMPILE_SLANG	1
#define GWX_COMPILE_GDBM	1
#define GWX_COMPILE_DB		1
#define GWX_COMPILE_EXPAT	1
#define GWX_COMPILE_XML2	1
#define GWX_COMPILE_XSLT	1
#define GWX_COMPILE_GDOME	1
#define GWX_COMPILE_MD5		1
#define GWX_COMPILE_RAND	1
#define GWX_COMPILE_OPENSLP	1
#define GWX_COMPILE_SASL	1
#define GWX_COMPILE_LDAP	1
#define GWX_COMPILE_LIBWWW	1
#define GWX_COMPILE_IDL		1
#define GWX_COMPILE_OPENSSL	1
#define GWX_COMPILE_XMLSEC1	1
#define GWX_COMPILE_MM		1
#define GWX_COMPILE_PCRE	1
#define GWX_COMPILE_GHTTP	1
#define GWX_COMPILE_CURL	1
#define GWX_COMPILE_JAVASCRIPT	1
#define GWX_COMPILE_SABLOT	1

/*
 * Shared library version names. Each of these is a list of library version
 * numbers ONLY, with the first being the name that will be inserted into the
 * actual shared library, and will be used by the dynamic loader as the file
 * name (i.e. this is the name you will see in ldd output).
 */
#define GWX_NAME_GETTEXT	"4:0:2" GWX_NAME_GETTEXT_OS
#define GWX_NAME_ZLIB		"1:3:0" GWX_NAME_ZLIB_OS
#define GWX_NAME_BZIP2		"1:0:0" GWX_NAME_BZIP2_OS
#define GWX_NAME_TIFF		"3:6:0" GWX_NAME_TIFF_OS
#define GWX_NAME_JPEG		"62:0:0" GWX_NAME_JPEG_OS
#define GWX_NAME_JASPER		"3:0:0" GWX_NAME_JASPER_OS
#define GWX_NAME_PNG		"2:2:0" GWX_NAME_PNG_OS
#define GWX_NAME_MNG		"1:0:0" GWX_NAME_MNG_OS
#define GWX_NAME_JBIG		"1:0:0" GWX_NAME_JBIG_OS
#define GWX_NAME_FREETYPE1	"2:0:0" GWX_NAME_FREETYPE1_OS
#define GWX_NAME_FREETYPE2	"9:4:3" GWX_NAME_FREETYPE2_OS
#define GWX_NAME_FONTCONFIG	"1:4:0" GWX_NAME_FONTCONFIG_OS
#define GWX_NAME_GD1		"1:8:0" GWX_NAME_GD1_OS
#define GWX_NAME_GD2		"2:0:0" GWX_NAME_GD2_OS
#define GWX_NAME_GIFLIB		"3:0:0" GWX_NAME_GIFLIB_OS
#define GWX_NAME_COMPFACE	"1:1:0" GWX_NAME_COMPFACE_OS
#define GWX_NAME_XPM		"3:3:0" GWX_NAME_XPM_OS
#define GWX_NAME_MPEGLIB	"2:1:2" GWX_NAME_MPEGLIB_OS
#define GWX_NAME_IMLIB		"10:11:9" GWX_NAME_IMLIB_OS
#define GWX_NAME_GDKIMLIB	"10:11:9" GWX_NAME_GDKIMLIB_OS
#define GWX_NAME_GTK1		"2:1:0" GWX_NAME_GTK1_OS
#define GWX_NAME_GDK1		"2:1:0" GWX_NAME_GDK1_OS
#define GWX_NAME_GLIB1		"2:1:0" GWX_NAME_GLIB1_OS
#define GWX_NAME_GMODULE1	"2:1:0" GWX_NAME_GMODULE1_OS
#define GWX_NAME_GTHREAD1	"2:1:0" GWX_NAME_GTHREAD1_OS
#define GWX_NAME_GTK2		"200:4:200" GWX_NAME_GTK2_OS
#define GWX_NAME_GDK2PIXBUF	"200:4:200" GWX_NAME_GDK2PIXBUF_OS
#define GWX_NAME_GDK2LFB	"200:4:200" GWX_NAME_GDK2LFB_OS
#define GWX_NAME_GDK2X11	"200:4:200" GWX_NAME_GDK2X11_OS
#define GWX_NAME_GLIB2		"200:3:200" GWX_NAME_GLIB2_OS
#define GWX_NAME_GMODULE2	"200:3:200" GWX_NAME_GMODULE2_OS
#define GWX_NAME_GTHREAD2	"200:3:200" GWX_NAME_GTHREAD2_OS
#define GWX_NAME_GOBJECT2	"200:3:200" GWX_NAME_GOBJECT2_OS
#define GWX_NAME_ATK		"200:4:200" GWX_NAME_ATK_OS
#define GWX_NAME_PANGO		"200:5:200" GWX_NAME_PANGO_OS
#define GWX_NAME_PANGOX		"200:5:200" GWX_NAME_PANGOX_OS
#define GWX_NAME_PANGOXFT	"200:5:200" GWX_NAME_PANGOXFT_OS
#define GWX_NAME_PANGOFT2	"200:5:200" GWX_NAME_PANGOFT2_OS
#define GWX_NAME_SLANG		"1:4:0" GWX_NAME_SLANG_OS
#define GWX_NAME_READLINE	"4:0:0" GWX_NAME_READLINE_OS
#define GWX_NAME_NETPBM		"10:0:0" GWX_NAME_NETPBM_OS
#define GWX_NAME_XAW3DR5	"5:0:0" GWX_NAME_XAW3DR5_OS
#define GWX_NAME_XAW3DR6	"6:0:0" GWX_NAME_XAW3DR6_OS
#define GWX_NAME_SASL		"2:9:0" GWX_NAME_SASL_OS
#define GWX_NAME_LDAP		"2:103:0" GWX_NAME_LDAP_OS
#define GWX_NAME_LIBWWW		"1:0:1" GWX_NAME_LIBWWW_OS
#define GWX_NAME_GDBM		"1:0:0" GWX_NAME_GDBM_OS
#define GWX_NAME_DB		"4:0:0" GWX_NAME_DB_OS
#define GWX_NAME_DBCXX		"4:0:0" GWX_NAME_DBCXX_OS
#define GWX_NAME_EXPAT		"5:0:5" GWX_NAME_EXPAT_OS
#define GWX_NAME_XML2		"8:1:6" GWX_NAME_XML2_OS
#define GWX_NAME_XSLT		"1:33:0" GWX_NAME_XSLT_OS
#define GWX_NAME_EXSLT		"7:22:7" GWX_NAME_EXSLT_OS
#define GWX_NAME_GDOME		"8:0:8" GWX_NAME_GDOME_OS
#define GWX_NAME_MD5		"1:0:0" GWX_NAME_MD5_OS
#define GWX_NAME_RAND		"1:0:0" GWX_NAME_RAND_OS
#define GWX_NAME_OPENSLP	"1:0:0" GWX_NAME_OPENSLP_OS
#define GWX_NAME_CRYPTO		"0:9:6" GWX_NAME_CRYPTO_OS
#define GWX_NAME_SSL		"0:9:6" GWX_NAME_SSL_OS
#define GWX_NAME_XMLSEC1	"3:1:2" GWX_NAME_XMLSEC1_OS
#define GWX_NAME_LCMS		"1:0:0" GWX_NAME_LCMS_OS
#define GWX_NAME_IDL		"0:0:0" GWX_NAME_IDL_OS
#define GWX_NAME_MM		"13:20" GWX_NAME_MM_OS
#define GWX_NAME_PCRE		"0:1:0" GWX_NAME_PCRE_OS
#define GWX_NAME_GHTTP		"1:0:0" GWX_NAME_GHTTP_OS
#define GWX_NAME_CURL		"2:2:0" GWX_NAME_CURL_OS
#define GWX_NAME_JAVASCRIPT	"1:0:0" GWX_NAME_JAVASCRIPT_OS
#define GWX_NAME_SABLOT		"100:0:100" GWX_NAME_SABLOT_OS

/*
*** Compile time options for library: zlib
*/
#define GWX_ZLIB_586ASM		0	/* Chose one of 586 or 686 based */
#define GWX_ZLIB_686ASM		1	/* assembler optimizations	 */

/*
*** Compile time options for library: tiff
*/
#define GWX_TIFF_PSP		1
#define GWX_TIFF_IPTC		1
#define GWX_TIFF_JPEG		1
#define GWX_TIFF_OJPEG		1
#define GWX_TIFF_ZLIB		1
#define GWX_TIFF_CCITT		1
#define GWX_TIFF_PACKBITS	1
#define GWX_TIFF_LZW		1
#define GWX_TIFF_THUNDER	1
#define GWX_TIFF_NEXT		1
#define GWX_TIFF_PIXARLOG	1
#define GWX_TIFF_LOGLUV		1
#define GWX_TIFF_COLORIMETRY	1
#define GWX_TIFF_YCBCR		1
#define GWX_TIFF_CMYK		1
#define GWX_TIFF_ICC		1
#define GWX_TIFF_SUBIFD		1

/*
*** Compile time options for library: jpeg
*/

/* Define if you want cjpeg/djpeg to show progress reports */
#define GWX_JPEG_PROGRESS	0

/*
 * Define if you want to be able to specify both input and output files
 * on the cjpeg/djpeg command lines instead of using stdout / stdin. MUST
 * set this if your system cannot do binary I/O on stdio streams.
 */
#define GWX_JPEG_TWOFILE	0

/* Select image file formats you want [cd]jpeg to grok */
#define GWX_JPEG_BMP		1
#define GWX_JPEG_GIF		1
#define GWX_JPEG_PPM		1
#define GWX_JPEG_RLE		0
#define GWX_JPEG_TARGA		1

/*
*** Compile time options for library: jasper
*/

/*
*** Compile time options for library: PNG
*/

/*
 * None defined here, but you may want to look at png/pngconf.h
 */

/*
*** Compile time options for library: JBIG
*/

/*
*** Compile time options for library: FREETYPE1
*** NOTE: The first two options apply to FREETYPE2 as well.
*/
#define GWX_FREETYPE_EXTENDED	1
#define GWX_FREETYPE_GRAYSCALE	1
#define GWX_FREETYPE_INTSWITCH	1
#define GWX_FREETYPE_THREADED	0  /* GWX_GLOBAL_THREADS */
#define GWX_FREETYPE_NLS	0  /* For the time being, do NOT enable NLS */

/*
*** Compile time options for library: FREETYPE2
***
*** NOTE: You should read the comments in the file
*** freetype2/include/freetype/config/ftoption.h.in carefully
*** before changing these defaults. There are some other settings
*** in there that you can not change here. You may want to review
*** that file for fine-tuning FreeType 2.
*/
#define GWX_FT2_FORCE_INT64	0	/* Force 64-bit in support */
#define GWX_FT2_GZIP		1	/* Support loading compressed fonts */
#define GWX_FT2_PS_NAMES	1	/* Include PSNames module */
#define GWX_FT2_ADOBE_NAMES	1	/* ... with the Adobe Glyph List */
#define GWX_FT2_INCREMENTAL	1	/* Aids GhostScript interface */
#define GWX_FT2_MACFONTS	1	/* Dont undefine */
#define GWX_FT2_DEBUG_ERROR	0	/* Compile in debug mode */
#define GWX_FT2_DEBUG_TRACE	0	/* ... with trace code */
#define GWX_FT2_DEBUG_MEM	0	/* ... and memory checks */
#define GWX_FT2_MODULE_ERRS	0	/* Encode module in error numbers */
#define GWX_FT2_EMB_BITMAPS	1	/* SFNT: Use embedded bitmaps */
#define GWX_FT2_TTPSNAMES	1	/* SFNT: use PSNames module */
#define GWX_FT2_TTSFNTNAMES	1	/* SFNT: use SFNTnames module */
#define GWX_FT2_BYTECODE	1	/* Include bytecode interpreter */
#define GWX_FT2_NO_AFM		0	/* Disable AFM loader */
#define GWX_FT2_NO_MULTIMASTER	0	/* Disable multiple masters supprot */

/*
*** Compile time options for library: GD1/GD2
*/
#define GWX_GD_JPEG		1	/* Include JPEG support */
#define GWX_GD_PNG		1	/* Include PNG support */
#define GWX_GD_XPM		1	/* Include Xpm support */
#define GWX_GD_FREETYPE1	1	/* Include ttf support */
#define GWX_GD_FREETYPE2	1	/* Include freetype support */

/*
*** Compile time options for library: GIFLIB
*/
#define GWX_GIFLIB_GRABX11	1       /* Grab images from X11         */
#define GWX_GIFLIB_GRABSGIGL	0       /* Grab images from SGI GL      */

/*
*** Compile time options for library: COMPFACE
*/

/*
*** Compile time options for library: XPM
*/

/*
*** Compile time options for library: MPEGLIB
*/
#define GWX_MPEGLIB_DITHER	1       /* Enable dithering support     */

/*
*** Compile time options for library: IMLIB
*/

/*
 * Compile time options for both verions of library: GTK+
 */
#define GWX_GTK_THREADS		GWX_GLOBAL_THREADS
#define GWX_GTK_XIM		1	/* Support XIM if available     */
#define GWX_GTK_XIM_INST	1	/* Use XIM instantiate callback */
#define GWX_GTK_XINPUT_GXI	0	/* Support GXI Input if avail   */
#define GWX_GTK_XINPUT_XF86	0	/* Support XFree86 Xi           */
#define GWX_GTK_SHM		1	/* Use shared memory if avail   */

/*
*** Compile time options for library: GTK+
*/

/*
*** Compile time options for library: GTK+-2.0
*/
#define GWX_GTK2_GCFRIENDLY	0	/* Glib is GC-friendly */
#define GWX_GTK2_NOPOOLS	0	/* Diable all memory pools in GLib */
#define GWX_GTK2_LINUXFB	0	/* If 0, X11 is default target */
#define GWX_GTK2_NOSHADOWFB	0	/* Disable shadow fb support */
#define GWX_GTK2_FBMANAGER	0	/* Enable FB manager support */
#define GWX_GTK2_MODULES	1	/* Support loadable modules */

/*
*** Compile time options for library: Slang
*/

/*
*** Compile time options for library: readline
*/
#define GWX_READLINE_CURSES	1       /* Use curses instead of termcap */

/*
*** Compile time options for library: NetPBM
*/
#define GWX_NETPBM_ARGVSWITCH	1	/* Use argv0 switch not unique files */

/*
*** Compile time options for library: Xaw3D
*/

/*
*** Compile time options for library: GDBM
*/

/*
*** Compile time options for library: Berkley DB 4.1.24
*/
#define GWX_DB_CRYPTO		1	/* Cryptography support */
#define GWX_DB_COMPAT185	1	/* Build 1.85 compatibility API */
#define GWX_DB_CXX		1	/* Build C++ API */
#define GWX_DB_DEBUG		0	/* Build a debugging version */
#define GWX_DB_ROP		0	/*    that logs read operations */
#define GWX_DB_WOP		0	/*    that logs write operations */
#define GWX_DB_DIAGS		0	/*    that contains runtime diags */
#define GWX_DB_POSIXMTX		0	/* Force use of POSIX mutexes */
#define GWX_DB_UIMTX		0	/* Force use of UNIX Intl mutexes */
#define GWX_DB_UMRW		0	/* Mask harmless uninitialized mem */
#define GWX_DB_RPC		1	/* Include RPC client/server code */
#define GWX_DB_UNIQUENAMES	0	/* Use unique names (not recommended) */

/*
*** Compile time options for library: expat
*/

/*
*** Compile time options for library: xml2
*/
#define GWX_XML2_ZLIB		1	/* Support compressed data */
#define GWX_XML2_USEBUFS	1	/* Use buffers for node content */
#define GWX_XML2_PUSH		1	/* Enable PUSH support */
#define GWX_XML2_TREE		1	/* Enable DOM-like tree support */
#define GWX_XML2_OUTPUT		1	/* Enable serialization/saving */
#define GWX_XML2_READER		1	/* Enable reader interface */
#define GWX_XML2_WRITER		1	/* Enable reader interface */
#define GWX_XML2_SAX1		1	/* Enable older SAX interface */
#define GWX_XML2_FTP		1	/* Enable FTP support */
#define GWX_XML2_HTTP		1	/* Enable HTTP support */
#define GWX_XML2_VALID		1	/* Enable DTD validation support */
#define GWX_XML2_HTML		1	/* Enable HTML support */
#define GWX_XML2_LEGACY		1	/* Enable legacy API support */
#define GWX_XML2_C14N		1	/* Enable Canonicalization support */
#define GWX_XML2_CATALOG	1	/* Enable catalog support */
#define GWX_XML2_DOCBOOK	1	/* Enable DocBook support */
#define GWX_XML2_XPATH		1	/* Enable XPath support */
#define GWX_XML2_XPOINTER	1	/* Enable XPointer support */
#define GWX_XML2_XINCLUDE	1	/* Enable XInclude support */
#define GWX_XML2_SCHEMAS	1	/* Enable experimental schema support */
#define GWX_XML2_THREADS	GWX_GLOBAL_THREADS
#define GWX_XML2_THREADMEM	0	/* Add per-thread memory */
#define GWX_XML2_REGEXP		1	/* Enable regexp support */
#define GWX_XML2_ICONV		1	/* Enable iconv support */
#define GWX_XML2_ISO8859	1	/* Fallback to ISO8859 if no iconv */
#define GWX_XML2_DEBUG		1	/* Enable debugging support */
#define GWX_XML2_MEMDEBUG	0	/* Enable memory debugging support */

/*
*** Compile time options for library: xslt
*/
#define GWX_XSLT_DEBUG		1	/* Enable debugging (recommended) */
#define GWX_XSLT_MEMDEBUG	0	/* Enable memory debugging (dont) */
#define GWX_XSLT_DEBUGGER	1	/* Enable debugger (recommended) */

/*
*** Compile time options for library: gdome2
*/

/*
*** Compile time options for library: md5
*/

/*
*** Compile time options for library: truerand
*/

/*
*** Compile time options for library: SASL
*/
#define GWX_SASL_SASLAUTHD	1	/* Compile saslauthd? */
#define GWX_SASL_CHECKAPOP	1	/* sasl_checkapop support */
#define GWX_SASL_CRAM_MD5	1	/* CRAM-MD5 authentication */
#define GWX_SASL_DIGEST_MD5	1	/* MD5 Digest authentication */
#define GWX_SASL_OTP		1	/* OTP authentication */
#define GWX_SASL_OPIE		0	/* Onetime passwords in everything */
#define GWX_SASL_SRP		1	/* SRP authentication */
#define GWX_SASL_SRPSETPASS	1	/* Enable setting SRP passwords */
#define GWX_SASL_ANON		1	/* Enable anoymous authentication */
#define GWX_SASL_PLAIN		1	/* Enable PLAIN authentication */
#define GWX_SASL_DB		1	/* Enable database authentication */
#define GWX_SASL_LDAP		1	/* Enable LDAP authentication */

/*
*** Compile time options for library: OpenSLP
*/
#define GWX_SLP_SLPV1		1	/* SLPv1 support enabled */
#define GWX_SLP_PREDICATES	1	/* Enable predicates */
#define GWX_SLP_ASYNC		0	/* Turn on asynchronous support */
#define GWX_SLP_SECURITY	1	/* Turn on SLPv2 security support */

/*
*** Compile time options for library: MNG
*/

/*
*** Compile time options for library: XMLSEC
*/
#define GWX_XMLSEC_SHA1		1	/* Enable SHA1 support */
#define GWX_XMLSEC_RIPEMD160	1	/* Enable RIPEMD-160 support */
#define GWX_XMLSEC_HMAC		1	/* Enable HMAC support */
#define GWX_XMLSEC_DSA		1	/* Eanble DSA support */
#define GWX_XMLSEC_RSA		1	/* Enable RSA support */
#define GWX_XMLSEC_X509		1	/* Enable X509 support */
#define GWX_XMLSEC_DES		1	/* Enable DES support */
#define GWX_XMLSEC_AES		1	/* Enable AES support (OpenSSL 0.9.7) */
#define GWX_XMLSEC_XMLDSIG	1	/* Enable XMLDSig support */
#define GWX_XMLSEC_XMLENC	1	/* Enable XMLEnc support */
#define GWX_XMLSEC_SKM		1	/* Enable simple key manager testing */

/*
*** Compile time options for library: MM
*/

/*
*** Compile time options for library: PCRE
*/
#define GWX_PCRE_POSIXWRAPPERS	1	/* Compile POSIX wrappers */
#define GWX_PCRE_UTF8		1	/* Compile in UTF-8 support */

/*
*** Compile time options for library: GHTTP
*/

/*
*** Compile time options for library: FONTCONFIG
*/

/*
*** Compile time options for library: LIBWWW
*/
#define GWX_LIBWWW_SIGNALS	1	/* Enable internal signal handler */
#define GWX_LIBWWW_NONAGLE	1	/* Disable Nagle's algorithm */
#define GWX_LIBWWW_AUTORULES	0	/* Automatically accept new rules */
#define GWX_LIBWWW_NOPIPELINE	0	/* Disable HTTP/1.1 pipelining */
#define GWX_LIBWWW_HTTPMUX	0	/* Use MUX as transport (broken) */

/*
*** Compile time options for library: CURL
*/
#define GWX_CURL_NOHTTP		0	/* Support http: protocol */
#define GWX_CURL_NOFTP		0	/* Support ftp: protocol */
#define GWX_CURL_NOGOPHER	0	/* Support gopher: protocol */
#define GWX_CURL_NOFILE		0	/* Support file: "protocol" */
#define GWX_CURL_NOLDAP		0	/* Support ldap: protocol */
#define GWX_CURL_NODICT		0	/* Support dict: protocol */
#define GWX_CURL_NOTELNET	0	/* Support telnet: protocol */
#define GWX_CURL_NONONBLOCKING	0	/* Support nonblocking connects */

/*
*** Compile time options for library: JAVASCRIPT
*/
#define GWX_JAVASCRIPT_PERL	0	/* JavaScript perlconnect */


/***************************************************************************
 ***                                                                     ***
 ***  NO USER EDITABLE OPTIONS BELOW THIS POINT. DO NOT MODIFY ANYTHING! ***
 ***                                                                     ***
 **************************************************************************/

#if !GWX_COMPILE_GTKPLUS1 && !GWX_COMPILE_GTKPLUS2
# undef GWX_COMPILE_GTKPLUS2
# define GWX_COMPILE_GTKPLUS2	1
# define GWX_GTKPLUS2_SMALL	1
#endif

/* Resolve inter-dependancies */
#if !GWX_COMPILE_ZLIB
# undef GWX_TIFF_ZLIB
# undef GWX_MPEGLIB_JPEG
# undef GWX_COMPILE_PNG
# undef GWX_XML2_ZLIB
# undef GWX_COMPILE_GD2
# define GWX_TIFF_ZLIB		0
# define GWX_MPEGLIB_ZLIB	0
# define GWX_COMPILE_PNG	0
# define GWX_XML2_ZLIB		0
# define GWX_COMPILE_GD2	0
#endif

#if !GWX_COMPILE_JPEG
# undef GWX_TIFF_JPEG
# undef GWX_GD_JPEG
# undef GWX_COMPILE_JASPER
# undef GWX_GTK2_JPEG
# undef GWX_COMPILE_GD2
# define GWX_TIFF_JPEG		0
# define GWX_GD_JPEG		0
# define GWX_COMPILE_JASPER	0
# define GWX_GTK2_JPEG		0
# define GWX_COMPILE_GD2	0
#endif

#if !GWX_COMPILE_PNG
# undef GWX_COMPILE_MNG
# undef GWX_GTK2_PNG
# undef GWX_COMPILE_GD2
# define GWX_COMPILE_MNG	0
# define GWX_GTK2_PNG		0
# define GWX_COMPILE_GD2	0
#endif

#if !GWX_COMPILE_TIFF
# undef GWX_GTK2_TIFF
# define GWX_GTK2_TIFF		0
#endif

#if GWX_COMPILE_ZLIB
# define HAVE_ZLIB		1
# define HAVE_LIBZ		1
# define HAVE_LIBZLIB		1
# define HAVE_LIBGZ		1
#endif

#if GWX_COMPILE_JPEG
# define HAVE_JPEG		1
# define HAVE_LIBJPEG		1
#endif

#if GWX_COMPILE_JASPER
# define HAVE_JASPER		1
# define HAVE_LIBJASPER		1
# define HAVE_JPEG2000		1
#endif

#if GWX_COMPILE_TIFF
# define HAVE_TIFF		1
# define HAVE_LIBTIFF		1
#endif

#if GWX_COMPILE_PNG
# define HAVE_PNG		1
# define HAVE_LIBPNG		1
#else
# undef GWX_GD_PNG
# define GWX_GD_PNG		0
#endif

#if GWX_COMPILE_JBIG
# define HAVE_JBIG		1
# define HAVE_LIBJBIG		1
#endif

#if GWX_COMPILE_FREETYPE1
# define HAVE_TTF		1
# define HAVE_LIBTTF		1
#else
# undef GWX_GD_FREETYPE1
# define GWX_GD_FREETYPE1	0
#endif

#if GWX_COMPILE_FREETYPE2
# define HAVE_FREETYPE		1
# define HAVE_LIBFREETYPE	1
#else
# undef GWX_GD_FREETYPE2
# define GWX_GD_FREETYPE2	0
#endif

#if GWX_COMPILE_GD
# define HAVE_GD		1
# define HAVE_GIF		1
# define HAVE_LIBGD		1
#endif

#if GWX_COMPILE_GIFLIB
# define HAVE_GIFLIB		1
# if !defined(HAVE_GIF)
#   define HAVE_GIF		1
# endif
# define HAVE_LIBGIFLIB		1
# define HAVE_LIBUNGIF		1
#endif

#if GWX_COMPILE_COMPFACE
# define HAVE_COMPFACE		1
# define HAVE_LIBCOMPFACE	1
#endif

#if GWX_COMPILE_XPM
# define HAVE_XPM		1
# define HAVE_LIBXPM		1
#else
# undef GWX_GD_XPM
# define GWX_GD_XPM		0
#endif

#if GWX_COMPILE_MPEGLIB
# define HAVE_MPEGLIB		1
# define HAVE_LIBMPEG		1
# define HAVE_LIBMPEGLIB	1
#endif

#if GWX_COMPILE_IMLIB
# define HAVE_IMLIB		1
# define HAVE_LIBIMLIB		1
#endif

#if GWX_COMPILE_GTKPLUS1
# define HAVE_GTKPLUS1		1
# define HAVE_LIBGTK1		1
# define HAVE_LIBGTKPLUS1	1
#endif

#if GWX_COMPILE_GTKPLUS2 && !GWX_GTKPLUS2_SMALL
# define HAVE_GTKPLUS2		1
# define HAVE_LIBGTK2		1
# define HAVE_LIBGTKPLUS2	1
#endif

#if !GWX_COMPILE_GTKPLUS1 && (!GWX_COMPILE_GTKPLUS2 || (GWX_COMPILE_GTKPLUS2 && GWX_GTKPLUS2_SMALL))
# undef GWX_COMPILE_GDOME
# undef GWX_COMPILE_IDL
# define GWX_COMPILE_GDOME	0
# define GWX_COMPILE_IDL	0
#endif

#if GWX_COMPILE_SLANG
# define HAVE_SLANG		1
# define HAVE_LIBSLANG		1
#endif

#if GWX_COMPILE_NETPBM
# define HAVE_NETPBM		1
# define HAVE_LIBPBM		1
# define HAVE_LIBPPM		1
# define HAVE_LIBPNM		1
#endif

#if GWX_COMPILE_GDBM
# define HAVE_GDBM		1
# define HAVE_LIBGDBM		1
#endif

#if GWX_COMPILE_DB
# define HAVE_DB		1
# define HAVE_DB3		1
# define HAVE_LIBDB		1
#endif

#if GWX_COMPILE_XML2
# define HAVE_LIBXML2		1
#else
# undef GWX_COMPILE_XSLT
# define GWX_COMPILE_XSLT	0
# undef GWX_COMPILE_GDOME
# define GWX_COMPILE_GDOME	0
#endif

#if GWX_ZLIB_586ASM
# undef GWX_ZLIB_686ASM
# define GWX_ZLIB_686ASM	0
#endif

#if GWX_ZLIB_686ASM
# undef GWX_ZLIB_586ASM
# define GWX_ZLIB_586ASM	0
#endif

#if !GWX_COMPILE_OPENSSL
# undef GWX_COMPILE_XMLSEC1
# undef GWX_COMPILE_SASL
# define GWX_COMPILE_XMLSEC1	0
# define GWX_COMPILE_SASL	0
#endif

#if !GWX_COMPILE_SASL
# undef GWX_COMPILE_LDAP
# define GWX_COMPILE_LDAP	0
#endif

#endif /* GWXCFG_HDR */

